@@ -277,13 +277,9 @@ namespace Akregator {
             void disconnectFromFeedList(FeedList* feedList);
 
             void updateTagActions();
-            
+
         protected slots:
 
-            /** this is called by the ctor, does init steps which need a properly created view and part */
-
-            void delayedInit();
-
             void connectFrame(Frame *);
 
             void setTabIcon(const QPixmap&);
