@@ -46,6 +46,7 @@
 #include "feedstorage.h"
 #include "storage.h"
 #include "treenodevisitor.h"
+#include "utils.h"
 
 #include "librss/librss.h"
 
@@ -126,11 +127,13 @@ Feed* Feed::fromOPML(QDomElement e)
 
     Feed* feed = 0;
 
-    if( e.hasAttribute("xmlUrl") || e.hasAttribute("xmlurl") )
+    if( e.hasAttribute("xmlUrl") || e.hasAttribute("xmlurl") || e.hasAttribute("xmlURL") )
     {
         QString title = e.hasAttribute("text") ? e.attribute("text") : e.attribute("title");
 
         QString xmlUrl = e.hasAttribute("xmlUrl") ? e.attribute("xmlUrl") : e.attribute("xmlurl");
+        if (xmlUrl.isEmpty())
+            xmlUrl = e.attribute("xmlURL");
 
         bool useCustomFetchInterval = e.attribute("useCustomFetchInterval") == "true" || e.attribute("autoFetch") == "true"; 
         // "autoFetch" is used in 3.4
@@ -205,8 +208,9 @@ QValueList<Article> Feed::articles(const QString& tag)
 
 void Feed::loadImage()
 {
-    QString u = d->xmlUrl;
-    QString imageFileName = KGlobal::dirs()->saveLocation("cache", "akregator/Media/") + u.replace("/", "_").replace(":", "_")+".png";
+    QString imageFileName = KGlobal::dirs()->saveLocation("cache", "akregator/Media/") 
+                            + Utils::fileNameForUrl(d->xmlUrl) + 
+".png";
     d->imagePixmap.load(imageFileName, "PNG");
 }
         
@@ -585,8 +589,9 @@ void Feed::slotImageFetched(const QPixmap& image)
     if (image.isNull())
         return;
     d->imagePixmap=image;
-    QString u = d->xmlUrl;
-    d->imagePixmap.save(KGlobal::dirs()->saveLocation("cache", "akregator/Media/")+u.replace("/", "_").replace(":", "_")+".png","PNG");
+    d->imagePixmap.save(KGlobal::dirs()->saveLocation("cache", "akregator/Media/") 
+                        + Utils::fileNameForUrl(d->xmlUrl) + 
+".png","PNG");
     nodeModified();
 }
 
