@@ -59,7 +59,7 @@
 #include <qtimer.h>
 
 
-using namespace Akregator;
+namespace Akregator {
 
 BrowserInterface::BrowserInterface( MainWindow *shell, const char *name )
     : KParts::BrowserInterface( shell, name )
@@ -282,6 +282,8 @@ void MainWindow::slotSetStatusBarText( const QString & text )
     m_statusLabel->setText(text);
 }
 
+} // namespace Akregator
+
 #include "mainwindow.moc"
 
 
