@@ -1,5 +1,5 @@
 // mk4.h --
-// $Id: mk4.h 403187 2005-04-04 20:17:07Z osterfeld $
+// $Id: mk4.h 798535 2008-04-18 14:31:04Z winterz $
 // This is part of Metakit, see http://www.equi4.com/metakit/
 
 /** @file
@@ -100,8 +100,8 @@
 
     // and here's the other end of the scale...
 #if !defined (_WIN32) && !defined (q4_LONG64)
-#if defined (_PA_RISC2_0) || defined (__powerpc64__) || defined(__sparcv9) || \
-    defined (__x86_64__) || defined (__s390x__) || defined (__alpha) || \
+#if (defined (_PA_RISC2_0) && defined(__hpux)) || defined (__powerpc64__) || defined(__sparcv9) || \
+    defined (__x86_64__) || defined (__s390x__) || defined (__alpha) || defined (__mips64) || \
     (defined (__ia64) && (!defined (__HP_aCC) || defined(__LP64__)))
 #define q4_LONG64 1
 #endif
