@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
@@ -39,6 +39,7 @@
 #include <gpgmepp/key.h>
 
 #include <qcstring.h>
+#include <qstring.h>
 
 #include <vector>
 #include <kdepimmacros.h>
@@ -107,6 +108,8 @@ namespace Kleo {
     GpgME::Error setSigningKeys( const std::vector<GpgME::Key> & signers );
     /*! Call this to implement a slotOperationDoneEvent() */
     void doSlotOperationDoneEvent( GpgME::Context * context, const GpgME::Error & e );
+    /*! Call this to extract the audit log from mCtx */
+    void getAuditLog();
 
     //
     // only boring stuff below this line...
@@ -116,6 +119,7 @@ namespace Kleo {
     virtual void doEmitProgressSignal( const QString & what, int current, int total ) = 0;
     virtual void doEmitDoneSignal() = 0;
     void doSlotCancel();
+    QString auditLogAsHtml() const { return mAuditLogAsHtml; }
 
   private:
     /*! \reimp from GpgME::ProgressProvider */
@@ -142,6 +146,7 @@ namespace Kleo {
     unsigned int mNumPatterns;
     unsigned int mChunkSize;
     unsigned int mPatternStartIndex, mPatternEndIndex;
+    QString mAuditLogAsHtml;
   };
 
 }
@@ -149,6 +154,7 @@ namespace Kleo {
 #define make_slot_cancel private: void slotCancel() { QGpgMEJob::doSlotCancel(); }
 #define make_progress_emitter private: void doEmitProgressSignal( const QString & what, int cur, int tot ) { emit progress( what, cur, tot ); }
 #define make_done_emitter private: void doEmitDoneSignal() { emit done(); }
-#define QGPGME_JOB make_slot_cancel make_progress_emitter make_done_emitter
+#define make_auditLogAsHtml private: QString auditLogAsHtml() const { return QGpgMEJob::auditLogAsHtml(); }
+#define QGPGME_JOB make_slot_cancel make_progress_emitter make_done_emitter make_auditLogAsHtml
 
 #endif // __KLEO_QGPGMEJOB_H__
