@@ -2,7 +2,7 @@
     keyselectiondialog.cpp
 
     This file is part of libkleopatra, the KDE keymanagement library
-    Copyright (c) 2004 Klarlvdalens Datakonsult AB
+    Copyright (c) 2004 Klarävdalens Datakonsult AB
 
     Based on kpgpui.cpp
     Copyright (C) 2001,2002 the KPGP authors
@@ -60,6 +60,7 @@
 #include <kwin.h>
 #include <kconfig.h>
 #include <kmessagebox.h>
+#include <kprocess.h>
 
 // Qt
 #include <qcheckbox.h>
@@ -295,7 +296,7 @@ Kleo::KeySelectionDialog::KeySelectionDialog( const QString & title,
 					      bool rememberChoice,
 					      QWidget * parent, const char * name,
 					      bool modal )
-  : KDialogBase( parent, name, modal, title, Default|Ok|Cancel, Ok ),
+  : KDialogBase( parent, name, modal, title, Default|Ok|Cancel|Help, Ok ),
     mOpenPGPBackend( 0 ),
     mSMIMEBackend( 0 ),
     mRememberCB( 0 ),
@@ -314,7 +315,7 @@ Kleo::KeySelectionDialog::KeySelectionDialog( const QString & title,
 					      bool rememberChoice,
 					      QWidget * parent, const char * name,
 					      bool modal )
-  : KDialogBase( parent, name, modal, title, Default|Ok|Cancel, Ok ),
+  : KDialogBase( parent, name, modal, title, Default|Ok|Cancel|Help, Ok ),
     mOpenPGPBackend( 0 ),
     mSMIMEBackend( 0 ),
     mRememberCB( 0 ),
@@ -336,15 +337,15 @@ void Kleo::KeySelectionDialog::init( bool rememberChoice, bool extendedSelection
   mStartSearchTimer = new QTimer( this );
 
   QFrame *page = makeMainWidget();
-  QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
+  mTopLayout = new QVBoxLayout( page, 0, spacingHint() );
 
   if ( !text.isEmpty() ) {
     QLabel* textLabel = new QLabel( text, page );
     textLabel->setAlignment( textLabel->alignment() | Qt::WordBreak );
-    topLayout->addWidget( textLabel );
+    mTopLayout->addWidget( textLabel );
   }
 
-  QHBoxLayout * hlay = new QHBoxLayout( topLayout ); // inherits spacing
+  QHBoxLayout * hlay = new QHBoxLayout( mTopLayout ); // inherits spacing
   QLineEdit * le = new QLineEdit( page );
   le->setText( initialQuery );
   QToolButton *clearButton = new QToolButton( page );
@@ -368,11 +369,11 @@ void Kleo::KeySelectionDialog::init( bool rememberChoice, bool extendedSelection
   mKeyListView->setShowToolTips( true );
   if ( extendedSelection )
     mKeyListView->setSelectionMode( QListView::Extended );
-  topLayout->addWidget( mKeyListView, 10 );
+  mTopLayout->addWidget( mKeyListView, 10 );
 
   if ( rememberChoice ) {
     mRememberCB = new QCheckBox( i18n("&Remember choice"), page );
-    topLayout->addWidget( mRememberCB );
+    mTopLayout->addWidget( mRememberCB );
     QWhatsThis::add( mRememberCB,
 		     i18n("<qt><p>If you check this box your choice will "
 			  "be stored and you will not be asked again."
@@ -391,15 +392,16 @@ void Kleo::KeySelectionDialog::init( bool rememberChoice, bool extendedSelection
            SLOT(slotRMB(Kleo::KeyListViewItem*,const QPoint&)) );
 
   setButtonText( KDialogBase::Default, i18n("&Reread Keys") );
-  connect( this, SIGNAL(defaultClicked()),
-           this, SLOT(slotRereadKeys()) );
+  setButtonGuiItem( KDialogBase::Help, i18n("&Start Certificate Manager") );
+  connect( this, SIGNAL(defaultClicked()), this, SLOT(slotRereadKeys()) );
+  connect( this, SIGNAL(helpClicked()), this, SLOT(slotStartCertificateManager()) );
 
   slotRereadKeys();
-  topLayout->activate();
+  mTopLayout->activate();
 
   if ( kapp ) {
     KWin::setIcons( winId(), kapp->icon(), kapp->miniIcon() );
-    QSize dialogSize( sizeHint() );
+    QSize dialogSize( 500, 400 );
 
     KConfigGroup dialogConfig( KGlobal::config(), "Key Selection Dialog" );
     dialogSize = dialogConfig.readSizeEntry( "Dialog size", &dialogSize );
@@ -493,6 +495,24 @@ void Kleo::KeySelectionDialog::slotRereadKeys() {
   }
 }
 
+void Kleo::KeySelectionDialog::slotHelp()
+{
+    emit helpClicked();
+}
+
+void Kleo::KeySelectionDialog::slotStartCertificateManager()
+{
+  KProcess certManagerProc;
+  certManagerProc << "kleopatra";
+
+  if( !certManagerProc.start( KProcess::DontCare ) )
+    KMessageBox::error( this, i18n( "Could not start certificate manager; "
+                                    "please check your installation." ),
+                                    i18n( "Certificate Manager Error" ) );
+  else
+    kdDebug(5006) << "\nslotStartCertManager(): certificate manager started.\n" << endl;
+}
+
 #ifndef __KLEO_UI_SHOW_KEY_LIST_ERROR_H__
 #define __KLEO_UI_SHOW_KEY_LIST_ERROR_H__
 static void showKeyListError( QWidget * parent, const GpgME::Error & err ) {
