@@ -53,6 +53,7 @@
 #include <libkdepim/categoryeditdialog.h>
 #include <libkdepim/categoryselectdialog.h>
 #include <libkdepim/kdateedit.h>
+#include <libkdepim/resourceabc.h>
 
 #include "addresseditwidget.h"
 #include "advancedcustomfields.h"
@@ -90,11 +91,23 @@ AddresseeEditorWidget::~AddresseeEditorWidget()
 void AddresseeEditorWidget::setAddressee( const KABC::Addressee &addr )
 {
   if ( mAddressee.uid() == addr.uid() )
-	  return;
-
+    return;
   mAddressee = addr;
 
-  bool readOnly = ( !addr.resource() ? false : addr.resource()->readOnly() );
+  bool readOnly = false;
+  if ( KABC::Resource *res = addr.resource() ) {
+    if ( res->readOnly() ) {
+      readOnly = true;
+
+    //Kolab resources have finer access control than planned in the overall design.
+    } else if ( res->inherits( "KPIM::ResourceABC" ) ) {
+      KPIM::ResourceABC *resAbc = static_cast<KPIM::ResourceABC *>( res );
+
+      QString subresource = resAbc->uidToResourceMap()[ addr.uid() ];
+      if ( !subresource.isEmpty() )
+        readOnly |= !resAbc->subresourceWritable( subresource );
+    }
+  }
   setReadOnly( readOnly );
 
   load();
@@ -529,9 +542,11 @@ void AddresseeEditorWidget::load()
 
   mRoleEdit->setText( mAddressee.role() );
   mOrgEdit->setText( mAddressee.organization() );
+#if KDE_IS_VERSION(3,5,8)
   mDepartmentEdit->setText( mAddressee.department() );
   // compatibility with older versions
   if ( mAddressee.department().isEmpty() )
+#endif
     mDepartmentEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-Department" ) );
   mURLEdit->setURL( mAddressee.url() );
   mURLEdit->home( false );
@@ -575,7 +590,14 @@ void AddresseeEditorWidget::save()
 
   mAddressee.setRole( mRoleEdit->text() );
   mAddressee.setOrganization( mOrgEdit->text() );
+#if KDE_IS_VERSION(3,5,8)
   mAddressee.setDepartment( mDepartmentEdit->text() );
+#else
+  if ( !mDepartmentEdit->text().isEmpty() )
+    mAddressee.insertCustom( "KADDRESSBOOK", "X-Department", mDepartmentEdit->text() );
+  else
+    mAddressee.removeCustom( "KADDRESSBOOK", "X-Department" );
+#endif
 
   QString homepage = mURLEdit->text().stripWhiteSpace();
   if ( homepage.isEmpty() )
