@@ -107,6 +107,12 @@ void KAddressbookPart::newContact()
   mCore->newContact();
 }
 
+
+void KAddressbookPart::newDistributionList()
+{
+  mCore->newDistributionList();
+}
+
 QString KAddressbookPart::getNameByPhone( QString phone )
 {
   return mCore->getNameByPhone( phone );
@@ -162,4 +168,12 @@ void KAddressbookPart::guiActivateEvent( KParts::GUIActivateEvent *e )
   }
 }
 
+void KAddressbookPart::loadProfile( const QString& )
+{
+}
+
+void KAddressbookPart::saveToProfile( const QString& ) const
+{
+}
+
 #include "kaddressbook_part.moc"
