@@ -25,6 +25,7 @@
 #define KADDRESSBOOKIFACE_H
 
 #include <dcopobject.h>
+#include <kurl.h>
 #include <qstringlist.h>
 #include <kdepimmacros.h>
 
@@ -34,16 +35,23 @@ class KDE_EXPORT KAddressBookIface : virtual public DCOPObject
 
   k_dcop:
     virtual void addEmail( QString addr ) = 0;
-    virtual void importVCard( const QString& vCardURL ) = 0;
+    virtual void importVCard( const KURL& url ) = 0;
+    virtual void importVCardFromData( const QString& vCard ) = 0;
 
     virtual ASYNC showContactEditor( QString uid ) = 0;
 
     /**
-      Show's dialog for creation of a new contact.  Returns once a contact
+      Shows dialog for creation of a new contact.  Returns once a contact
       is created (or canceled).
      */
     virtual void newContact() = 0;
 
+    /**
+      Shows dialog for creation of a new distribution list.  Returns once a distribution list
+      is created (or canceled).
+     */
+    virtual void newDistributionList() = 0;
+
     /**
       Save changes to the address book files.
      */
@@ -56,6 +64,9 @@ class KDE_EXPORT KAddressBookIface : virtual public DCOPObject
      * Return true if handled, false if command-line was empty.
      */
     virtual bool handleCommandLine() = 0;
+
+    virtual void loadProfile( const QString& path ) = 0;
+    virtual void saveToProfile( const QString& path ) const = 0;
 };
 
 #endif
