@@ -1,7 +1,7 @@
 /*
  *  birthdaydlg.cpp  -  dialog to pick birthdays from address book
  *  Program:  kalarm
- *  Copyright © 2002-2007 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2002-2008 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -88,7 +88,6 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 	QGroupBox* textGroup = new QGroupBox(2, Qt::Horizontal, i18n("Alarm Text"), topWidget);
 	topLayout->addWidget(textGroup);
 	QLabel* label = new QLabel(i18n("Pre&fix:"), textGroup);
-	label->setFixedSize(label->sizeHint());
 	mPrefix = new BLineEdit(mPrefixText, textGroup);
 	mPrefix->setMinimumSize(mPrefix->sizeHint());
 	label->setBuddy(mPrefix);
@@ -98,7 +97,6 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 	           "including any necessary trailing spaces."));
 
 	label = new QLabel(i18n("S&uffix:"), textGroup);
-	label->setFixedSize(label->sizeHint());
 	mSuffix = new BLineEdit(mSuffixText, textGroup);
 	mSuffix->setMinimumSize(mSuffix->sizeHint());
 	label->setBuddy(mSuffix);
@@ -128,19 +126,10 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 	QBoxLayout* groupLayout = new QVBoxLayout(group, marginHint(), spacingHint());
 	groupLayout->addSpacing(fontMetrics().lineSpacing()/2);
 
-	// Colour choice drop-down list
-	QBoxLayout* layout = new QHBoxLayout(groupLayout, 2*spacingHint());
-	QHBox* box;
-	mBgColourChoose = EditAlarmDlg::createBgColourChooser(&box, group);
-	connect(mBgColourChoose, SIGNAL(highlighted(const QColor&)), SLOT(slotBgColourSelected(const QColor&)));
-	layout->addWidget(box);
-	layout->addStretch();
-
-	// Font and colour choice drop-down list
+	// Font and colour choice button and sample text
 	mFontColourButton = new FontColourButton(group);
-	mFontColourButton->setFixedSize(mFontColourButton->sizeHint());
-	connect(mFontColourButton, SIGNAL(selected()), SLOT(slotFontColourSelected()));
-	layout->addWidget(mFontColourButton);
+	mFontColourButton->setMaximumHeight(mFontColourButton->sizeHint().height() * 3/2);
+	groupLayout->addWidget(mFontColourButton);
 
 	// Sound checkbox and file selector
 	mSoundPicker = new SoundPicker(group);
@@ -159,9 +148,8 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 	groupLayout->addWidget(mReminder, 0, Qt::AlignAuto);
 
 	// Acknowledgement confirmation required - default = no confirmation
-	layout = new QHBoxLayout(groupLayout, 2*spacingHint());
+	QHBoxLayout* layout = new QHBoxLayout(groupLayout, 2*spacingHint());
 	mConfirmAck = EditAlarmDlg::createConfirmAckCheckbox(group);
-	mConfirmAck->setFixedSize(mConfirmAck->sizeHint());
 	layout->addWidget(mConfirmAck);
 	layout->addSpacing(2*spacingHint());
 	layout->addStretch();
@@ -170,28 +158,25 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 	{
 		// Special actions button
 		mSpecialActionsButton = new SpecialActionsButton(i18n("Special Actions..."), group);
-		mSpecialActionsButton->setFixedSize(mSpecialActionsButton->sizeHint());
 		layout->addWidget(mSpecialActionsButton);
 	}
 
 	// Late display checkbox - default = allow late display
 	layout = new QHBoxLayout(groupLayout, 2*spacingHint());
 	mLateCancel = new LateCancelSelector(false, group);
-	mLateCancel->setFixedSize(mLateCancel->sizeHint());
 	layout->addWidget(mLateCancel);
 	layout->addStretch();
 
-	// Simple repetition button
-	mSimpleRepetition = new RepetitionButton(i18n("Simple Repetition"), false, group);
-	mSimpleRepetition->setFixedSize(mSimpleRepetition->sizeHint());
-	mSimpleRepetition->set(0, 0, true, 364*24*60);
-	QWhatsThis::add(mSimpleRepetition, i18n("Set up an additional alarm repetition"));
-	layout->addWidget(mSimpleRepetition);
+	// Sub-repetition button
+	mSubRepetition = new RepetitionButton(i18n("Sub-Repetition"), false, group);
+	mSubRepetition->set(0, 0, true, 364*24*60);
+	QWhatsThis::add(mSubRepetition, i18n("Set up an additional alarm repetition"));
+	layout->addWidget(mSubRepetition);
 
 	// Set the values to their defaults
 	mFontColourButton->setDefaultFont();
 	mFontColourButton->setBgColour(Preferences::defaultBgColour());
-	mBgColourChoose->setColour(Preferences::defaultBgColour());     // set colour before setting alarm type buttons
+	mFontColourButton->setFgColour(Preferences::defaultFgColour());     // set colour before setting alarm type buttons
 	mLateCancel->setMinutes(Preferences::defaultLateCancel(), true, TimePeriod::DAYS);
 	mConfirmAck->setChecked(Preferences::defaultConfirmAck());
 	mSoundPicker->set(Preferences::defaultSoundType(), Preferences::defaultSoundFile(),
@@ -226,6 +211,18 @@ void BirthdayDlg::loadAddressBook()
                 KMessageBox::error(this, i18n("Error reading address book"));
 }
 
+/******************************************************************************
+* Close the address book.This is called at program termination.
+*/
+void BirthdayDlg::close()
+{
+	if (mAddressBook)
+	{
+		KABC::StdAddressBook::close();
+		mAddressBook = 0;
+	}
+}
+
 /******************************************************************************
 * Initialise or update the birthday selection list by fetching all birthdays
 * from the address book and displaying those which do not already have alarms.
@@ -316,7 +313,7 @@ QValueList<KAEvent> BirthdayDlg::events() const
 					date.setYMD(thisYear + 1, date.month(), date.day());
 				KAEvent event(date,
 				              mPrefix->text() + aItem->text(AddresseeItem::NAME) + mSuffix->text(),
-				              mBgColourChoose->color(), mFontColourButton->fgColour(),
+				              mFontColourButton->bgColour(), mFontColourButton->fgColour(),
 				              mFontColourButton->font(), KAEvent::MESSAGE, mLateCancel->minutes(),
 				              mFlags);
 				float fadeVolume;
@@ -326,7 +323,7 @@ QValueList<KAEvent> BirthdayDlg::events() const
 				QValueList<int> months;
 				months.append(date.month());
 				event.setRecurAnnualByDate(1, months, 0, Preferences::defaultFeb29Type(), -1, QDate());
-				event.setRepetition(mSimpleRepetition->interval(), mSimpleRepetition->count());
+				event.setRepetition(mSubRepetition->interval(), mSubRepetition->count());
 				event.setNextOccurrence(todayNoon);
 				if (reminder)
 					event.setReminder(reminder, false);
@@ -394,24 +391,6 @@ void BirthdayDlg::slotTextLostFocus()
 	}
 }
 
-/******************************************************************************
-*  Called when the a new background colour has been selected using the colour
-*  combo box.
-*/
-void BirthdayDlg::slotBgColourSelected(const QColor& colour)
-{
-	mFontColourButton->setBgColour(colour);
-}
-
-/******************************************************************************
-*  Called when the a new font and colour have been selected using the font &
-*  colour pushbutton.
-*/
-void BirthdayDlg::slotFontColourSelected()
-{
-	mBgColourChoose->setColour(mFontColourButton->bgColour());
-}
-
 
 /*=============================================================================
 = Class: AddresseeItem
