@@ -1,7 +1,7 @@
 /*
  *  dcophandler.h  -  handler for DCOP calls by other applications
  *  Program:  kalarm
- *  Copyright © 2001,2002,2004-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001,2002,2004-2006,2008 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ class DcopHandler : public QWidget, virtual public KAlarmIface
 	virtual bool scheduleMessage(const QString& message, const QString& startDateTime, int lateCancel, unsigned flags,
 	                             const QString& bgColor, const QString& fgColor, const QString& font,
 	                             const KURL& audioFile, int reminderMins, const QString& recurrence,
-	                             int repeatInterval, int repeatCount);
+	                             int subRepeatInterval, int subRepeatCount);
 	virtual bool scheduleMessage(const QString& message, const QString& startDateTime, int lateCancel, unsigned flags,
 	                             const QString& bgColor, const QString& fgColor, const QString& font,
 	                             const KURL& audioFile, int reminderMins, int recurType, int recurInterval, int recurCount);
@@ -47,13 +47,13 @@ class DcopHandler : public QWidget, virtual public KAlarmIface
 	                             const KURL& audioFile, int reminderMins, int recurType, int recurInterval, const QString& endDateTime);
 	virtual bool scheduleFile(const KURL& file, const QString& startDateTime, int lateCancel, unsigned flags, const QString& bgColor,
 	                          const KURL& audioFile, int reminderMins, const QString& recurrence,
-	                          int repeatInterval, int repeatCount);
+	                          int subRepeatInterval, int subRepeatCount);
 	virtual bool scheduleFile(const KURL& file, const QString& startDateTime, int lateCancel, unsigned flags, const QString& bgColor,
 	                          const KURL& audioFile, int reminderMins, int recurType, int recurInterval, int recurCount);
 	virtual bool scheduleFile(const KURL& file, const QString& startDateTime, int lateCancel, unsigned flags, const QString& bgColor,
 	                          const KURL& audioFile, int reminderMins, int recurType, int recurInterval, const QString& endDateTime);
 	virtual bool scheduleCommand(const QString& commandLine, const QString& startDateTime, int lateCancel, unsigned flags,
-	                             const QString& recurrence, int repeatInterval, int repeatCount);
+	                             const QString& recurrence, int subRepeatInterval, int subRepeatCount);
 	virtual bool scheduleCommand(const QString& commandLine, const QString& startDateTime, int lateCancel, unsigned flags,
 	                             int recurType, int recurInterval, int recurCount);
 	virtual bool scheduleCommand(const QString& commandLine, const QString& startDateTime, int lateCancel, unsigned flags,
@@ -74,19 +74,19 @@ class DcopHandler : public QWidget, virtual public KAlarmIface
 	static bool scheduleMessage(const QString& message, const DateTime& start, int lateCancel, unsigned flags,
                                 const QString& bgColor, const QString& fgColor, const QString& fontStr,
                                 const KURL& audioFile, int reminderMins, const KARecurrence&,
-	                            int repeatInterval = 0, int repeatCount = 0);
+	                            int subRepeatInterval = 0, int subRepeatCount = 0);
 	static bool scheduleFile(const KURL& file, const DateTime& start, int lateCancel, unsigned flags, const QString& bgColor,
                              const KURL& audioFile, int reminderMins, const KARecurrence&,
-	                         int repeatInterval = 0, int repeatCount = 0);
+	                         int subRepeatInterval = 0, int subRepeatCount = 0);
 	static bool scheduleCommand(const QString& commandLine, const DateTime& start, int lateCancel, unsigned flags,
-                                const KARecurrence&, int repeatInterval = 0, int repeatCount = 0);
+                                const KARecurrence&, int subRepeatInterval = 0, int subRepeatCount = 0);
 	static bool scheduleEmail(const QString& fromID, const QString& addresses, const QString& subject, const QString& message,
                               const QString& attachments, const DateTime& start, int lateCancel, unsigned flags,
-                              const KARecurrence&, int repeatInterval = 0, int repeatCount = 0);
+                              const KARecurrence&, int subRepeatInterval = 0, int subRepeatCount = 0);
 	static DateTime  convertStartDateTime(const QString& startDateTime);
 	static unsigned  convertStartFlags(const DateTime& start, unsigned flags);
 	static QColor    convertBgColour(const QString& bgColor);
-	static bool      convertRecurrence(DateTime& start, KARecurrence&, const QString& startDateTime, const QString& icalRecurrence);
+	static bool      convertRecurrence(DateTime& start, KARecurrence&, const QString& startDateTime, const QString& icalRecurrence, int& subRepeatInterval);
 	static bool      convertRecurrence(DateTime& start, KARecurrence&, const QString& startDateTime, int recurType, int recurInterval, int recurCount);
 	static bool      convertRecurrence(DateTime& start, KARecurrence&, const QString& startDateTime, int recurType, int recurInterval, const QString& endDateTime);
 	static bool      convertRecurrence(KARecurrence&, const DateTime& start, int recurType, int recurInterval, int recurCount, const QDateTime& end);
