@@ -1,7 +1,7 @@
 /*
  *  editdlg.cpp  -  dialogue to create or modify an alarm or alarm template
  *  Program:  kalarm
- *  Copyright © 2001-2007 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2008 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -76,7 +76,6 @@
 #include "radiobutton.h"
 #include "recurrenceedit.h"
 #include "reminder.h"
-#include "repetition.h"
 #include "shellprocess.h"
 #include "soundpicker.h"
 #include "specialactions.h"
@@ -128,7 +127,12 @@ class PickLogFileRadio : public PickFileRadio
 
 inline QString recurText(const KAEvent& event)
 {
-	return QString::fromLatin1("%1 / %2").arg(event.recurrenceText()).arg(event.repetitionText());
+	QString r;
+	if (event.repeatCount())
+		r = QString::fromLatin1("%1 / %2").arg(event.recurrenceText()).arg(event.repetitionText());
+	else
+		r = event.recurrenceText();
+	return i18n("&Recurrence - [%1]").arg(r);
 }
 
 // Collect these widget labels together to ensure consistent wording and
@@ -213,12 +217,13 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const QString& caption, QWidget* paren
 	// Recurrence tab
 	QVBox* recurTab = new QVBox(mTabs);
 	mainPageBox->setSpacing(spacingHint());
-	mTabs->addTab(recurTab, i18n("&Recurrence"));
+	mTabs->addTab(recurTab, QString::null);
 	mRecurPageIndex = 1;
 	mRecurrenceEdit = new RecurrenceEdit(readOnly, recurTab, "recurPage");
 	connect(mRecurrenceEdit, SIGNAL(shown()), SLOT(slotShowRecurrenceEdit()));
 	connect(mRecurrenceEdit, SIGNAL(typeChanged(int)), SLOT(slotRecurTypeChange(int)));
 	connect(mRecurrenceEdit, SIGNAL(frequencyChanged()), SLOT(slotRecurFrequencyChange()));
+	connect(mRecurrenceEdit, SIGNAL(repeatNeedsInitialisation()), SLOT(slotSetSubRepetition()));
 
 	// Alarm action
 
@@ -354,27 +359,6 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const QString& caption, QWidget* paren
 		topLayout->addWidget(mTimeWidget);
 	}
 
-	// Recurrence type display
-	layout = new QHBoxLayout(topLayout, 2*spacingHint());
-	QHBox* box = new QHBox(mainPage);   // this is to control the QWhatsThis text display area
-	box->setSpacing(KDialog::spacingHint());
-	label = new QLabel(i18n("Recurrence:"), box);
-	label->setFixedSize(label->sizeHint());
-	mRecurrenceText = new QLabel(box);
-	QWhatsThis::add(box,
-	      i18n("How often the alarm recurs.\nThe times shown are those configured in the Recurrence tab and in the Simple Repetition dialog."));
-	box->setFixedHeight(box->sizeHint().height());
-	layout->addWidget(box);
-	layout->addStretch();
-
-	// Simple repetition button
-	mSimpleRepetition = new RepetitionButton(i18n("Simple Repetition"), true, mainPage);
-	mSimpleRepetition->setFixedSize(mSimpleRepetition->sizeHint());
-	connect(mSimpleRepetition, SIGNAL(needsInitialisation()), SLOT(slotSetSimpleRepetition()));
-	connect(mSimpleRepetition, SIGNAL(changed()), SLOT(slotRecurFrequencyChange()));
-	QWhatsThis::add(mSimpleRepetition, i18n("Set up a simple, or additional, alarm repetition"));
-	layout->addWidget(mSimpleRepetition);
-
 	// Reminder
 	static const QString reminderText = i18n("Enter how long in advance of the main alarm to display a reminder alarm.");
 	mReminder = new Reminder(i18n("Rem&inder:"),
@@ -438,7 +422,7 @@ void EditAlarmDlg::initDisplayAlarms(QWidget* parent)
 
 	// Text message edit box
 	mTextMessageEdit = new TextEdit(mDisplayAlarmsFrame);
-	mTextMessageEdit->setWordWrap(QTextEdit::NoWrap);
+	mTextMessageEdit->setWordWrap(KTextEdit::NoWrap);
 	QWhatsThis::add(mTextMessageEdit, i18n("Enter the text of the alarm message. It may be multi-line."));
 	frameLayout->addWidget(mTextMessageEdit);
 
@@ -457,21 +441,20 @@ void EditAlarmDlg::initDisplayAlarms(QWidget* parent)
 	QWhatsThis::add(mFileBrowseButton, i18n("Select a text or image file to display."));
 	mFileRadio->init(mFileBrowseButton, mFileMessageEdit);
 
-	// Colour choice drop-down list
-	QBoxLayout* layout = new QHBoxLayout(frameLayout);
-	QHBox* box;
-	mBgColourChoose = createBgColourChooser(&box, mDisplayAlarmsFrame);
-	mBgColourChoose->setFixedSize(mBgColourChoose->sizeHint());
-	connect(mBgColourChoose, SIGNAL(highlighted(const QColor&)), SLOT(slotBgColourSelected(const QColor&)));
-	layout->addWidget(box);
-	layout->addSpacing(2*spacingHint());
-	layout->addStretch();
-
-	// Font and colour choice drop-down list
+	// Font and colour choice button and sample text
 	mFontColourButton = new FontColourButton(mDisplayAlarmsFrame);
-	mFontColourButton->setFixedSize(mFontColourButton->sizeHint());
-	connect(mFontColourButton, SIGNAL(selected()), SLOT(slotFontColourSelected()));
-	layout->addWidget(mFontColourButton);
+	mFontColourButton->setMaximumHeight(mFontColourButton->sizeHint().height());
+	frameLayout->addWidget(mFontColourButton);
+
+	QHBoxLayout* layout = new QHBoxLayout(frameLayout, 0, 0);
+	mBgColourBox = new QHBox(mDisplayAlarmsFrame);
+	mBgColourBox->setSpacing(spacingHint());
+	layout->addWidget(mBgColourBox);
+	layout->addStretch();
+	QLabel* label = new QLabel(i18n("&Background color:"), mBgColourBox);
+	mBgColourButton = new ColourCombo(mBgColourBox);
+	label->setBuddy(mBgColourButton);
+	QWhatsThis::add(mBgColourBox, i18n("Select the alarm message background color"));
 
 	// Sound checkbox and file selector
 	layout = new QHBoxLayout(frameLayout);
@@ -703,7 +686,7 @@ void EditAlarmDlg::initialise(const KAEvent* event)
 			mFontColourButton->setFont(event->font());
 		mFontColourButton->setBgColour(event->bgColour());
 		mFontColourButton->setFgColour(event->fgColour());
-		mBgColourChoose->setColour(event->bgColour());     // set colour before setting alarm type buttons
+		mBgColourButton->setColour(event->bgColour());
 		if (mTemplate)
 		{
 			// Editing a template
@@ -745,8 +728,8 @@ void EditAlarmDlg::initialise(const KAEvent* event)
 			else
 			{
 				mExpiredRecurrence = recurs && event->mainExpired();
-				mTimeWidget->setDateTime(!event->mainExpired() ? event->mainDateTime()
-				                         : recurs ? DateTime() : event->deferDateTime());
+				mTimeWidget->setDateTime(recurs || event->uidStatus() == KAEvent::EXPIRED ? event->startDateTime()
+				                         : event->mainExpired() ? event->deferDateTime() : event->mainDateTime());
 			}
 		}
 
@@ -787,9 +770,8 @@ void EditAlarmDlg::initialise(const KAEvent* event)
 		mReminder->enableOnceOnly(event->recurs());
 		if (mSpecialActionsButton)
 			mSpecialActionsButton->setActions(event->preAction(), event->postAction());
-		mSimpleRepetition->set(event->repeatInterval(), event->repeatCount());
-		mRecurrenceText->setText(recurText(*event));
-		mRecurrenceEdit->set(*event);   // must be called after mTimeWidget is set up, to ensure correct date-only enabling
+		mRecurrenceEdit->set(*event, (mTemplate || event->isTemplate()));   // must be called after mTimeWidget is set up, to ensure correct date-only enabling
+		mTabs->setTabLabel(mTabs->page(mRecurPageIndex), recurText(*event));
 		SoundPicker::Type soundType = event->speak()                ? SoundPicker::SPEAK
 		                            : event->beep()                 ? SoundPicker::BEEP
 		                            : !event->audioFile().isEmpty() ? SoundPicker::PLAY_FILE
@@ -806,7 +788,7 @@ void EditAlarmDlg::initialise(const KAEvent* event)
 		mEmailSubjectEdit->setText(event->emailSubject());
 		mEmailBcc->setChecked(event->emailBcc());
 		if (mEmailFromList)
-			mEmailFromList->setCurrentIdentity(event->emailFromKMail());
+			mEmailFromList->setCurrentIdentity(event->emailFromId());
 	}
 	else
 	{
@@ -821,7 +803,7 @@ void EditAlarmDlg::initialise(const KAEvent* event)
 		mFontColourButton->setDefaultFont();
 		mFontColourButton->setBgColour(Preferences::defaultBgColour());
 		mFontColourButton->setFgColour(Preferences::defaultFgColour());
-		mBgColourChoose->setColour(Preferences::defaultBgColour());     // set colour before setting alarm type buttons
+		mBgColourButton->setColour(Preferences::defaultBgColour());
 		QDateTime defaultTime = QDateTime::currentDateTime().addSecs(60);
 		if (mTemplate)
 		{
@@ -883,15 +865,14 @@ void EditAlarmDlg::setReadOnly()
 		mDeferChangeButton->hide();
 	else
 		mDeferChangeButton->show();
-	mSimpleRepetition->setReadOnly(mReadOnly);
 	if (mShowInKorganizer)
 		mShowInKorganizer->setReadOnly(mReadOnly);
 
 	// Message alarm controls
 	mTextMessageEdit->setReadOnly(mReadOnly);
 	mFileMessageEdit->setReadOnly(mReadOnly);
-	mBgColourChoose->setReadOnly(mReadOnly);
 	mFontColourButton->setReadOnly(mReadOnly);
+	mBgColourButton->setReadOnly(mReadOnly);
 	mSoundPicker->setReadOnly(mReadOnly);
 	mConfirmAck->setReadOnly(mReadOnly);
 	mReminder->setReadOnly(mReadOnly);
@@ -988,24 +969,6 @@ void EditAlarmDlg::setAction(KAEvent::Action action, const AlarmText& alarmText)
 	mActionGroup->setButton(mActionGroup->id(radio));
 }
 
-/******************************************************************************
- * Create a widget to choose the alarm message background colour.
- */
-ColourCombo* EditAlarmDlg::createBgColourChooser(QHBox** box, QWidget* parent, const char* name)
-{
-	*box = new QHBox(parent);   // this is to control the QWhatsThis text display area
-	QLabel* label = new QLabel(i18n("&Background color:"), *box);
-	label->setFixedSize(label->sizeHint());
-	ColourCombo* widget = new ColourCombo(*box, name);
-	QSize size = widget->sizeHint();
-	widget->setMinimumHeight(size.height() + 4);
-	QToolTip::add(widget, i18n("Message color"));
-	label->setBuddy(widget);
-	(*box)->setFixedHeight((*box)->sizeHint().height());
-	QWhatsThis::add(*box, i18n("Choose the background color for the alarm message."));
-	return widget;
-}
-
 /******************************************************************************
  * Create an "acknowledgement confirmation required" checkbox.
  */
@@ -1041,7 +1004,7 @@ void EditAlarmDlg::saveState(const KAEvent* event)
 	mSavedConfirmAck       = mConfirmAck->isChecked();
 	mSavedFont             = mFontColourButton->font();
 	mSavedFgColour         = mFontColourButton->fgColour();
-	mSavedBgColour         = mBgColourChoose->color();
+	mSavedBgColour         = mFileRadio->isOn() ? mBgColourButton->colour() : mFontColourButton->bgColour();
 	mSavedReminder         = mReminder->minutes();
 	mSavedOnceOnly         = mReminder->isOnceOnly();
 	if (mSpecialActionsButton)
@@ -1068,8 +1031,6 @@ void EditAlarmDlg::saveState(const KAEvent* event)
 	if (mShowInKorganizer)
 		mSavedShowInKorganizer = mShowInKorganizer->isChecked();
 	mSavedRecurrenceType   = mRecurrenceEdit->repeatType();
-	mSavedRepeatInterval   = mSimpleRepetition->interval();
-	mSavedRepeatCount      = mSimpleRepetition->count();
 }
 
 /******************************************************************************
@@ -1102,9 +1063,7 @@ bool EditAlarmDlg::stateChanged() const
 	||  mSavedLateCancel       != mLateCancel->minutes()
 	||  mShowInKorganizer && mSavedShowInKorganizer != mShowInKorganizer->isChecked()
 	||  textFileCommandMessage != mSavedTextFileCommandMessage
-	||  mSavedRecurrenceType   != mRecurrenceEdit->repeatType()
-	||  mSavedRepeatInterval   != mSimpleRepetition->interval()
-	||  mSavedRepeatCount      != mSimpleRepetition->count())
+	||  mSavedRecurrenceType   != mRecurrenceEdit->repeatType())
 		return true;
 	if (mMessageRadio->isOn()  ||  mFileRadio->isOn())
 	{
@@ -1112,7 +1071,7 @@ bool EditAlarmDlg::stateChanged() const
 		||  mSavedConfirmAck != mConfirmAck->isChecked()
 		||  mSavedFont       != mFontColourButton->font()
 		||  mSavedFgColour   != mFontColourButton->fgColour()
-		||  mSavedBgColour   != mBgColourChoose->color()
+		||  mSavedBgColour   != (mFileRadio->isOn() ? mBgColourButton->colour() : mFontColourButton->bgColour())
 		||  mSavedReminder   != mReminder->minutes()
 		||  mSavedOnceOnly   != mReminder->isOnceOnly()
 		||  mSavedAutoClose  != mLateCancel->isAutoClose())
@@ -1214,7 +1173,8 @@ void EditAlarmDlg::setEvent(KAEvent& event, const QString& text, bool trial)
 			dt = QDateTime(QDate(2000,1,1), mTemplateTime->time());
 	}
 	KAEvent::Action type = getAlarmType();
-	event.set(dt, text, mBgColourChoose->color(), mFontColourButton->fgColour(), mFontColourButton->font(),
+	event.set(dt, text, (mFileRadio->isOn() ? mBgColourButton->colour() : mFontColourButton->bgColour()),
+	          mFontColourButton->fgColour(), mFontColourButton->font(),
 	          type, (trial ? 0 : mLateCancel->minutes()), getAlarmFlags());
 	switch (type)
 	{
@@ -1236,9 +1196,7 @@ void EditAlarmDlg::setEvent(KAEvent& event, const QString& text, bool trial)
 		}
 		case KAEvent::EMAIL:
 		{
-			QString from;
-			if (mEmailFromList)
-				from = mEmailFromList->currentIdentityName();
+			uint from = mEmailFromList ? mEmailFromList->currentIdentity() : 0;
 			event.setEmail(from, mEmailAddresses, mEmailSubjectEdit->text(), mEmailAttachments);
 			break;
 		}
@@ -1254,6 +1212,15 @@ void EditAlarmDlg::setEvent(KAEvent& event, const QString& text, bool trial)
 		if (mRecurrenceEdit->repeatType() != RecurrenceEdit::NO_RECUR)
 		{
 			mRecurrenceEdit->updateEvent(event, !mTemplate);
+			QDateTime now = QDateTime::currentDateTime();
+			bool dateOnly = mAlarmDateTime.isDateOnly();
+			if (dateOnly  &&  mAlarmDateTime.date() < now.date()
+			||  !dateOnly  &&  mAlarmDateTime.rawDateTime() < now)
+			{
+				// A timed recurrence has an entered start date which has
+				// already expired, so we must adjust the next repetition.
+				event.setNextOccurrence(now);
+			}
 			mAlarmDateTime = event.startDateTime();
 			if (mDeferDateTime.isValid()  &&  mDeferDateTime < mAlarmDateTime)
 			{
@@ -1275,8 +1242,6 @@ void EditAlarmDlg::setEvent(KAEvent& event, const QString& text, bool trial)
 					event.defer(mDeferDateTime, deferReminder, false);
 			}
 		}
-		if (mSimpleRepetition->count())
-			event.setRepetition(mSimpleRepetition->interval(), mSimpleRepetition->count());
 		if (mTemplate)
 		{
 			int afterTime = mTemplateDefaultTime->isOn() ? 0
@@ -1376,7 +1341,6 @@ void EditAlarmDlg::slotOk()
 	&&  mTabs->currentPageIndex() == mRecurPageIndex  &&  recurType == RecurrenceEdit::AT_LOGIN)
 		mTimeWidget->setDateTime(mRecurrenceEdit->endDateTime());
 	bool timedRecurrence = mRecurrenceEdit->isTimedRepeatType();    // does it recur other than at login?
-	bool repeated = mSimpleRepetition->count();
 	if (mTemplate)
 	{
 		// Check that the template name is not blank and is unique
@@ -1400,7 +1364,7 @@ void EditAlarmDlg::slotOk()
 	else
 	{
 		QWidget* errWidget;
-		mAlarmDateTime = mTimeWidget->getDateTime(0, !(timedRecurrence || repeated), false, &errWidget);
+		mAlarmDateTime = mTimeWidget->getDateTime(0, !timedRecurrence, false, &errWidget);
 		if (errWidget)
 		{
 			// It's more than just an existing deferral being changed, so the time matters
@@ -1446,58 +1410,45 @@ void EditAlarmDlg::slotOk()
 			return;
 		}
 	}
-	int longestRecurInterval = -1;
 	if (recurType != RecurrenceEdit::NO_RECUR)
 	{
+		KAEvent recurEvent;
+		int longestRecurInterval = -1;
 		int reminder = mReminder->minutes();
-		if (reminder)
+		if (reminder  &&  !mReminder->isOnceOnly())
 		{
-			KAEvent event;
-			mRecurrenceEdit->updateEvent(event, false);
-			if (!mReminder->isOnceOnly())
+			mRecurrenceEdit->updateEvent(recurEvent, false);
+			longestRecurInterval = recurEvent.longestRecurrenceInterval();
+			if (longestRecurInterval  &&  reminder >= longestRecurInterval)
 			{
-				longestRecurInterval = event.longestRecurrenceInterval();
-				if (longestRecurInterval  &&  reminder >= longestRecurInterval)
-				{
-					mTabs->setCurrentPage(mMainPageIndex);
-					mReminder->setFocusOnCount();
-					KMessageBox::sorry(this, i18n("Reminder period must be less than the recurrence interval, unless '%1' is checked."
-					                             ).arg(Reminder::i18n_first_recurrence_only()));
-					return;
-				}
+				mTabs->setCurrentPage(mMainPageIndex);
+				mReminder->setFocusOnCount();
+				KMessageBox::sorry(this, i18n("Reminder period must be less than the recurrence interval, unless '%1' is checked."
+				                             ).arg(Reminder::i18n_first_recurrence_only()));
+				return;
 			}
 		}
-	}
-	if (mSimpleRepetition->count())
-	{
-		switch (recurType)
+		if (mRecurrenceEdit->subRepeatCount())
 		{
-			case RecurrenceEdit::AT_LOGIN:    // alarm repeat not allowed
-				mSimpleRepetition->set(0, 0);
-				break;
-			default:          // repeat duration must be less than recurrence interval
-				if (longestRecurInterval < 0)
-				{
-					KAEvent event;
-					mRecurrenceEdit->updateEvent(event, false);
-					longestRecurInterval = event.longestRecurrenceInterval();
-				}
-				if (mSimpleRepetition->count() * mSimpleRepetition->interval() >= longestRecurInterval - mReminder->minutes())
-				{
-					KMessageBox::sorry(this, i18n("Simple alarm repetition duration must be less than the recurrence interval minus any reminder period"));
-					mSimpleRepetition->activate();   // display the alarm repetition dialog again
-					return;
-				}
-				// fall through to NO_RECUR
-			case RecurrenceEdit::NO_RECUR:    // no restriction on repeat duration
-				if (mSimpleRepetition->interval() % 1440
-				&&  (mTemplate && mTemplateAnyTime->isOn()  ||  !mTemplate && mAlarmDateTime.isDateOnly()))
-				{
-					KMessageBox::sorry(this, i18n("Simple alarm repetition period must be in units of days or weeks for a date-only alarm"));
-					mSimpleRepetition->activate();   // display the alarm repetition dialog again
-					return;
-				}
-				break;
+			if (longestRecurInterval < 0)
+			{
+				mRecurrenceEdit->updateEvent(recurEvent, false);
+				longestRecurInterval = recurEvent.longestRecurrenceInterval();
+			}
+			if (longestRecurInterval > 0
+			&&  recurEvent.repeatInterval() * recurEvent.repeatCount() >= longestRecurInterval - reminder)
+			{
+				KMessageBox::sorry(this, i18n("The duration of a repetition within the recurrence must be less than the recurrence interval minus any reminder period"));
+				mRecurrenceEdit->activateSubRepetition();   // display the alarm repetition dialog again
+				return;
+			}
+			if (recurEvent.repeatInterval() % 1440
+			&&  (mTemplate && mTemplateAnyTime->isOn()  ||  !mTemplate && mAlarmDateTime.isDateOnly()))
+			{
+				KMessageBox::sorry(this, i18n("For a repetition within the recurrence, its period must be in units of days or weeks for a date-only alarm"));
+				mRecurrenceEdit->activateSubRepetition();   // display the alarm repetition dialog again
+				return;
+			}
 		}
 	}
 	if (checkText(mAlarmMessage))
@@ -1569,7 +1520,8 @@ void EditAlarmDlg::slotEditDeferral()
 	if (!mTimeWidget)
 		return;
 	bool limit = true;
-	int repeatCount = mSimpleRepetition->count();
+	int repeatInterval;
+	int repeatCount = mRecurrenceEdit->subRepeatCount(&repeatInterval);
 	DateTime start = mTimeWidget->getDateTime(0, !repeatCount, !mExpiredRecurrence);
 	if (!start.isValid())
 	{
@@ -1582,15 +1534,15 @@ void EditAlarmDlg::slotEditDeferral()
 	{
 		if (repeatCount  &&  start < now)
 		{
-			// Simple repetition - find the time of the next one
-			int interval = mSimpleRepetition->interval() * 60;
-			int repetition = (start.secsTo(now) + interval - 1) / interval;
+			// Sub-repetition - find the time of the next one
+			repeatInterval *= 60;
+			int repetition = (start.secsTo(now) + repeatInterval - 1) / repeatInterval;
 			if (repetition > repeatCount)
 			{
 				mTimeWidget->getDateTime();    // output the appropriate error message
 				return;
 			}
-			start = start.addSecs(repetition * interval);
+			start = start.addSecs(repetition * repeatInterval);
 		}
 	}
 
@@ -1695,43 +1647,30 @@ void EditAlarmDlg::slotRecurTypeChange(int repeatType)
 }
 
 /******************************************************************************
-*  Called when the recurrence frequency selection changes, or the simple
+*  Called when the recurrence frequency selection changes, or the sub-
 *  repetition interval changes.
 *  Updates the recurrence frequency text.
 */
 void EditAlarmDlg::slotRecurFrequencyChange()
 {
+	slotSetSubRepetition();
 	KAEvent event;
 	mRecurrenceEdit->updateEvent(event, false);
-	event.setRepetition(mSimpleRepetition->interval(), mSimpleRepetition->count());
-	mRecurrenceText->setText(recurText(event));
+	mTabs->setTabLabel(mTabs->page(mRecurPageIndex), recurText(event));
 }
 
 /******************************************************************************
-*  Called when the Simple Repetition button has been pressed to display the
-*  alarm repetition dialog.
+*  Called when the Repetition within Recurrence button has been pressed to
+*  display the sub-repetition dialog.
 *  Alarm repetition has the following restrictions:
 *  1) Not allowed for a repeat-at-login alarm
 *  2) For a date-only alarm, the repeat interval must be a whole number of days.
 *  3) The overall repeat duration must be less than the recurrence interval.
 */
-void EditAlarmDlg::slotSetSimpleRepetition()
+void EditAlarmDlg::slotSetSubRepetition()
 {
 	bool dateOnly = mTemplate ? mTemplateAnyTime->isOn() : mTimeWidget->anyTime();
-	int maxDuration;
-	switch (mRecurrenceEdit->repeatType())
-	{
-		case RecurrenceEdit::NO_RECUR:  maxDuration = -1;  break;  // no restriction on repeat duration
-		case RecurrenceEdit::AT_LOGIN:  maxDuration = 0;  break;   // alarm repeat not allowed
-		default:          // repeat duration must be less than recurrence interval
-		{
-			KAEvent event;
-			mRecurrenceEdit->updateEvent(event, false);
-			maxDuration = event.longestRecurrenceInterval() - mReminder->minutes() - 1;
-			break;
-		}
-	}
-	mSimpleRepetition->initialise(mSimpleRepetition->interval(), mSimpleRepetition->count(), dateOnly, maxDuration);
+	mRecurrenceEdit->setSubRepetition(mReminder->minutes(), dateOnly);
 }
 
 /******************************************************************************
@@ -1834,6 +1773,7 @@ void EditAlarmDlg::slotAlarmTypeChanged(int)
 		mFilePadding->hide();
 		mTextMessageEdit->show();
 		mFontColourButton->show();
+		mBgColourBox->hide();
 		mSoundPicker->showSpeak(true);
 		mDisplayAlarmsFrame->show();
 		mCommandFrame->hide();
@@ -1850,6 +1790,7 @@ void EditAlarmDlg::slotAlarmTypeChanged(int)
 		mFileBox->show();
 		mFilePadding->show();
 		mFontColourButton->hide();
+		mBgColourBox->show();
 		mSoundPicker->showSpeak(false);
 		mDisplayAlarmsFrame->show();
 		mCommandFrame->hide();
@@ -1921,24 +1862,6 @@ void EditAlarmDlg::slotTemplateTimeType(int)
 	mTemplateTimeAfter->setEnabled(mTemplateUseTimeAfter->isOn());
 }
 
-/******************************************************************************
-*  Called when the a new background colour has been selected using the colour
-*  combo box.
-*/
-void EditAlarmDlg::slotBgColourSelected(const QColor& colour)
-{
-	mFontColourButton->setBgColour(colour);
-}
-
-/******************************************************************************
-*  Called when the a new font and colour have been selected using the font &
-*  colour pushbutton.
-*/
-void EditAlarmDlg::slotFontColourSelected()
-{
-	mBgColourChoose->setColour(mFontColourButton->bgColour());
-}
-
 /******************************************************************************
 *  Called when the "Any time" checkbox is toggled in the date/time widget.
 *  Sets the advance reminder and late cancel units to days if any time is checked.
@@ -2104,7 +2027,7 @@ bool EditAlarmDlg::checkText(QString& result, bool showErrorMessage) const
 = Provides KDE 2 compatibility.
 =============================================================================*/
 TextEdit::TextEdit(QWidget* parent, const char* name)
-	: QTextEdit(parent, name)
+	: KTextEdit(parent, name)
 {
 	QSize tsize = sizeHint();
 	tsize.setHeight(fontMetrics().lineSpacing()*13/4 + 2*frameWidth());
@@ -2115,5 +2038,5 @@ void TextEdit::dragEnterEvent(QDragEnterEvent* e)
 {
 	if (KCal::ICalDrag::canDecode(e))
 		e->accept(false);   // don't accept "text/calendar" objects
-	QTextEdit::dragEnterEvent(e);
+	KTextEdit::dragEnterEvent(e);
 }
