@@ -1,7 +1,7 @@
 /*
  *  editdlgprivate.h  -  private classes for editdlg.cpp
  *  Program:  kalarm
- *  Copyright (C) 2003 - 2005 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2003-2005,2008 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #ifndef EDITDLGPRIVATE_H
 #define EDITDLGPRIVATE_H
 
-#include <qtextedit.h>
+#include <ktextedit.h>
 
 
 class PageFrame : public QFrame
@@ -35,7 +35,7 @@ class PageFrame : public QFrame
 		void             shown();
 };
 
-class TextEdit : public QTextEdit
+class TextEdit : public KTextEdit
 {
 		Q_OBJECT
 	public:
