@@ -1,7 +1,7 @@
 /*
  *  fontcolour.cpp  -  font and colour chooser widget
  *  Program:  kalarm
- *  Copyright (C) 2001 - 2003, 2005 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2003,2005,2008 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -55,42 +55,39 @@ FontColourChooser::FontColourChooser(QWidget *parent, const char *name,
 		page = new QGroupBox(frameLabel, this);
 		topLayout->addWidget(page);
 		topLayout = new QVBoxLayout(page, KDialog::marginHint(), KDialog::spacingHint());
-		topLayout->addSpacing(fontMetrics().lineSpacing()/2);
+		topLayout->addSpacing(fontMetrics().height() - KDialog::marginHint() + KDialog::spacingHint());
 	}
+	QHBoxLayout* hlayout = new QHBoxLayout(topLayout);
+	QVBoxLayout* colourLayout = new QVBoxLayout(hlayout);
 	if (fg)
 	{
-		QBoxLayout* layout = new QHBoxLayout(topLayout);
 		QHBox* box = new QHBox(page);    // to group widgets for QWhatsThis text
-		box->setSpacing(KDialog::spacingHint());
-		layout->addWidget(box);
+		box->setSpacing(KDialog::spacingHint()/2);
+		colourLayout->addWidget(box);
 
 		QLabel* label = new QLabel(i18n("&Foreground color:"), box);
-		label->setMinimumSize(label->sizeHint());
+		box->setStretchFactor(new QWidget(box), 0);
 		mFgColourButton = new ColourCombo(box);
-		mFgColourButton->setMinimumSize(mFgColourButton->sizeHint());
 		connect(mFgColourButton, SIGNAL(activated(const QString&)), SLOT(setSampleColour()));
 		label->setBuddy(mFgColourButton);
 		QWhatsThis::add(box, i18n("Select the alarm message foreground color"));
-		layout->addStretch();
 	}
 
-	QBoxLayout* layout = new QHBoxLayout(topLayout);
 	QHBox* box = new QHBox(page);    // to group widgets for QWhatsThis text
-	box->setSpacing(KDialog::spacingHint());
-	layout->addWidget(box);
+	box->setSpacing(KDialog::spacingHint()/2);
+	colourLayout->addWidget(box);
 
 	QLabel* label = new QLabel(i18n("&Background color:"), box);
-	label->setMinimumSize(label->sizeHint());
+	box->setStretchFactor(new QWidget(box), 0);
 	mBgColourButton = new ColourCombo(box);
-	mBgColourButton->setMinimumSize(mBgColourButton->sizeHint());
 	connect(mBgColourButton, SIGNAL(activated(const QString&)), SLOT(setSampleColour()));
 	label->setBuddy(mBgColourButton);
 	QWhatsThis::add(box, i18n("Select the alarm message background color"));
-	layout->addStretch();
+	hlayout->addStretch();
 
 	if (editColours)
 	{
-		layout = new QHBoxLayout(topLayout);
+		QHBoxLayout* layout = new QHBoxLayout(topLayout);
 		QPushButton* button = new QPushButton(i18n("Add Co&lor..."), page);
 		button->setFixedSize(button->sizeHint());
 		connect(button, SIGNAL(clicked()), SLOT(slotAddColour()));
@@ -107,7 +104,7 @@ FontColourChooser::FontColourChooser(QWidget *parent, const char *name,
 
 	if (defaultFont)
 	{
-		layout = new QHBoxLayout(topLayout);
+		QHBoxLayout* layout = new QHBoxLayout(topLayout);
 		mDefaultFont = new CheckBox(i18n("Use &default font"), page);
 		mDefaultFont->setMinimumSize(mDefaultFont->sizeHint());
 		connect(mDefaultFont, SIGNAL(toggled(bool)), SLOT(slotDefaultFontToggled(bool)));
@@ -120,6 +117,10 @@ FontColourChooser::FontColourChooser(QWidget *parent, const char *name,
 		mDefaultFont = 0;
 
 	mFontChooser = new KFontChooser(page, name, onlyFixed, fontList, false, visibleListSize);
+	mFontChooser->installEventFilter(this);   // for read-only mode
+	const QObjectList* kids = mFontChooser->queryList();
+	for (QObjectList::ConstIterator it = kids->constBegin();  it != kids->constEnd();  ++it)
+		(*it)->installEventFilter(this);
 	topLayout->addWidget(mFontChooser);
 
 	slotDefaultFontToggled(false);
@@ -212,6 +213,25 @@ void FontColourChooser::setReadOnly(bool ro)
 	}
 }
 
+bool FontColourChooser::eventFilter(QObject*, QEvent* e)
+{
+	if (mReadOnly)
+	{
+		switch (e->type())
+		{
+			case QEvent::MouseButtonPress:
+			case QEvent::MouseButtonRelease:
+			case QEvent::MouseButtonDblClick:
+			case QEvent::KeyPress:
+			case QEvent::KeyRelease:
+				return true;   // prevent the event being handled
+			default:
+				break;
+		}
+	}
+	return false;
+}
+
 void FontColourChooser::slotDefaultFontToggled(bool on)
 {
 	mFontChooser->setEnabled(!on);
