@@ -1,7 +1,7 @@
 /*
  *  mainwindow.h  -  main application window
  *  Program:  kalarm
- *  Copyright © 2001-2007 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2007 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -53,7 +53,6 @@ class MainWindow : public MainWindowBase
 
 		static void        refresh();
 		static void        updateExpired();
-		static void        updateTimeColumns(bool oldTime, bool oldTimeTo);
 		static void        addEvent(const KAEvent&, MainWindow*);
 		static void        executeNew(MainWindow* w = 0, KAEvent::Action a = KAEvent::MESSAGE, const AlarmText& t = AlarmText())
 		                                      { executeNew(w, 0, a, t); }
@@ -69,10 +68,8 @@ class MainWindow : public MainWindowBase
 		static int         count()            { return mWindowList.count(); }
 
 		static QString i18n_a_ShowAlarmTimes();     // text of 'Show Alarm Times' checkbox, with 'A' shortcut
-		static QString i18n_t_ShowAlarmTime();      // text of 'Show alarm time' checkbox, with 'T' shortcut
 		static QString i18n_m_ShowAlarmTime();      // text of 'Show alarm time' checkbox, with 'M' shortcut
 		static QString i18n_o_ShowTimeToAlarms();   // text of 'Show Time to Alarms' checkbox, with 'O' shortcut
-		static QString i18n_n_ShowTimeToAlarm();    // text of 'Show time until alarm' checkbox, with 'N' shortcut
 		static QString i18n_l_ShowTimeToAlarm();    // text of 'Show time until alarm' checkbox, with 'L' shortcut
 		static QString i18n_ShowExpiredAlarms();    // plain text of 'Show Expired Alarms' action
 		static QString i18n_e_ShowExpiredAlarms();  // text of 'Show Expired Alarms' checkbox, with 'E' shortcut
@@ -115,7 +112,8 @@ class MainWindow : public MainWindowBase
 		void           slotQuit();
 		void           slotDeletion();
 		void           slotSelection();
-		void           slotMouseClicked(int button, QListViewItem* item, const QPoint&, int);
+		void           slotContextMenuRequested(QListViewItem*, const QPoint&, int);
+		void           slotMouseClicked(int button, QListViewItem*, const QPoint&, int);
 		void           slotDoubleClicked(QListViewItem*);
 		void           slotShowTime();
 		void           slotShowTimeTo();
