@@ -1,7 +1,7 @@
 /*
  *  messagewin.h  -  displays an alarm message
  *  Program:  kalarm
- *  Copyright © 2001-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2007 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@
 
 /** @file messagewin.h - displays an alarm message */
 
+#include <qmap.h>
+
 #include "mainwindowbase.h"
 #include "alarmevent.h"
 
@@ -92,8 +94,11 @@ class MessageWin : public MainWindowBase
 		void                displayComplete();
 		void                playAudio();
 		void                setDeferralLimit(const KAEvent&);
+		bool                haveErrorMessage(unsigned msg) const;
+		void                clearErrorMessage(unsigned msg) const;
 
 		static QValueList<MessageWin*> mWindowList;  // list of existing message windows
+		static QMap<QString, unsigned> mErrorMessages;  // error messages currently displayed, by event ID
 		// Properties needed by readProperties()
 		QString             mMessage;
 		QFont               mFont;
@@ -154,6 +159,7 @@ class MessageWin : public MainWindowBase
 		bool                mPositioning;     // true when the window is being positioned initially
 		bool                mNoCloseConfirm;  // the Defer or Edit button is closing the dialog
 		bool                mUsingKMix;       // master volume is being set using kmix
+		bool                mDisableDeferral; // true if past deferral limit, so don't enable Defer button
 };
 
 #endif // MESSAGEWIN_H
