@@ -1,7 +1,7 @@
 /*
  *  templatedlg.cpp  -  dialogue to create, edit and delete alarm templates
  *  Program:  kalarm
- *  Copyright (c) 2004-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2004-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -59,26 +59,22 @@ TemplateDlg::TemplateDlg(QWidget* parent, const char* name)
 
 	layout = new QVBoxLayout(topLayout);
 	QPushButton* button = new QPushButton(i18n("&New..."), topWidget);
-	button->setFixedSize(button->sizeHint());
 	connect(button, SIGNAL(clicked()), SLOT(slotNew()));
 	QWhatsThis::add(button, i18n("Create a new alarm template"));
 	layout->addWidget(button);
 
 	mEditButton = new QPushButton(i18n("&Edit..."), topWidget);
-	mEditButton->setFixedSize(mEditButton->sizeHint());
 	connect(mEditButton, SIGNAL(clicked()), SLOT(slotEdit()));
 	QWhatsThis::add(mEditButton, i18n("Edit the currently highlighted alarm template"));
 	layout->addWidget(mEditButton);
 
 	mCopyButton = new QPushButton(i18n("Co&py"), topWidget);
-	mCopyButton->setFixedSize(mCopyButton->sizeHint());
 	connect(mCopyButton, SIGNAL(clicked()), SLOT(slotCopy()));
 	QWhatsThis::add(mCopyButton,
 	      i18n("Create a new alarm template based on a copy of the currently highlighted template"));
 	layout->addWidget(mCopyButton);
 
 	mDeleteButton = new QPushButton(i18n("&Delete"), topWidget);
-	mDeleteButton->setFixedSize(mDeleteButton->sizeHint());
 	connect(mDeleteButton, SIGNAL(clicked()), SLOT(slotDelete()));
 	QWhatsThis::add(mDeleteButton, i18n("Delete the currently highlighted alarm template"));
 	layout->addWidget(mDeleteButton);
@@ -144,14 +140,14 @@ void TemplateDlg::slotCopy()
 */
 void TemplateDlg::createTemplate(const KAEvent* event, QWidget* parent, TemplateListView* view)
 {
-	EditAlarmDlg editDlg(true, i18n("New Alarm Template"), parent, "editDlg", event);
+	EditAlarmDlg editDlg(true, i18n("New Alarm Template"), parent, 0, event);
 	if (editDlg.exec() == QDialog::Accepted)
 	{
 		KAEvent event;
 		editDlg.getEvent(event);
 
 		// Add the template to the displayed lists and to the calendar file
-		KAlarm::addTemplate(event, view);
+		KAlarm::addTemplate(event, view, &editDlg);
 		Undo::saveAdd(event);
 	}
 }
@@ -166,7 +162,7 @@ void TemplateDlg::slotEdit()
 	if (item)
 	{
 		KAEvent event = item->event();
-		EditAlarmDlg editDlg(true, i18n("Edit Alarm Template"), this, "editDlg", &event);
+		EditAlarmDlg editDlg(true, i18n("Edit Alarm Template"), this, 0, &event);
 		if (editDlg.exec() == QDialog::Accepted)
 		{
 			KAEvent newEvent;
@@ -175,7 +171,7 @@ void TemplateDlg::slotEdit()
 			newEvent.setEventID(id);
 
 			// Update the event in the displays and in the calendar file
-			KAlarm::updateTemplate(newEvent, mTemplateList);
+			KAlarm::updateTemplate(newEvent, mTemplateList, &editDlg);
 			Undo::saveEdit(event, newEvent);
 		}
 	}
@@ -195,16 +191,29 @@ void TemplateDlg::slotDelete()
 		    != KMessageBox::Continue)
 		return;
 
+	int warnErr = 0;
+	KAlarm::UpdateStatus status = KAlarm::UPDATE_OK;
 	QValueList<KAEvent> events;
 	AlarmCalendar::templateCalendar()->startUpdate();    // prevent multiple saves of the calendar until we're finished
 	for (QValueList<EventListViewItemBase*>::Iterator it = items.begin();  it != items.end();  ++it)
 	{
 		TemplateListViewItem* item = (TemplateListViewItem*)(*it);
 		events.append(item->event());
-		KAlarm::deleteTemplate(item->event());
+		KAlarm::UpdateStatus st = KAlarm::deleteTemplate(item->event());
+		if (st != KAlarm::UPDATE_OK)
+		{
+			status = st;
+			++warnErr;
+		}
+	}
+	if (!AlarmCalendar::templateCalendar()->endUpdate())    // save the calendar now
+	{
+		status = KAlarm::SAVE_FAILED;
+		warnErr = items.count();
 	}
-	AlarmCalendar::templateCalendar()->endUpdate();    // save the calendar now
 	Undo::saveDeletes(events);
+	if (warnErr)
+		displayUpdateError(this, status, KAlarm::ERR_TEMPLATE, warnErr);
 }
 
 /******************************************************************************
