@@ -1,7 +1,7 @@
 /*
- *  undo.h  -  edit undo facility
+ *  undo.h  -  undo/redo facility
  *  Program:  kalarm
- *  (C) 2005 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright (C) 2005 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,15 +13,16 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef UNDO_H
 #define UNDO_H
 
-#ifdef UNDO_FEATURE
+/**  @file undo.h - undo/redo facility */
+
 #include <qvaluelist.h>
 #include <qstringlist.h>
 
@@ -36,23 +37,32 @@ class Undo : public QObject
 		enum Type { NONE, UNDO, REDO };
 
 		static Undo*       instance();
-		static void        saveAdd(const QString& eventID);
-		static void        saveEdit(const KAEvent& oldEvent, const QString& newEventID);
+		static void        saveAdd(const KAEvent&);
+		static void        saveEdit(const KAEvent& oldEvent, const KAEvent& newEvent);
 		static void        saveDelete(const KAEvent&);
 		static void        saveDeletes(const QValueList<KAEvent>&);
-		static QString     undo()             { return undo(mUndoList.begin(), UNDO); }
-		static QString     undo(int id)       { return undo(findItem(id, UNDO), UNDO); }
-		static QString     redo()             { return undo(mRedoList.begin(), REDO); }
-		static QString     redo(int id)       { return undo(findItem(id, REDO), REDO); }
+		static void        saveReactivate(const KAEvent&);
+		static void        saveReactivates(const QValueList<KAEvent>&);
+		static bool        undo(QWidget* parent, const QString& action)
+		                                      { return undo(mUndoList.begin(), UNDO, parent, action); }
+		static bool        undo(int id, QWidget* parent, const QString& action)
+		                                      { return undo(findItem(id, UNDO), UNDO, parent, action); }
+		static bool        redo(QWidget* parent, const QString& action)
+		                                      { return undo(mRedoList.begin(), REDO, parent, action); }
+		static bool        redo(int id, QWidget* parent, const QString& action)
+		                                      { return undo(findItem(id, REDO), REDO, parent, action); }
 		static void        clear();
 		static bool        haveUndo()         { return !mUndoList.isEmpty(); }
 		static bool        haveRedo()         { return !mRedoList.isEmpty(); }
-		static QString     description(Type);
+		static QString     actionText(Type);
+		static QString     actionText(Type, int id);
 		static QString     description(Type, int id);
-		static QString     tooltip(Type, int id);
 		static QValueList<int> ids(Type);
 		static void        emitChanged();
 
+		// Types for use by UndoItem class and its descendants
+		typedef QValueList<UndoItem*>  List;
+
 	signals:
 		void               changed(const QString& undo, const QString& redo);
 
@@ -63,12 +73,11 @@ class Undo : public QObject
 		static void        replace(UndoItem* old, UndoItem* New);
 
 	private:
-		typedef QValueList<UndoItem*>           List;
 		typedef QValueList<UndoItem*>::Iterator Iterator;
 
 		Undo(QObject* parent)  : QObject(parent) { }
 		static void        removeRedos(const QString& eventID);
-		static QString     undo(Iterator, Type);
+		static bool        undo(Iterator, Type, QWidget* parent, const QString& action);
 		static UndoItem*   getItem(int id, Type);
 		static Iterator    findItem(int id, Type);
 		void               emitChanged(const QString& undo, const QString& redo)
@@ -79,11 +88,6 @@ class Undo : public QObject
 		static List        mRedoList;     // edit history for redo, latest redo first
 
 	friend class UndoItem;
-	friend class UndoAdd;
-	friend class UndoEdit;
-	friend class UndoDelete;
-	friend class UndoDeletes;
 };
 
-#endif
 #endif // UNDO_H
