@@ -102,6 +102,16 @@ class KarmStorage
      */
     QString load(TaskView* taskview, const Preferences* preferences, QString fileName="" );
 
+    /*
+     * Return the name of the iCal file
+     */
+    QString icalfile();
+
+    /*
+     * Build up the taskview.
+     *
+     * This is needed if the iCal file has been modified
+     */
     QString buildTaskView(KCal::ResourceCalendar *rc, TaskView *view);
     
     /* Close calendar and clear view.  Release lock if holding one. */
@@ -150,7 +160,7 @@ class KarmStorage
      */
     QString report( TaskView *taskview, const ReportCriteria &rc );
 
-    /*
+    /**
      * Log the change in a task's time.
      *
      * We create an iCalendar event to store each change.  The event start
@@ -229,7 +239,7 @@ class KarmStorage
      *
      * @param task   The task the timer was stopped for.
      */
-    void stopTimer(const Task* task);
+    void stopTimer(const Task* task, QDateTime when=QDateTime::currentDateTime());
 
     /**
      * Log a new comment for this task.
