@@ -62,13 +62,13 @@ void Task::init( const QString& taskName, long minutes, long sessionTime,
 
   if (icons == 0) {
     icons = new QPtrVector<QPixmap>(8);
-    KIconLoader* kil = new KIconLoader("karm"); // always load icons from the KArm application
+    KIconLoader kil("karm"); // always load icons from the KArm application
     for (int i=0; i<8; i++)
     {
       QPixmap *icon = new QPixmap();
       QString name;
       name.sprintf("watch-%d.xpm",i);
-      *icon = kil->loadIcon( name, KIcon::User );
+      *icon = kil.loadIcon( name, KIcon::User );
       icons->insert(i,icon);
     }
   }
@@ -97,11 +97,11 @@ Task::~Task() {
 void Task::setRunning( bool on, KarmStorage* storage, QDateTime whenStarted, QDateTime whenStopped  )
 // Sets a task running or stopped. If the task is to be stopped, whenStarted is not evaluated.
 // on=true if the task shall be started on=false if the task shall be stopped
+// This is the back-end, the front-end is StartTimerFor()
 {
   kdDebug(5970) << "Entering Task::setRunning " << "on=" << on << "whenStarted=" << whenStarted << " whenStopped=" << whenStopped << endl;
   if ( on ) 
   {
-    if (isComplete()) return; // don't start if its marked complete
     if (!_timer->isActive()) 
     {
       _timer->start(1000);
