@@ -104,20 +104,6 @@ extern "C"
   KDE_EXPORT int kdemain (int argc, char **argv);
 }
 
-#ifdef HAVE_LIBSASL2
-static sasl_callback_t callbacks[] = {
-    { SASL_CB_ECHOPROMPT, NULL, NULL },
-    { SASL_CB_NOECHOPROMPT, NULL, NULL },
-    { SASL_CB_GETREALM, NULL, NULL },
-    { SASL_CB_USER, NULL, NULL },
-    { SASL_CB_AUTHNAME, NULL, NULL },
-    { SASL_CB_PASS, NULL, NULL },
-    { SASL_CB_GETOPT, NULL, NULL },
-    { SASL_CB_CANON_USER, NULL, NULL },
-    { SASL_CB_LIST_END, NULL, NULL }
-};
-#endif
-
 int
 kdemain (int argc, char **argv)
 {
@@ -131,7 +117,7 @@ kdemain (int argc, char **argv)
   }
 
 #ifdef HAVE_LIBSASL2
-  if ( sasl_client_init( callbacks ) != SASL_OK ) {
+  if ( sasl_client_init( NULL ) != SASL_OK ) {
     fprintf(stderr, "SASL library initialization failed!\n");
     ::exit (-1);
   }
@@ -327,7 +313,7 @@ IMAP4Protocol::get (const KURL & _url)
         cmd = sendCommand (imapCommand::clientFetch (aSequence, mySection));
         do
         {
-          while (!parseLoop ());
+          while (!parseLoop ()) ;
         }
         while (!cmd->isComplete ());
         completeQueue.removeRef (cmd);
@@ -346,7 +332,7 @@ IMAP4Protocol::get (const KURL & _url)
       aUpper = aSection.upper();
       do
       {
-        while (!(res = parseLoop()));
+        while (!(res = parseLoop())) ;
         if (res == -1) break;
 
         mailHeader *lastone = 0;
@@ -609,7 +595,7 @@ IMAP4Protocol::listDir (const KURL & _url)
         imapCache *cache;
         do
         {
-          while (!parseLoop ());
+          while (!parseLoop ()) ;
 
           cache = getLastHandled ();
 
@@ -838,7 +824,7 @@ IMAP4Protocol::put (const KURL & _url, int, bool, bool)
 
     imapCommand *cmd =
       sendCommand (imapCommand::clientAppend (aBox, aSection, length));
-    while (!parseLoop ());
+    while (!parseLoop ()) ;
 
     // see if server is waiting
     if (!cmd->isComplete () && !getContinuation ().isEmpty ())
@@ -1220,6 +1206,7 @@ IMAP4Protocol::del (const KURL & _url, bool isFile)
  * AnnotateMore commands: data = 'M' + 'G'et/'S'et + URL + entry + command-dependent args
  * Search: data = 'E' + URL (KURL)
  * Quota commands: data = 'Q' + 'R'oot/'G'et/'S'et + URL + entry + command-dependent args
+ * Custom command: data = 'X' + 'N'ormal/'E'xtended + command + command-dependent args
  */
 void
 IMAP4Protocol::special (const QByteArray & aData)
@@ -1360,9 +1347,16 @@ IMAP4Protocol::special (const QByteArray & aData)
     QString aBox, aSequence, aLType, aSection, aValidity, aDelimiter, aInfo;
     parseURL (_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter, aInfo);
     if (!assureBox(aBox, false)) return;
+
+    // make sure we only touch flags we know
+    QCString knownFlags = "\\SEEN \\ANSWERED \\FLAGGED \\DRAFT";
+    const imapInfo info = getSelected();
+    if ( info.permanentFlagsAvailable() && (info.permanentFlags() & imapInfo::User) ) {
+      knownFlags += " KMAILFORWARDED KMAILTODO KMAILWATCHED KMAILIGNORED $FORWARDED $TODO $WATCHED $IGNORED";
+    }
+
     imapCommand *cmd = doCommand (imapCommand::
-                                  clientStore (aSequence, "-FLAGS.SILENT",
-                                               "\\SEEN \\ANSWERED \\FLAGGED \\DRAFT"));
+                                  clientStore (aSequence, "-FLAGS.SILENT", knownFlags));
     if (cmd->result () != "OK")
     {
       completeQueue.removeRef (cmd);
@@ -1387,12 +1381,49 @@ IMAP4Protocol::special (const QByteArray & aData)
     finished();
     break;
   }
+  case 's':
+  {
+    // seen
+    KURL _url;
+    bool seen;
+    QCString newFlags;
+    stream >> _url >> seen;
+
+    QString aBox, aSequence, aLType, aSection, aValidity, aDelimiter, aInfo;
+    parseURL (_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter, aInfo);
+    if ( !assureBox(aBox, true) ) // read-only because changing SEEN should be possible even then
+      return;
+
+    imapCommand *cmd;
+    if ( seen )
+      cmd = doCommand( imapCommand::clientStore( aSequence, "+FLAGS.SILENT", "\\SEEN" ) );
+    else
+      cmd = doCommand( imapCommand::clientStore( aSequence, "-FLAGS.SILENT", "\\SEEN" ) );
+
+    if (cmd->result () != "OK")
+    {
+      completeQueue.removeRef (cmd);
+      error(ERR_COULD_NOT_WRITE, i18n("Changing the flags of message %1 "
+                                      "failed.").arg(_url.prettyURL()));
+      return;
+    }
+    completeQueue.removeRef (cmd);
+    finished();
+    break;
+  }
+
   case 'E':
   {
     // search
     specialSearchCommand( stream );
     break;
   }
+  case 'X':
+  {
+    // custom command
+    specialCustomCommand( stream );
+    break;
+  }
   default:
     kdWarning(7116) << "Unknown command in special(): " << tmp << endl;
     error( ERR_UNSUPPORTED_ACTION, QString(QChar(tmp)) );
@@ -1462,10 +1493,10 @@ IMAP4Protocol::specialACLCommand( int command, QDataStream& stream )
     }
     // Returning information to the application from a special() command isn't easy.
     // I'm reusing the infoMessage trick seen above (for capabilities), but this
-    // limits me to a string instead of a stringlist. I'm using space as separator,
-    // since I don't think it can be used in login names.
+    // limits me to a string instead of a stringlist. Using DQUOTE as separator,
+    // because it's forbidden in userids by rfc3501
     kdDebug(7116) << getResults() << endl;
-    infoMessage(getResults().join( " " ));
+    infoMessage(getResults().join( "\"" ));
     finished();
     break;
   }
@@ -1530,6 +1561,85 @@ IMAP4Protocol::specialSearchCommand( QDataStream& stream )
   finished();
 }
 
+void
+IMAP4Protocol::specialCustomCommand( QDataStream& stream )
+{
+  kdDebug(7116) << "IMAP4Protocol::specialCustomCommand" << endl;
+
+  QString command, arguments;
+  int type;
+  stream >> type;
+  stream >> command >> arguments;
+
+  /**
+   * In 'normal' mode we send the command with all information in one go
+   * and retrieve the result.
+   */
+  if ( type == 'N' ) {
+    kdDebug(7116) << "IMAP4Protocol::specialCustomCommand: normal mode" << endl;
+    imapCommand *cmd = doCommand (imapCommand::clientCustom( command, arguments ));
+    if (cmd->result () != "OK")
+    {
+      error(ERR_SLAVE_DEFINED, i18n("Custom command %1:%2 "
+            "failed. The server returned: %3")
+          .arg(command)
+          .arg(arguments)
+          .arg(cmd->resultInfo()));
+      return;
+    }
+    completeQueue.removeRef(cmd);
+    QStringList lst = getResults();
+    kdDebug(7116) << "IMAP4Protocol::specialCustomCommand '" << command <<
+      ":" << arguments <<
+      "' returns " << lst << endl;
+    infoMessage( lst.join( " " ) );
+
+    finished();
+  } else
+  /**
+   * In 'extended' mode we send a first header and push the data of the request in
+   * streaming mode.
+   */
+  if ( type == 'E' ) {
+    kdDebug(7116) << "IMAP4Protocol::specialCustomCommand: extended mode" << endl;
+    imapCommand *cmd = sendCommand (imapCommand::clientCustom( command, QString() ));
+    while ( !parseLoop () ) ;
+
+    // see if server is waiting
+    if (!cmd->isComplete () && !getContinuation ().isEmpty ())
+    {
+      const QByteArray buffer = arguments.utf8();
+
+      // send data to server
+      bool sendOk = (write (buffer.data (), buffer.size ()) == (ssize_t)buffer.size ());
+      processedSize( buffer.size() );
+
+      if ( !sendOk ) {
+        error ( ERR_CONNECTION_BROKEN, myHost );
+        completeQueue.removeRef ( cmd );
+        setState(ISTATE_CONNECT);
+        closeConnection();
+        return;
+      }
+    }
+    parseWriteLine ("");
+
+    do
+    {
+      while (!parseLoop ()) ;
+    }
+    while (!cmd->isComplete ());
+
+    completeQueue.removeRef (cmd);
+
+    QStringList lst = getResults();
+    kdDebug(7116) << "IMAP4Protocol::specialCustomCommand: returns " << lst << endl;
+    infoMessage( lst.join( " " ) );
+
+    finished ();
+  }
+}
+
 void
 IMAP4Protocol::specialAnnotateMoreCommand( int command, QDataStream& stream )
 {
@@ -1922,7 +2032,7 @@ bool IMAP4Protocol::makeLogin ()
     imapCommand *cmd;
 
     unhandled.clear ();
-    if (!alreadyConnected) while (!parseLoop ());    //get greeting
+    if (!alreadyConnected) while (!parseLoop ()) ;    //get greeting
     QString greeting;
     if (!unhandled.isEmpty()) greeting = unhandled.first().stripWhiteSpace();
     unhandled.clear ();       //get rid of it
