@@ -220,6 +220,16 @@ ulong imapInfo::_flags (const QCString & inFlags)
       flags ^= Recent;
     else if (0 != entry.contains ("\\*"))
       flags ^= User;
+
+    // non standard kmail falgs
+    else if ( entry.contains( "KMAILFORWARDED" ) || entry.contains( "$FORWARDED" ) )
+      flags = flags | Forwarded;
+    else if ( entry.contains( "KMAILTODO" ) || entry.contains( "$TODO" ) )
+      flags = flags | Todo;
+    else if ( entry.contains( "KMAILWATCHED" ) || entry.contains( "$WATCHED" ) )
+      flags = flags | Watched;
+    else if ( entry.contains( "KMAILIGNORED" ) || entry.contains( "$IGNORED" ) )
+      flags = flags | Ignored;
   }
 
   return flags;
