@@ -36,7 +36,7 @@ class ConfigGuiPalm : public ConfigGui
     ConfigGuiPalm( const QSync::Member &, QWidget *parent );
 
     void load( const QString &xml );
-    QString save();
+    QString save() const;
 
   private:
     void initGUI();
