@@ -173,11 +173,11 @@ void AntiSpamWizard::accept()
         pipeFilterPattern->setName( uniqueNameFor( (*it).getFilterName() ) );
         pipeFilterPattern->append( KMSearchRule::createInstance( "<size>",
                                    KMSearchRule::FuncIsGreaterOrEqual, "0" ) );
-        pipeFilter->setApplyOnOutbound( FALSE);
+        pipeFilter->setApplyOnOutbound( false);
         pipeFilter->setApplyOnInbound();
         pipeFilter->setApplyOnExplicit();
-        pipeFilter->setStopProcessingHere( FALSE );
-        pipeFilter->setConfigureShortcut( FALSE );
+        pipeFilter->setStopProcessingHere( false );
+        pipeFilter->setConfigureShortcut( false );
 
         filterList.append( pipeFilter );
       }
@@ -218,11 +218,11 @@ void AntiSpamWizard::accept()
           }
         }
       }
-      virusFilter->setApplyOnOutbound( FALSE);
+      virusFilter->setApplyOnOutbound( false);
       virusFilter->setApplyOnInbound();
       virusFilter->setApplyOnExplicit();
-      virusFilter->setStopProcessingHere( TRUE );
-      virusFilter->setConfigureShortcut( FALSE );
+      virusFilter->setStopProcessingHere( true );
+      virusFilter->setConfigureShortcut( false );
 
       filterList.append( virusFilter );
     }
@@ -252,11 +252,11 @@ void AntiSpamWizard::accept()
           pipeFilterPattern->setName( uniqueNameFor( (*it).getFilterName() ) );
         pipeFilterPattern->append( KMSearchRule::createInstance( "<size>",
                                    KMSearchRule::FuncIsLessOrEqual, "256000" ) );
-        pipeFilter->setApplyOnOutbound( FALSE);
+        pipeFilter->setApplyOnOutbound( false);
         pipeFilter->setApplyOnInbound();
         pipeFilter->setApplyOnExplicit();
-        pipeFilter->setStopProcessingHere( FALSE );
-        pipeFilter->setConfigureShortcut( FALSE );
+        pipeFilter->setStopProcessingHere( false );
+        pipeFilter->setConfigureShortcut( false );
 
         filterList.append( pipeFilter );
       }
@@ -304,11 +304,11 @@ void AntiSpamWizard::accept()
           }
       }
     }
-    spamFilter->setApplyOnOutbound( FALSE);
+    spamFilter->setApplyOnOutbound( false);
     spamFilter->setApplyOnInbound();
     spamFilter->setApplyOnExplicit();
-    spamFilter->setStopProcessingHere( TRUE );
-    spamFilter->setConfigureShortcut( FALSE );
+    spamFilter->setStopProcessingHere( true );
+    spamFilter->setConfigureShortcut( false );
     filterList.append( spamFilter );
 
     if ( mSpamRulesPage->moveUnsureSelected() )
@@ -346,11 +346,11 @@ void AntiSpamWizard::accept()
             }
         }
       }
-      unsureFilter->setApplyOnOutbound( FALSE);
+      unsureFilter->setApplyOnOutbound( false);
       unsureFilter->setApplyOnInbound();
       unsureFilter->setApplyOnExplicit();
-      unsureFilter->setStopProcessingHere( TRUE );
-      unsureFilter->setConfigureShortcut( FALSE );
+      unsureFilter->setStopProcessingHere( true );
+      unsureFilter->setConfigureShortcut( false );
 
       if ( atLeastOneUnsurePattern )
         filterList.append( unsureFilter );
@@ -389,12 +389,12 @@ void AntiSpamWizard::accept()
       classSpamFilterPattern->setName( uniqueNameFor( i18n( "Classify as spam" ) ) );
     classSpamFilterPattern->append( KMSearchRule::createInstance( "<size>",
                                     KMSearchRule::FuncIsGreaterOrEqual, "0" ) );
-    classSpamFilter->setApplyOnOutbound( FALSE);
-    classSpamFilter->setApplyOnInbound( FALSE );
-    classSpamFilter->setApplyOnExplicit( FALSE );
-    classSpamFilter->setStopProcessingHere( TRUE );
-    classSpamFilter->setConfigureShortcut( TRUE );
-    classSpamFilter->setConfigureToolbar( TRUE );
+    classSpamFilter->setApplyOnOutbound( false);
+    classSpamFilter->setApplyOnInbound( false );
+    classSpamFilter->setApplyOnExplicit( false );
+    classSpamFilter->setStopProcessingHere( true );
+    classSpamFilter->setConfigureShortcut( true );
+    classSpamFilter->setConfigureToolbar( true );
     filterList.append( classSpamFilter );
 
     // Classify messages manually as not Spam / as Ham
@@ -421,12 +421,12 @@ void AntiSpamWizard::accept()
       classHamFilterPattern->setName( uniqueNameFor( i18n( "Classify as NOT spam" ) ) );
     classHamFilterPattern->append( KMSearchRule::createInstance( "<size>",
                                     KMSearchRule::FuncIsGreaterOrEqual, "0" ) );
-    classHamFilter->setApplyOnOutbound( FALSE);
-    classHamFilter->setApplyOnInbound( FALSE );
-    classHamFilter->setApplyOnExplicit( FALSE );
-    classHamFilter->setStopProcessingHere( TRUE );
-    classHamFilter->setConfigureShortcut( TRUE );
-    classHamFilter->setConfigureToolbar( TRUE );
+    classHamFilter->setApplyOnOutbound( false);
+    classHamFilter->setApplyOnInbound( false );
+    classHamFilter->setApplyOnExplicit( false );
+    classHamFilter->setStopProcessingHere( true );
+    classHamFilter->setConfigureShortcut( true );
+    classHamFilter->setConfigureToolbar( true );
     filterList.append( classHamFilter );
   }
 
@@ -435,7 +435,7 @@ void AntiSpamWizard::accept()
    * which will result in the filter list in kmmainwidget being
    * initialized. This should happend only once. */
   if ( !filterList.isEmpty() )
-    KMKernel::self()->filterMgr()->appendFilters( 
+    KMKernel::self()->filterMgr()->appendFilters(
           filterList, replaceExistingFilters );
 
   QDialog::accept();
@@ -632,8 +632,8 @@ const QString AntiSpamWizard::uniqueNameFor( const QString & name )
 }
 
 
-void AntiSpamWizard::sortFilterOnExistance( 
-        const QString & intendedFilterName, 
+void AntiSpamWizard::sortFilterOnExistance(
+        const QString & intendedFilterName,
         QString & newFilters, QString & replaceFilters )
 {
   if ( uniqueNameFor( intendedFilterName ) == intendedFilterName )
@@ -825,7 +825,7 @@ void AntiSpamWizard::ConfigReader::sortToolList()
 
 
 //---------------------------------------------------------------------------
-ASWizPage::ASWizPage( QWidget * parent, const char * name, 
+ASWizPage::ASWizPage( QWidget * parent, const char * name,
                       const QString *bannerName )
   : QWidget( parent, name )
 {
@@ -908,12 +908,12 @@ void ASWizInfoPage::addAvailableTool( const QString &visibleName )
 {
   QString listName = visibleName;
   mToolsList->insertItem( listName );
-  if ( !mToolsList->isVisible() ) 
+  if ( !mToolsList->isVisible() )
   {
     mToolsList->show();
     mToolsList->setSelected( 0, true );
     mSelectionHint->setText( i18n("<p>Please select the tools to be used "
-                                  "for the spam detection and go "
+                                  "for the detection and go "
                                   "to the next page.</p>") );
   }
 }
