@@ -33,6 +33,7 @@
 #include "callback.h"
 #include "kmkernel.h"
 #include "kmmessage.h"
+#include "kmmsgpart.h"
 #include <libemailfunctions/email.h>
 #include <libkpimidentities/identity.h>
 #include <libkpimidentities/identitymanager.h>
@@ -50,27 +51,43 @@
 using namespace KMail;
 
 
-Callback::Callback( KMMessage* msg, KMReaderWin* readerWin ) 
+Callback::Callback( KMMessage* msg, KMReaderWin* readerWin )
   : mMsg( msg ), mReaderWin( readerWin ), mReceiverSet( false )
 {
 }
 
-bool Callback::mailICal( const QString& to, const QString iCal,
-                         const QString& subject ) const
+bool Callback::mailICal( const QString& to, const QString &iCal,
+                         const QString& subject, const QString &status,
+                         bool delMessage ) const
 {
   kdDebug(5006) << "Mailing message:\n" << iCal << endl;
 
   KMMessage *msg = new KMMessage;
   msg->initHeader();
-  msg->setHeaderField( "Content-Type",
-                       "text/calendar; method=reply; charset=\"utf-8\"" );
   msg->setSubject( subject );
+  if ( GlobalSettings::self()->exchangeCompatibleInvitations() ) {
+    if ( status == QString("cancel") )
+      msg->setSubject( QString("Declined: %1").arg(subject).replace("Answer: ","") );
+    else if ( status == QString("tentative") )
+      msg->setSubject(QString("Tentative: %1").arg(subject).replace("Answer: ","") );
+    else if ( status == QString("accepted") )
+      msg->setSubject( QString("Accepted: %1").arg(subject).replace("Answer: ","") );
+    else if ( status == QString("delegated") )
+      msg->setSubject( QString("Delegated: %1").arg(subject).replace("Answer: ","") );
+  }
   msg->setTo( to );
-  msg->setBody( iCal.utf8() );
   msg->setFrom( receiver() );
-  /* We want the triggering mail to be moved to the trash once this one
-   * has been sent successfully. Set a link header which accomplishes that. */
-  msg->link( mMsg, KMMsgStatusDeleted );
+
+  if ( !GlobalSettings::self()->exchangeCompatibleInvitations() ) {
+    msg->setHeaderField( "Content-Type",
+                         "text/calendar; method=reply; charset=\"utf-8\"" );
+    msg->setBody( iCal.utf8() );
+  }
+
+  if ( delMessage && deleteInvitationAfterReply() )
+    /* We want the triggering mail to be moved to the trash once this one
+    * has been sent successfully. Set a link header which accomplishes that. */
+    msg->link( mMsg, KMMsgStatusDeleted );
 
   // Outlook will only understand the reply if the From: header is the
   // same as the To: header of the invitation message.
@@ -79,20 +96,36 @@ bool Callback::mailICal( const QString& to, const QString iCal,
     // Try and match the receiver with an identity
     const KPIM::Identity& identity =
       kmkernel->identityManager()->identityForAddress( receiver() );
-    if( identity != KPIM::Identity::null() )
+    if( identity != KPIM::Identity::null() ) {
       // Identity found. Use this
       msg->setFrom( identity.fullEmailAddr() );
       msg->setHeaderField("X-KMail-Identity", QString::number( identity.uoid() ));
-      // Remove BCC from identity on ical invitations (https://intevation.de/roundup/kolab/issue474)
-      msg->setBcc( "" );
+    }
+    // Remove BCC from identity on ical invitations (https://intevation.de/roundup/kolab/issue474)
+    msg->setBcc( "" );
   }
 
   KMail::Composer * cWin = KMail::makeComposer();
   cWin->setMsg( msg, false /* mayAutoSign */ );
   // cWin->setCharset( "", true );
-  cWin->slotWordWrapToggled( false );
+  cWin->disableWordWrap();
   cWin->setSigningAndEncryptionDisabled( true );
 
+  if( GlobalSettings::self()->exchangeCompatibleInvitations() ) {
+    // For Exchange, send ical as attachment, with proper
+    // parameters
+    msg->setSubject( status );
+    msg->setCharset( "utf-8" );
+    KMMessagePart *msgPart = new KMMessagePart;
+    msgPart->setName( "cal.ics" );
+    // msgPart->setCteStr( attachCte ); // "base64" ?
+    msgPart->setBodyEncoded( iCal.utf8() );
+    msgPart->setTypeStr( "text" );
+    msgPart->setSubtypeStr( "calendar" );
+    msgPart->setParameter( "method", "reply" );
+    cWin->addAttach( msgPart );
+  }
+
   if ( options.readBoolEntry( "AutomaticSending", true ) ) {
     cWin->setAutoDeleteWindow(  true );
     cWin->slotSendNow();
@@ -138,6 +171,7 @@ QString Callback::receiver() const
           "receiver of this message,<br>please "
           "choose which of the following addresses "
           "is yours, if any:");
+      addrs += kmkernel->identityManager()->allEmails();
     } else {
       selectMessage = i18n("<qt>Several of your identities match the "
           "receiver of this message,<br>please "
@@ -148,7 +182,7 @@ QString Callback::receiver() const
     mReceiver =
       KInputDialog::getItem( i18n( "Select Address" ),
           selectMessage,
-          addrs, 0, FALSE, &ok, kmkernel->mainWin() );
+          addrs+ccaddrs, 0, FALSE, &ok, kmkernel->mainWin() );
     if( !ok )
       mReceiver = QString::null;
   }
@@ -162,3 +196,24 @@ void Callback::closeIfSecondaryWindow() const
   if ( window )
     window->close();
 }
+
+bool Callback::askForComment( KCal::Attendee::PartStat status ) const
+{
+    if ( ( status != KCal::Attendee::Accepted
+            && GlobalSettings::self()->askForCommentWhenReactingToInvitation()
+            == GlobalSettings:: EnumAskForCommentWhenReactingToInvitation::AskForAllButAcceptance )
+        || GlobalSettings::self()->askForCommentWhenReactingToInvitation()
+        == GlobalSettings:: EnumAskForCommentWhenReactingToInvitation::AlwaysAsk )
+        return true;
+    return false;
+}
+
+bool Callback::deleteInvitationAfterReply() const
+{
+    return GlobalSettings::self()->deleteInvitationEmailsAfterSendingReply();
+}
+
+QString Callback::sender() const
+{
+  return mMsg->from();
+}
