@@ -45,6 +45,19 @@ class QPoint;
 class ComposerCryptoConfiguration;
 class WarningConfiguration;
 class SMimeConfiguration;
+class TemplatesConfiguration;
+class CustomTemplates;
+class QGroupBox;
+class QVGroupBox;
+#include <qdict.h>
+class QLineEdit;
+class KMMsgTagDesc;
+class KListBox;
+class KColorCombo;
+class KFontRequester;
+class KIconButton;
+class KKeyButton;
+class QSpinBox;
 
 namespace Kpgp {
   class Config;
@@ -337,6 +350,7 @@ class AccountsPageReceivingTab : public ConfigModuleTab {
   Q_OBJECT
 public:
   AccountsPageReceivingTab( QWidget * parent=0, const char * name=0 );
+  ~AccountsPageReceivingTab();
   QString helpAnchor() const;
   void save();
 
@@ -372,7 +386,7 @@ private:
     QGuardedPtr< KMAccount > oldAccount;
     QGuardedPtr< KMAccount > newAccount;
   };
-  // ### make this a qptrlist:
+  // ### make this value-based:
   QValueList< ModifiedAccountsType* >  mModifiedAccounts;
 };
 
@@ -448,6 +462,7 @@ private:
   QCheckBox    *mCustomColorCheck;
   ColorListBox *mColorList;
   QCheckBox    *mRecycleColorCheck;
+  QSpinBox     *mCloseToQuotaThreshold;
 };
 
 class AppearancePageLayoutTab : public ConfigModuleTab {
@@ -469,6 +484,8 @@ private: // data
   QButtonGroup *mMIMETreeLocationGroup;
   QButtonGroup *mMIMETreeModeGroup;
   QButtonGroup *mReaderWindowModeGroup;
+  QCheckBox *mFavoriteFolderViewCB;
+  QCheckBox *mFolderQuickSearchCB;
 };
 
 class AppearancePageHeadersTab : public ConfigModuleTab {
@@ -488,6 +505,7 @@ private: // methods
   void setDateDisplay( int id, const QString & format );
 
 private: // data
+  QCheckBox    *mShowQuickSearch;
   QCheckBox    *mMessageSizeCheck;
   QCheckBox    *mAttachmentCheck;
   QCheckBox    *mNestedMessagesCheck;
@@ -591,6 +609,7 @@ private:
 
 private:
   QCheckBox     *mAutoAppSignFileCheck;
+  QCheckBox     *mTopQuoteCheck;
   QCheckBox     *mSmartQuoteCheck;
   QCheckBox     *mAutoRequestMDNCheck;
   QCheckBox	*mShowRecentAddressesInComposer;
@@ -632,6 +651,40 @@ private:
   LanguageItemList mLanguageList;
 };
 
+class ComposerPageTemplatesTab : public ConfigModuleTab {
+  Q_OBJECT
+public:
+  ComposerPageTemplatesTab( QWidget * parent=0, const char * name=0 );
+  QString helpAnchor() const;
+
+  void save();
+
+private slots:
+
+private:
+  virtual void doLoadFromGlobalSettings();
+
+private:
+    TemplatesConfiguration* mWidget;
+};
+
+class ComposerPageCustomTemplatesTab : public ConfigModuleTab {
+  Q_OBJECT
+public:
+  ComposerPageCustomTemplatesTab( QWidget * parent=0, const char * name=0 );
+  QString helpAnchor() const;
+
+  void save();
+
+private slots:
+
+private:
+  virtual void doLoadFromGlobalSettings();
+
+private:
+    CustomTemplates* mWidget;
+};
+
 class ComposerPageSubjectTab : public ConfigModuleTab {
   Q_OBJECT
 public:
@@ -734,6 +787,8 @@ public:
   // hrmpf. moc doesn't like nested classes with slots/signals...:
   typedef ComposerPageGeneralTab GeneralTab;
   typedef ComposerPagePhrasesTab PhrasesTab;
+  typedef ComposerPageTemplatesTab TemplatesTab;
+  typedef ComposerPageCustomTemplatesTab CustomTemplatesTab;
   typedef ComposerPageSubjectTab SubjectTab;
   typedef ComposerPageCharsetTab CharsetTab;
   typedef ComposerPageHeadersTab HeadersTab;
@@ -742,6 +797,8 @@ public:
 private:
   GeneralTab  *mGeneralTab;
   PhrasesTab  *mPhrasesTab;
+  TemplatesTab  *mTemplatesTab;
+  CustomTemplatesTab  *mCustomTemplatesTab;
   SubjectTab  *mSubjectTab;
   CharsetTab  *mCharsetTab;
   HeadersTab  *mHeadersTab;
@@ -775,6 +832,7 @@ private:
   QButtonGroup *mMDNGroup;
   QButtonGroup *mOrigQuoteGroup;
   QCheckBox    *mAutomaticallyImportAttachedKeysCheck;
+  QCheckBox    *mAlwaysDecrypt;
 };
 
 
@@ -922,6 +980,7 @@ private:
   KIntSpinBox  *mDelayedMarkTime;
   QCheckBox    *mShowPopupAfterDnD;
   KMail::FolderRequester *mOnStartupOpenFolder;
+  QComboBox    *mQuotaCmbBox;
 };
 
 class MiscPageGroupwareTab : public ConfigModuleTab  {
@@ -954,12 +1013,13 @@ private:
   KMail::AccountComboBox* mAccountCombo; // in the widgetstack
 
   QCheckBox* mHideGroupwareFolders;
-  QCheckBox* mAutoResCB;
-  QCheckBox* mAutoDeclConflCB;
-  QCheckBox* mAutoDeclRecurCB;
+  QCheckBox* mOnlyShowGroupwareFolders;
+  QCheckBox* mSyncImmediately;
+  QCheckBox* mDeleteInvitations;
 
   QCheckBox* mLegacyMangleFromTo;
   QCheckBox* mLegacyBodyInvites;
+  QCheckBox* mExchangeCompatibleInvitations;
   QCheckBox* mAutomaticSending;
 };
 
