@@ -15,16 +15,23 @@
     
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
+#include <config.h> // for KDEPIM_NEW_DISTRLISTS
+
 #include "distributionlistdialog.h"
 
 #include <libemailfunctions/email.h>
+#include <kabc/resource.h>
 #include <kabc/stdaddressbook.h>
 #include <kabc/distributionlist.h>
 
+#ifdef KDEPIM_NEW_DISTRLISTS
+#include <libkdepim/distributionlist.h>
+#endif
+
 #include <klistview.h>
 #include <klocale.h>
 #include <kdebug.h>
@@ -127,7 +134,7 @@ void DistributionListDialog::setRecipients( const Recipient::List &recipients )
         if ( addressees.isEmpty() ) {
           KABC::Addressee a;
           a.setNameFromString( name );
-          a.insertEmail( name );
+          a.insertEmail( email );
           item->setTransientAddressee( a, email );
           item->setOn( true );
         } else {
@@ -146,7 +153,7 @@ void DistributionListDialog::slotUser1()
 {
   bool isEmpty = true;
 
-  KABC::StdAddressBook *ab = KABC::StdAddressBook::self( true );
+  KABC::AddressBook *ab = KABC::StdAddressBook::self( true );
 
   QListViewItem *i = mRecipientsList->firstChild();
   while( i ) {
@@ -166,8 +173,10 @@ void DistributionListDialog::slotUser1()
     return;
   }
 
+#ifndef KDEPIM_NEW_DISTRLISTS
   KABC::DistributionListManager manager( ab );
   manager.load();
+#endif
 
   QString name = mTitleEdit->text();
 
@@ -179,13 +188,40 @@ void DistributionListDialog::slotUser1()
       return;
   }
 
+#ifdef KDEPIM_NEW_DISTRLISTS
+  if ( !KPIM::DistributionList::findByName( ab, name ).isEmpty() ) {
+#else
   if ( manager.list( name ) ) {
+#endif
     KMessageBox::information( this,
       i18n( "<qt>Distribution list with the given name <b>%1</b> "
         "already exists. Please select a different name.</qt>" ).arg( name ) );
     return;
   }
 
+#ifdef KDEPIM_NEW_DISTRLISTS
+  KPIM::DistributionList dlist;
+  dlist.setName( name );
+
+  i = mRecipientsList->firstChild();
+  while( i ) {
+    DistributionListItem *item = static_cast<DistributionListItem *>( i );
+    if ( item->isOn() ) {
+      kdDebug() << "  " << item->addressee().fullEmail() << endl;
+      if ( item->isTransient() ) {
+        ab->insertAddressee( item->addressee() );
+      }
+      if ( item->email() == item->addressee().preferredEmail() ) {
+        dlist.insertEntry( item->addressee() );
+      } else {
+        dlist.insertEntry( item->addressee(), item->email() );
+      }
+    }
+    i = i->nextSibling();
+  }
+
+  ab->insertAddressee( dlist );
+#else
   KABC::DistributionList *dlist = new KABC::DistributionList( &manager, name );
   i = mRecipientsList->firstChild();
   while( i ) {
@@ -193,7 +229,6 @@ void DistributionListDialog::slotUser1()
     if ( item->isOn() ) {
       kdDebug() << "  " << item->addressee().fullEmail() << endl;
       if ( item->isTransient() ) {
-        // FIXME: Adding to the address book doesn't seem to work.
         ab->insertAddressee( item->addressee() );
       }
       if ( item->email() == item->addressee().preferredEmail() ) {
@@ -204,8 +239,23 @@ void DistributionListDialog::slotUser1()
     }
     i = i->nextSibling();
   }
+#endif
 
+  // FIXME: Ask the user which resource to save to instead of the default
+  bool saveError = true;
+  KABC::Ticket *ticket = ab->requestSaveTicket( 0 /*default resource */ );
+  if ( ticket )
+    if ( ab->save( ticket ) )
+      saveError = false;
+    else
+      ab->releaseSaveTicket( ticket );
+
+  if ( saveError )
+    kdWarning(5006) << k_funcinfo << " Couldn't save new addresses in the distribution list just created to the address book" << endl;
+
+#ifndef KDEPIM_NEW_DISTRLISTS
   manager.save();
+#endif
 
   close();
 }
