@@ -76,8 +76,8 @@ static const struct {
   const char* userString;
 } standardPermissions[] = {
   { 0, I18N_NOOP2( "Permissions", "None" ) },
-  { ACLJobs::List | ACLJobs::Read, I18N_NOOP2( "Permissions", "Read" ) },
-  { ACLJobs::List | ACLJobs::Read | ACLJobs::Insert | ACLJobs::Post, I18N_NOOP2( "Permissions", "Append" ) },
+  { ACLJobs::List | ACLJobs::Read | ACLJobs::WriteSeenFlag, I18N_NOOP2( "Permissions", "Read" ) },
+  { ACLJobs::List | ACLJobs::Read | ACLJobs::WriteSeenFlag | ACLJobs::Insert | ACLJobs::Post, I18N_NOOP2( "Permissions", "Append" ) },
   { ACLJobs::AllWrite, I18N_NOOP2( "Permissions", "Write" ) },
   { ACLJobs::All, I18N_NOOP2( "Permissions", "All" ) }
 };
