@@ -40,6 +40,8 @@ class QCheckBox;
 class QComboBox;
 class QString;
 class QStringList;
+class TemplatesConfiguration;
+class KPushButton;
 namespace Kleo {
   class EncryptionKeyRequester;
   class SigningKeyRequester;
@@ -73,6 +75,8 @@ namespace KMail {
     void slotAboutToShow( QWidget * w );
     /*! \reimp */
     void slotOk();
+    // copy default templates to identity templates
+    void slotCopyGlobal();
 
   private:
     bool checkFolderExists( const QString & folder, const QString & msg );
@@ -96,8 +100,13 @@ namespace KMail {
     KMail::DictionaryComboBox    *mDictionaryCombo;
     FolderRequester              *mFccCombo;
     FolderRequester              *mDraftsCombo;
+    FolderRequester              *mTemplatesCombo;
     QCheckBox                    *mTransportCheck;
     QComboBox                    *mTransportCombo; // should be a KMTransportCombo...
+    // "templates" tab:
+    TemplatesConfiguration       *mWidget;
+    QCheckBox                    *mCustom;
+    KPushButton                  *mCopyGlobal;
     // "signature" tab:
     KMail::SignatureConfigurator *mSignatureConfigurator;
     // "X-Face" tab:
