@@ -81,12 +81,15 @@ namespace KMail {
 
   ImapAccountBase::ImapAccountBase( AccountManager * parent, const QString & name, uint id )
     : NetworkAccount( parent, name, id ),
+      mIdleTimer( 0, "mIdleTimer" ),
+      mNoopTimer( 0, "mNoopTimer" ),
       mTotal( 0 ),
       mCountUnread( 0 ),
       mCountLastUnread( 0 ),
       mAutoExpunge( true ),
       mHiddenFolders( false ),
       mOnlySubscribedFolders( false ),
+      mOnlyLocallySubscribedFolders( false ),
       mLoadOnDemand( true ),
       mListOnlyOpenFolders( false ),
       mProgressEnabled( false ),
@@ -94,6 +97,7 @@ namespace KMail {
       mPasswordDialogIsActive( false ),
       mACLSupport( true ),
       mAnnotationSupport( true ),
+      mQuotaSupport( true ),
       mSlaveConnected( false ),
       mSlaveConnectionError( false ),
       mCheckingSingleFolder( false ),
@@ -118,6 +122,7 @@ namespace KMail {
     mAutoExpunge = true;
     mHiddenFolders = false;
     mOnlySubscribedFolders = false;
+    mOnlyLocallySubscribedFolders = false;
     mLoadOnDemand = true;
     mListOnlyOpenFolders = false;
     mProgressEnabled = false;
@@ -132,10 +137,12 @@ namespace KMail {
     setAutoExpunge( i->autoExpunge() );
     setHiddenFolders( i->hiddenFolders() );
     setOnlySubscribedFolders( i->onlySubscribedFolders() );
+    setOnlyLocallySubscribedFolders( i->onlyLocallySubscribedFolders() );
     setLoadOnDemand( i->loadOnDemand() );
     setListOnlyOpenFolders( i->listOnlyOpenFolders() );
     setNamespaces( i->namespaces() );
     setNamespaceToDelimiter( i->namespaceToDelimiter() );
+    localBlacklistFromStringList( i->locallyBlacklistedFolders() );
   }
 
   unsigned short int ImapAccountBase::defaultPort() const {
@@ -164,6 +171,10 @@ namespace KMail {
     mOnlySubscribedFolders = show;
   }
 
+  void ImapAccountBase::setOnlyLocallySubscribedFolders( bool show ) {
+    mOnlyLocallySubscribedFolders = show;
+  }
+
   void ImapAccountBase::setLoadOnDemand( bool load ) {
     mLoadOnDemand = load;
   }
@@ -184,6 +195,7 @@ namespace KMail {
     setAutoExpunge( config.readBoolEntry( "auto-expunge", false ) );
     setHiddenFolders( config.readBoolEntry( "hidden-folders", false ) );
     setOnlySubscribedFolders( config.readBoolEntry( "subscribed-folders", false ) );
+    setOnlyLocallySubscribedFolders( config.readBoolEntry( "locally-subscribed-folders", false ) );
     setLoadOnDemand( config.readBoolEntry( "loadondemand", false ) );
     setListOnlyOpenFolders( config.readBoolEntry( "listOnlyOpenFolders", false ) );
     // read namespaces
@@ -201,7 +213,7 @@ namespace KMail {
     // read namespace - delimiter
     namespaceDelim entries = config.entryMap( config.group() );
     namespaceDelim namespaceToDelimiter;
-    for ( namespaceDelim::ConstIterator it = entries.begin(); 
+    for ( namespaceDelim::ConstIterator it = entries.begin();
           it != entries.end(); ++it ) {
       if ( it.key().startsWith( "Namespace:" ) ) {
         QString key = it.key().right( it.key().length() - 10 );
@@ -213,6 +225,7 @@ namespace KMail {
     if ( !mOldPrefix.isEmpty() ) {
       makeConnection();
     }
+    localBlacklistFromStringList( config.readListEntry( "locallyUnsubscribedFolders" ) );
   }
 
   void ImapAccountBase::writeConfig( KConfig/*Base*/ & config ) /*const*/ {
@@ -221,6 +234,7 @@ namespace KMail {
     config.writeEntry( "auto-expunge", autoExpunge() );
     config.writeEntry( "hidden-folders", hiddenFolders() );
     config.writeEntry( "subscribed-folders", onlySubscribedFolders() );
+    config.writeEntry( "locally-subscribed-folders", onlyLocallySubscribedFolders() );
     config.writeEntry( "loadondemand", loadOnDemand() );
     config.writeEntry( "listOnlyOpenFolders", listOnlyOpenFolders() );
     QString data;
@@ -231,11 +245,12 @@ namespace KMail {
       }
     }
     QString key;
-    for ( namespaceDelim::ConstIterator it = mNamespaceToDelimiter.begin(); 
+    for ( namespaceDelim::ConstIterator it = mNamespaceToDelimiter.begin();
           it != mNamespaceToDelimiter.end(); ++it ) {
       key = "Namespace:" + it.key();
       config.writeEntry( key, it.data() );
     }
+    config.writeEntry( "locallyUnsubscribedFolders", locallyBlacklistedFolders() );
   }
 
   //
@@ -254,7 +269,7 @@ namespace KMail {
     return m;
   }
 
-  ImapAccountBase::ConnectionState ImapAccountBase::makeConnection() 
+  ImapAccountBase::ConnectionState ImapAccountBase::makeConnection()
   {
     if ( mSlave && mSlaveConnected ) {
       return Connected;
@@ -276,7 +291,7 @@ namespace KMail {
       QString msg = i18n("You need to supply a username and a password to "
 			 "access this mailbox.");
       mPasswordDialogIsActive = true;
-      
+
       PasswordDialog dlg( msg, log, true /* store pw */, true, KMKernel::self()->mainWin() );
       dlg.setPlainCaption( i18n("Authorization Dialog") );
       dlg.addCommentLine( i18n("Account:"), name() );
@@ -357,9 +372,9 @@ namespace KMail {
       stream << (int) 'U' << url;
 
     // create the KIO-job
-    if ( makeConnection() != Connected ) 
+    if ( makeConnection() != Connected )
       return;// ## doesn't handle Connecting
-    KIO::SimpleJob *job = KIO::special(url, packedArgs, FALSE);
+    KIO::SimpleJob *job = KIO::special(url, packedArgs, false);
     KIO::Scheduler::assignJobToSlave(mSlave, job);
     jobData jd( url.url(), NULL );
     // a bit of a hack to save one slot
@@ -473,6 +488,35 @@ namespace KMail {
     if (mSlave) removeJob(job);
   }
 
+  //-----------------------------------------------------------------------------
+  // Do not remove imapPath, FolderDiaQuotaTab needs to call this with parent==0.
+  void ImapAccountBase::getStorageQuotaInfo( KMFolder* parent, const QString& imapPath )
+  {
+    if ( !mSlave ) return;
+    KURL url = getUrl();
+    url.setPath(imapPath);
+
+    QuotaJobs::GetStorageQuotaJob* job = QuotaJobs::getStorageQuota( mSlave, url );
+    jobData jd( url.url(), parent );
+    jd.cancellable = true;
+    insertJob(job, jd);
+
+    connect(job, SIGNAL(result(KIO::Job *)),
+            SLOT(slotGetStorageQuotaInfoResult(KIO::Job *)));
+  }
+
+  void ImapAccountBase::slotGetStorageQuotaInfoResult( KIO::Job* _job )
+  {
+    QuotaJobs::GetStorageQuotaJob* job = static_cast<QuotaJobs::GetStorageQuotaJob *>( _job );
+    JobIterator it = findJob( job );
+    if ( it == jobsEnd() ) return;
+    if ( job->error() && job->error() == KIO::ERR_UNSUPPORTED_ACTION )
+      setHasNoQuotaSupport();
+
+    KMFolder* folder = (*it).parent; // can be 0
+    emit receivedStorageQuotaInfo( folder, job, job->storageQuotaInfo() );
+    if (mSlave) removeJob(job);
+  }
 
   void ImapAccountBase::slotNoopTimeout()
   {
@@ -520,19 +564,19 @@ namespace KMail {
     if (aSlave != mSlave) return;
     handleError( errorCode, errorMsg, 0, QString::null, true );
     if ( mAskAgain )
-      makeConnection();
-    else {
-      if ( !mSlaveConnected ) {
-        mSlaveConnectionError = true;
-        resetConnectionList( this );
-        if ( mSlave )
-        {
-          KIO::Scheduler::disconnectSlave( slave() );
-          mSlave = 0;
-        }
+      if ( makeConnection() != ImapAccountBase::Error )
+        return;
+
+    if ( !mSlaveConnected ) {
+      mSlaveConnectionError = true;
+      resetConnectionList( this );
+      if ( mSlave )
+      {
+        KIO::Scheduler::disconnectSlave( slave() );
+        mSlave = 0;
       }
-      emit connectionResult( errorCode, errorMsg );
     }
+    emit connectionResult( errorCode, errorMsg );
   }
 
   //-----------------------------------------------------------------------------
@@ -582,13 +626,13 @@ namespace KMail {
       }
       return;
     }
-    
+
     QByteArray packedArgs;
     QDataStream stream( packedArgs, IO_WriteOnly);
     stream << (int) 'n';
     jobData jd;
     jd.total = 1; jd.done = 0; jd.cancellable = true;
-    jd.progressItem = ProgressManager::createProgressItem( 
+    jd.progressItem = ProgressManager::createProgressItem(
         ProgressManager::getUniqueID(),
         i18n("Retrieving Namespaces"),
         QString::null, true, useSSL() || useTLS() );
@@ -631,7 +675,7 @@ namespace KMail {
     kdDebug(5006) << "namespaces fetched" << endl;
     emit namespacesFetched( map );
   }
-    
+
   //-----------------------------------------------------------------------------
   void ImapAccountBase::slotSaveNamespaces( const ImapAccountBase::nsDelimMap& map )
   {
@@ -718,7 +762,7 @@ namespace KMail {
         }
         KMessageBox::information( kmkernel->getKMMainWidget(), msg );
       }
-    } else 
+    } else
     {
       kdDebug(5006) << "migratePrefix - no migration needed" << endl;
     }
@@ -753,7 +797,7 @@ namespace KMail {
       }
     }
     return QString::null;
-  }  
+  }
 
   //-----------------------------------------------------------------------------
   QString ImapAccountBase::delimiterForNamespace( const QString& prefix )
@@ -766,12 +810,12 @@ namespace KMail {
 
     // then try if the prefix is part of a namespace
     // exclude empty namespace
-    for ( namespaceDelim::ConstIterator it = mNamespaceToDelimiter.begin(); 
+    for ( namespaceDelim::ConstIterator it = mNamespaceToDelimiter.begin();
           it != mNamespaceToDelimiter.end(); ++it ) {
       // the namespace definition sometimes contains the delimiter
       // make sure we also match this version
       QString stripped = it.key().left( it.key().length() - 1 );
-      if ( !it.key().isEmpty() && 
+      if ( !it.key().isEmpty() &&
           ( prefix.contains( it.key() ) || prefix.contains( stripped ) ) ) {
         return it.data();
       }
@@ -831,14 +875,39 @@ namespace KMail {
     const QString from = msg->from().isEmpty() ? i18n( "<unknown>" ) : msg->from();
     QString myError = "<p><b>" + i18n("Error while uploading message")
       + "</b></p><p>"
-      + i18n("Could not upload the message dated %1 from %2 with subject %3 on the server.").arg( msg->dateStr(), QStyleSheet::escape( from ), QStyleSheet::escape( subject ) )
+      + i18n("Could not upload the message dated %1 from <i>%2</i> with subject <i>%3</i> to the server.").arg( msg->dateStr(), QStyleSheet::escape( from ), QStyleSheet::escape( subject ) )
       + "</p><p>"
-      + i18n("The destination folder was %1, which has the URL %2.").arg( QStyleSheet::escape( folder->label() ), QStyleSheet::escape( jd.htmlURL() ) )
+      + i18n("The destination folder was: <b>%1</b>.").arg( QStyleSheet::escape( folder->prettyURL() ) )
       + "</p><p>"
-      + i18n("The error message from the server communication is here:") + "</p>";
+      + i18n("The server reported:") + "</p>";
     return handleJobError( job, myError );
   }
 
+  QString ImapAccountBase::prettifyQuotaError( const QString& _error, KIO::Job * job )
+  {
+      QString error = _error;
+      if ( error.find( "quota", 0, false ) == -1 ) return error;
+      // this is a quota error, prettify it a bit
+      JobIterator it = findJob( job );
+      QString quotaAsString( i18n("No detailed quota information available.") );
+      bool readOnly = false;
+      if (it != mapJobData.end()) {
+          const KMFolder * const folder = (*it).parent;
+          assert(folder);
+          const KMFolderCachedImap * const imap = dynamic_cast<const KMFolderCachedImap*>( folder->storage() );
+          if ( imap ) {
+              quotaAsString = imap->quotaInfo().toString();
+          }
+          readOnly = folder->isReadOnly();
+      }
+      error = i18n("The folder is too close to its quota limit. (%1)").arg( quotaAsString );
+      if ( readOnly ) {
+          error += i18n("\nSince you do not have write privileges on this folder, "
+                  "please ask the owner of the folder to free up some space in it.");
+      }
+      return error;
+  }
+
   //-----------------------------------------------------------------------------
   bool ImapAccountBase::handleError( int errorCode, const QString &errorMsg, KIO::Job* job, const QString& context, bool abortSync )
   {
@@ -850,7 +919,7 @@ namespace KMail {
     bool jobsKilled = true;
     switch( errorCode ) {
     case KIO::ERR_SLAVE_DIED: slaveDied(); killAllJobs( true ); break;
-    case KIO::ERR_COULD_NOT_LOGIN: // bad password
+    case KIO::ERR_COULD_NOT_AUTHENTICATE: // bad password
       mAskAgain = true;
       // fallthrough intended
     case KIO::ERR_CONNECTION_BROKEN:
@@ -859,6 +928,7 @@ namespace KMail {
       // These mean that we'll have to reconnect on the next attempt, so disconnect and set mSlave to 0.
       killAllJobs( true );
       break;
+    case KIO::ERR_COULD_NOT_LOGIN:
     case KIO::ERR_USER_CANCELED:
       killAllJobs( false );
       break;
@@ -873,9 +943,9 @@ namespace KMail {
     // check if we still display an error
     if ( !mErrorDialogIsActive && errorCode != KIO::ERR_USER_CANCELED ) {
       mErrorDialogIsActive = true;
-      QString msg = context + '\n' + KIO::buildErrorString( errorCode, errorMsg );
+      QString msg = context + '\n' + prettifyQuotaError( KIO::buildErrorString( errorCode, errorMsg ), job );
       QString caption = i18n("Error");
-      
+
       if ( jobsKilled || errorCode == KIO::ERR_COULD_NOT_LOGIN ) {
         if ( errorCode == KIO::ERR_SERVER_TIMEOUT || errorCode == KIO::ERR_CONNECTION_BROKEN ) {
           msg = i18n("The connection to the server %1 was unexpectedly closed or timed out. It will be re-established automatically if possible.").
@@ -894,10 +964,10 @@ namespace KMail {
           else
               KMessageBox::error( kapp->activeWindow(), msg, caption );
           }
-      }
-      else { // i.e. we have a chance to continue, ask the user about it
+      } else { // i.e. we have a chance to continue, ask the user about it
         if ( errors.count() >= 3 ) { // there is no detailedWarningContinueCancel... (#86517)
-          msg = QString( "<qt>") + context + errors[1] + '\n' + errors[2];
+          QString error = prettifyQuotaError( errors[1], job );
+          msg = QString( "<qt>") + context + error + '\n' + errors[2];
           caption = errors[0];
         }
         int ret = KMessageBox::warningContinueCancel( kapp->activeWindow(), msg, caption );
@@ -944,17 +1014,11 @@ namespace KMail {
     }
   }
 
-
-  //-----------------------------------------------------------------------------
-  QString ImapAccountBase::jobData::htmlURL() const
-  {
-    KURL u(  url );
-    return u.htmlURL();
-  }
-
   //-----------------------------------------------------------------------------
   void ImapAccountBase::processNewMailSingleFolder(KMFolder* folder)
   {
+    if ( mFoldersQueuedForChecking.contains( folder ) )
+      return;
     mFoldersQueuedForChecking.append(folder);
     mCheckingSingleFolder = true;
     if ( checkingMail() )
@@ -976,7 +1040,8 @@ namespace KMail {
 
     QValueList<QGuardedPtr<KMFolder> > mSaveList = mMailCheckFolders;
     mMailCheckFolders = mFoldersQueuedForChecking;
-    kmkernel->acctMgr()->singleCheckMail(this, true);
+    if ( kmkernel->acctMgr() )
+      kmkernel->acctMgr()->singleCheckMail(this, true);
     mMailCheckFolders = mSaveList;
     mFoldersQueuedForChecking.clear();
   }
@@ -999,7 +1064,7 @@ namespace KMail {
     msg->deleteBodyParts();
     // make the parts and fill the mBodyPartList
     constructParts( stream, 1, 0, 0, msg->asDwMessage() );
-    if ( mBodyPartList.count() == 1 ) // we directly set the body later
+    if ( mBodyPartList.count() == 1 ) // we directly set the body later, at partsToLoad below
       msg->deleteBodyParts();
 
     if ( !as )
@@ -1025,6 +1090,12 @@ namespace KMail {
         ++partsToLoad;
       }
     }
+    // if the only body part is not text, part->loadPart() would return false
+    // and that part is never loaded, so make sure it loads.
+    // it seems that TEXT does load the single body part even if it is not text/*
+    if ( mBodyPartList.count() == 1 && partsToLoad == 0 )
+        partsToLoad = 1; // this causes the next test to succeed, and loads the whole message
+
     if ( (mBodyPartList.count() * 0.5) < partsToLoad )
     {
       // more than 50% of the parts have to be loaded anyway so it is faster
@@ -1127,10 +1198,10 @@ namespace KMail {
 
      stream << (int) 'S' << url << flags;
 
-     if ( makeConnection() != Connected ) 
+     if ( makeConnection() != Connected )
        return; // can't happen with dimap
 
-     KIO::SimpleJob *job = KIO::special(url, packedArgs, FALSE);
+     KIO::SimpleJob *job = KIO::special(url, packedArgs, false);
      KIO::Scheduler::assignJobToSlave(slave(), job);
      ImapAccountBase::jobData jd( url.url(), folder );
      jd.path = path;
@@ -1138,20 +1209,45 @@ namespace KMail {
      connect(job, SIGNAL(result(KIO::Job *)),
            SLOT(slotSetStatusResult(KIO::Job *)));
   }
+
+  void ImapAccountBase::setImapSeenStatus(KMFolder * folder, const QString & path, bool seen)
+  {
+     KURL url = getUrl();
+     url.setPath(path);
+
+     QByteArray packedArgs;
+     QDataStream stream( packedArgs, IO_WriteOnly);
+
+     stream << (int) 's' << url << seen;
+
+     if ( makeConnection() != Connected )
+       return; // can't happen with dimap
+
+     KIO::SimpleJob *job = KIO::special(url, packedArgs, false);
+     KIO::Scheduler::assignJobToSlave(slave(), job);
+     ImapAccountBase::jobData jd( url.url(), folder );
+     jd.path = path;
+     insertJob(job, jd);
+     connect(job, SIGNAL(result(KIO::Job *)),
+           SLOT(slotSetStatusResult(KIO::Job *)));
+  }
+
   //-----------------------------------------------------------------------------
   void ImapAccountBase::slotSetStatusResult(KIO::Job * job)
   {
      ImapAccountBase::JobIterator it = findJob(job);
      if ( it == jobsEnd() ) return;
      int errorCode = job->error();
+     KMFolder * const parent = (*it).parent;
+     const QString path = (*it).path;
      if (errorCode && errorCode != KIO::ERR_CANNOT_OPEN_FOR_WRITING)
      {
        bool cont = handleJobError( job, i18n( "Error while uploading status of messages to server: " ) + '\n' );
-       emit imapStatusChanged( (*it).parent, (*it).path, cont );
+       emit imapStatusChanged( parent, path, cont );
      }
      else
      {
-       emit imapStatusChanged( (*it).parent, (*it).path, true );
+       emit imapStatusChanged( parent, path, true );
        removeJob(it);
      }
   }
@@ -1266,10 +1362,10 @@ namespace KMail {
   }
 
   //------------------------------------------------------------------------------
-  QString ImapAccountBase::createImapPath( const QString& parent, 
+  QString ImapAccountBase::createImapPath( const QString& parent,
                                            const QString& folderName )
   {
-    kdDebug(5006) << "createImapPath parent="<<parent<<", folderName="<<folderName<<endl;  
+    kdDebug(5006) << "createImapPath parent="<<parent<<", folderName="<<folderName<<endl;
     QString newName = parent;
     // strip / at the end
     if ( newName.endsWith("/") ) {
@@ -1281,7 +1377,7 @@ namespace KMail {
     if ( delim.isEmpty() ) {
       delim = "/";
     }
-    if ( !newName.isEmpty() && 
+    if ( !newName.isEmpty() &&
          !newName.endsWith( delim ) && !folderName.startsWith( delim ) ) {
       newName = newName + delim;
     }
@@ -1295,7 +1391,7 @@ namespace KMail {
   }
 
   //------------------------------------------------------------------------------
-  QString ImapAccountBase::createImapPath( FolderStorage* parent, 
+  QString ImapAccountBase::createImapPath( FolderStorage* parent,
                                            const QString& folderName )
   {
     QString path;
@@ -1307,10 +1403,44 @@ namespace KMail {
       // error
       return path;
     }
-    
+
     return createImapPath( path, folderName );
   }
 
+
+  bool ImapAccountBase::locallySubscribedTo( const QString& imapPath )
+  {
+      return mLocalSubscriptionBlackList.find( imapPath ) == mLocalSubscriptionBlackList.end();
+  }
+
+  void ImapAccountBase::changeLocalSubscription( const QString& imapPath, bool subscribe )
+  {
+    if ( subscribe ) {
+      // find in blacklist and remove from it
+      mLocalSubscriptionBlackList.erase( imapPath );
+    } else {
+      // blacklist
+      mLocalSubscriptionBlackList.insert( imapPath );
+    }
+  }
+
+
+  QStringList ImapAccountBase::locallyBlacklistedFolders() const
+  {
+      QStringList list;
+      std::set<QString>::const_iterator it = mLocalSubscriptionBlackList.begin();
+      std::set<QString>::const_iterator end = mLocalSubscriptionBlackList.end();
+      for ( ; it != end ; ++it )
+        list.append( *it );
+      return list;
+  }
+
+  void ImapAccountBase::localBlacklistFromStringList( const QStringList &list )
+  {
+    for( QStringList::ConstIterator it = list.constBegin( ); it != list.constEnd( ); ++it )
+      mLocalSubscriptionBlackList.insert( *it );
+  }
+
 } // namespace KMail
 
 #include "imapaccountbase.moc"
