@@ -2,7 +2,7 @@
     keyresolver.cpp
 
     This file is part of libkleopatra, the KDE keymanagement library
-    Copyright (c) 2004 Klarlvdalens Datakonsult AB
+    Copyright (c) 2004 Klarälvdalens Datakonsult AB
 
     Based on kpgp.cpp
     Copyright (C) 2001,2002 the KPGP authors
@@ -20,7 +20,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
@@ -61,6 +61,8 @@
 #include <qstringlist.h>
 #include <qtl.h>
 
+#include <time.h>
+
 #include <algorithm>
 #include <memory>
 #include <iterator>
@@ -68,8 +70,8 @@
 #include <map>
 #include <set>
 #include <iostream>
+#include <cassert>
 
-#include <time.h>
 
 //
 // some predicates to be used in STL algorithms:
@@ -119,7 +121,7 @@ static bool ValidTrustedOpenPGPEncryptionKey( const GpgME::Key & key ) {
     return false;
   const std::vector<GpgME::UserID> uids = key.userIDs();
   for ( std::vector<GpgME::UserID>::const_iterator it = uids.begin() ; it != uids.end() ; ++it ) {
-    if ( !it->isRevoked() && it->validity() >= GpgME::UserID::Marginal )
+    if ( !it->isRevoked() && it->validity() != GpgME::UserID::Marginal )
       return true;
 #if 0
     else
@@ -189,6 +191,69 @@ static inline bool NotValidSMIMESigningKey( const GpgME::Key & key ) {
   return !ValidSMIMESigningKey( key );
 }
 
+static QStringList keysAsStrings( const std::vector<GpgME::Key>& keys ) {
+  QStringList strings;
+  for ( std::vector<GpgME::Key>::const_iterator it = keys.begin() ; it != keys.end() ; ++it ) {
+    assert( !(*it).userID(0).isNull() );
+    QString keyLabel = QString::fromUtf8( (*it).userID(0).email() );
+    if ( keyLabel.isEmpty() )
+      keyLabel = QString::fromUtf8( (*it).userID(0).name() );
+    if ( keyLabel.isEmpty() )
+      keyLabel = QString::fromUtf8( (*it).userID(0).id() );
+    strings.append( keyLabel );
+  }
+  return strings;
+}
+
+static inline std::vector<GpgME::Key> TrustedOrConfirmed( const std::vector<GpgME::Key> & keys ) {
+
+  std::vector<GpgME::Key> fishies;
+  std::vector<GpgME::Key> ickies;
+  std::vector<GpgME::Key>::const_iterator it = keys.begin();
+  const std::vector<GpgME::Key>::const_iterator end = keys.end();
+  for ( ; it != end ; it++ ) {
+    const GpgME::Key key = *it;
+    assert( ValidTrustedEncryptionKey( key ) );
+    const std::vector<GpgME::UserID> uids = key.userIDs();
+    for ( std::vector<GpgME::UserID>::const_iterator it = uids.begin() ; it != uids.end() ; ++it ) {
+      if ( !it->isRevoked()  && it->validity() == GpgME::UserID::Marginal ) {
+        fishies.push_back( key );
+        break;
+      }
+      if ( !it->isRevoked()  && it->validity() < GpgME::UserID::Never ) {
+        ickies.push_back( key );
+        break;
+      }
+    }
+  }
+
+  if ( fishies.empty() && ickies.empty() )
+    return keys;
+
+  // if  some keys are not fully trusted, let the user confirm their use
+  QString msg = i18n("One or more of your configured OpenPGP encryption "
+                      "keys or S/MIME certificates is not fully trusted "
+                      "for encryption.");
+
+  if ( !fishies.empty() ) {
+    // certificates can't have marginal trust
+    msg += i18n( "\nThe following keys are only marginally trusted: \n");
+    msg += keysAsStrings( fishies ).join(",");
+  }
+  if ( !ickies.empty() ) {
+    msg += i18n( "\nThe following keys or certificates have unknown trust level: \n");
+    msg += keysAsStrings( ickies ).join(",");
+  }
+
+  if( KMessageBox::warningContinueCancel( 0, msg, i18n("Not Fully Trusted Encryption Keys"),
+                                              KStdGuiItem::cont(),
+                                              "not fully trusted encryption key warning" )
+          == KMessageBox::Continue )
+    return keys;
+  else
+    return std::vector<GpgME::Key>();
+}
+
 namespace {
   struct IsNotForFormat : public std::unary_function<GpgME::Key,bool> {
     IsNotForFormat( Kleo::CryptoMessageFormat f ) : format( f ) {}
@@ -690,7 +755,7 @@ std::vector<Kleo::KeyResolver::Item> Kleo::KeyResolver::getEncryptionItems( cons
   items.reserve( addresses.size() );
   for ( QStringList::const_iterator it = addresses.begin() ; it != addresses.end() ; ++it ) {
     QString addr = canonicalAddress( *it ).lower();
-    ContactPreferences& pref = lookupContactPreferences( addr );
+    const ContactPreferences pref = lookupContactPreferences( addr );
 
     items.push_back( Item( *it, /*getEncryptionKeys( *it, true ),*/
 			   pref.encryptionPreference,
@@ -780,7 +845,7 @@ bool Kleo::KeyResolver::encryptionPossible() const {
 		       EmptyKeyList ) == d->mSecondaryEncryptionKeys.end() ;
 }
 
-Kpgp::Result Kleo::KeyResolver::resolveAllKeys( bool signingRequested, bool encryptionRequested ) {
+Kpgp::Result Kleo::KeyResolver::resolveAllKeys( bool& signingRequested, bool& encryptionRequested ) {
   if ( !encryptionRequested && !signingRequested ) {
     // make a dummy entry with all recipients, but no signing or
     // encryption keys to avoid special-casing on the caller side:
@@ -797,8 +862,13 @@ Kpgp::Result Kleo::KeyResolver::resolveAllKeys( bool signingRequested, bool encr
   if ( signingRequested )
     if ( encryptionRequested )
       result = resolveSigningKeysForEncryption();
-    else
+    else {
       result = resolveSigningKeysForSigningOnly();
+      if ( result == Kpgp::Failure ) {
+        signingRequested = false;
+        return Kpgp::Ok;
+      }
+    }
   return result;
 }
 
@@ -814,7 +884,7 @@ Kpgp::Result Kleo::KeyResolver::resolveEncryptionKeys( bool signingRequested ) {
     if ( it->keys.empty() )
       return Kpgp::Canceled;
     QString addr = canonicalAddress( it->address ).lower();
-    ContactPreferences& pref = lookupContactPreferences( addr );
+    const ContactPreferences pref = lookupContactPreferences( addr );
     it->pref = pref.encryptionPreference;
     it->signPref = pref.signingPreference;
     it->format = pref.cryptoMessageFormat;
@@ -827,7 +897,7 @@ Kpgp::Result Kleo::KeyResolver::resolveEncryptionKeys( bool signingRequested ) {
     if ( it->keys.empty() )
       return Kpgp::Canceled;
     QString addr = canonicalAddress( it->address ).lower();
-    ContactPreferences& pref = lookupContactPreferences( addr );
+    const ContactPreferences pref = lookupContactPreferences( addr );
     it->pref = pref.encryptionPreference;
     it->signPref = pref.signingPreference;
     it->format = pref.cryptoMessageFormat;
@@ -1023,8 +1093,10 @@ Kpgp::Result Kleo::KeyResolver::resolveSigningKeysForSigningOnly() {
   CryptoMessageFormat commonFormat = AutoFormat;
 
   for ( unsigned int i = 0 ; i < numConcreteCryptoMessageFormats ; ++i ) {
+    if ( !(mCryptoMessageFormats & concreteCryptoMessageFormats[i]) )
+      continue; // skip
     if ( signingKeysFor( concreteCryptoMessageFormats[i] ).empty() )
-      continue; // skip;
+      continue; // skip
     if ( count.numOf( concreteCryptoMessageFormats[i] ) == count.numTotal() ) {
       commonFormat = concreteCryptoMessageFormats[i];
       break;
@@ -1041,7 +1113,17 @@ Kpgp::Result Kleo::KeyResolver::resolveSigningKeysForSigningOnly() {
     return Kpgp::Ok;
   }
 
-  return Kpgp::Failure;
+  const QString msg = i18n("Examination of recipient's signing preferences "
+                           "showed no common type of signature matching your "
+                           "available signing keys.\n"
+                           "Send message without signing?"  );
+  if ( KMessageBox::warningContinueCancel( 0, msg, i18n("No signing possible"),
+                                           KStdGuiItem::cont() )
+       == KMessageBox::Continue ) {
+    d->mFormatInfoMap[OpenPGPMIMEFormat].splitInfos.push_back( SplitInfo( allRecipients() ) );
+    return Kpgp::Failure; // means "Ok, but without signing"
+  }
+  return Kpgp::Canceled;
 }
 
 std::vector<GpgME::Key> Kleo::KeyResolver::signingKeysFor( CryptoMessageFormat f ) const {
@@ -1169,8 +1251,20 @@ Kpgp::Result Kleo::KeyResolver::showKeyApprovalDialog() {
 
   if ( dlg.preferencesChanged() ) {
     for ( uint i = 0; i < items.size(); ++i ) {
-      ContactPreferences& pref = lookupContactPreferences( items[i].address );
+      ContactPreferences pref = lookupContactPreferences( items[i].address );
       pref.encryptionPreference = items[i].pref;
+      pref.pgpKeyFingerprints.clear();
+      pref.smimeCertFingerprints.clear();
+      const std::vector<GpgME::Key> & keys = items[i].keys;
+      for ( std::vector<GpgME::Key>::const_iterator it = keys.begin(), end = keys.end() ; it != end ; ++it ) {
+        if ( it->protocol() == GpgME::Context::OpenPGP ) {
+          if ( const char * fpr = it->primaryFingerprint() )
+            pref.pgpKeyFingerprints.push_back( fpr );
+        } else if ( it->protocol() == GpgME::Context::CMS ) {
+          if ( const char * fpr = it->primaryFingerprint() )
+            pref.smimeCertFingerprints.push_back( fpr );
+        }
+      }
       saveContactPreference( items[i].address, pref );
     }
   }
@@ -1272,12 +1366,15 @@ std::vector<GpgME::Key> Kleo::KeyResolver::signingKeys( CryptoMessageFormat f )
 std::vector<GpgME::Key> Kleo::KeyResolver::selectKeys( const QString & person, const QString & msg, const std::vector<GpgME::Key> & selectedKeys ) const {
   Kleo::KeySelectionDialog dlg( i18n("Encryption Key Selection"),
 				msg, selectedKeys,
-				Kleo::KeySelectionDialog::ValidTrustedEncryptionKeys,
+				Kleo::KeySelectionDialog::ValidEncryptionKeys,
 				true, true ); // multi-selection and "remember choice" box
 
   if ( dlg.exec() != QDialog::Accepted )
     return std::vector<GpgME::Key>();
-  const std::vector<GpgME::Key> keys = dlg.selectedKeys();
+  std::vector<GpgME::Key> keys = dlg.selectedKeys();
+  keys.erase( std::remove_if( keys.begin(), keys.end(),
+                                      NotValidTrustedEncryptionKey ),
+                              keys.end() );
   if ( !keys.empty() && dlg.rememberSelection() )
     setKeysForAddress( person, dlg.pgpKeyFingerprints(), dlg.smimeFingerprints() );
   return keys;
@@ -1299,23 +1396,25 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const QString & pe
     if ( !keys.empty() ) {
       // Check if all of the keys are trusted and valid encryption keys
       if ( std::find_if( keys.begin(), keys.end(),
-			 NotValidTrustedEncryptionKey ) == keys.end() )
-	return keys;
+                         NotValidTrustedEncryptionKey ) != keys.end() ) {
+
+        // not ok, let the user select: this is not conditional on !quiet,
+        // since it's a bug in the configuration and the user should be
+        // notified about it as early as possible:
+        keys = selectKeys( person,
+            i18n("if in your language something like "
+              "'key(s)' isn't possible please "
+              "use the plural in the translation",
+              "There is a problem with the "
+              "encryption key(s) for \"%1\".\n\n"
+              "Please re-select the key(s) which should "
+              "be used for this recipient.").arg(person),
+            keys );
+      }
+      keys = TrustedOrConfirmed( keys );
 
-      // not ok, let the user select: this is not conditional on !quiet,
-      // since it's a bug in the configuration and the user should be
-      // notified about it as early as possible:
-      keys = selectKeys( person,
-			 i18n("if in your language something like "
-			      "'key(s)' isn't possible please "
-			      "use the plural in the translation",
-			      "There is a problem with the "
-			      "encryption key(s) for \"%1\".\n\n"
-			      "Please re-select the key(s) which should "
-			      "be used for this recipient.").arg(person),
-			 keys );
       if ( !keys.empty() )
-	return keys;
+        return keys;
       // hmmm, should we not return the keys in any case here?
     }
   }
@@ -1334,28 +1433,33 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const QString & pe
 			matchingKeys.end() );
   }
 
+  // if called with quite == true (from EncryptionPreferenceCounter), we only want to
+  // check if there are keys for this recipients, not (yet) their validity, so
+  // don't show the untrusted encryption key warning in that case
+  if ( !quiet )
+    matchingKeys = TrustedOrConfirmed( matchingKeys );
   if ( quiet || matchingKeys.size() == 1 )
     return matchingKeys;
 
   // no match until now, or more than one key matches; let the user
   // choose the key(s)
   // FIXME: let user get the key from keyserver
-  return selectKeys( person,
-		     matchingKeys.empty()
-		     ? i18n("if in your language something like "
-			    "'key(s)' isn't possible please "
-			    "use the plural in the translation",
-			    "No valid and trusted encryption key was "
-			    "found for \"%1\".\n\n"
-			    "Select the key(s) which should "
-			    "be used for this recipient.").arg(person)
-		     : i18n("if in your language something like "
-			    "'key(s)' isn't possible please "
-			    "use the plural in the translation",
-			    "More than one key matches \"%1\".\n\n"
-			    "Select the key(s) which should "
-			    "be used for this recipient.").arg(person),
-		     matchingKeys );
+  return TrustedOrConfirmed( selectKeys( person,
+          matchingKeys.empty()
+          ? i18n("if in your language something like "
+              "'key(s)' isn't possible please "
+              "use the plural in the translation",
+              "No valid and trusted encryption key was "
+              "found for \"%1\".\n\n"
+              "Select the key(s) which should "
+              "be used for this recipient.").arg(person)
+          : i18n("if in your language something like "
+              "'key(s)' isn't possible please "
+              "use the plural in the translation",
+              "More than one key matches \"%1\".\n\n"
+              "Select the key(s) which should "
+              "be used for this recipient.").arg(person),
+          matchingKeys ) );
 }
 
 
@@ -1425,35 +1529,35 @@ void Kleo::KeyResolver::addKeys( const std::vector<Item> & items ) {
   dump();
 }
 
-Kleo::KeyResolver::ContactPreferences& Kleo::KeyResolver::lookupContactPreferences( const QString& address ) const
+Kleo::KeyResolver::ContactPreferences Kleo::KeyResolver::lookupContactPreferences( const QString& address ) const
 {
-  Private::ContactPreferencesMap::iterator pos =
+  const Private::ContactPreferencesMap::iterator it =
     d->mContactPreferencesMap.find( address );
-  if ( pos == d->mContactPreferencesMap.end() ) {
-    KABC::AddressBook *ab = KABC::StdAddressBook::self();
-    KABC::Addressee::List res = ab->findByEmail( address );
-    ContactPreferences pref;
-    if ( !res.isEmpty() ) {
-      KABC::Addressee addr = res.first();
-      QString encryptPref = addr.custom( "KADDRESSBOOK", "CRYPTOENCRYPTPREF" );
-      pref.encryptionPreference = Kleo::stringToEncryptionPreference( encryptPref );
-      QString signPref = addr.custom( "KADDRESSBOOK", "CRYPTOSIGNPREF" );
-      pref.signingPreference = Kleo::stringToSigningPreference( signPref );
-      QString cryptoFormats = addr.custom( "KADDRESSBOOK", "CRYPTOPROTOPREF" );
-      pref.cryptoMessageFormat = Kleo::stringToCryptoMessageFormat( cryptoFormats );
-      pref.pgpKeyFingerprints = QStringList::split( ',', addr.custom( "KADDRESSBOOK", "OPENPGPFP" ) );
-      pref.smimeCertFingerprints = QStringList::split( ',', addr.custom( "KADDRESSBOOK", "SMIMEFP" ) );
-    }
-    // insert into map and grab resulting iterator
-    pos = d->mContactPreferencesMap.insert(
-      Private::ContactPreferencesMap::value_type( address, pref ) ).first;
+  if ( it != d->mContactPreferencesMap.end() )
+    return it->second;
 
+  KABC::AddressBook *ab = KABC::StdAddressBook::self( true );
+  const KABC::Addressee::List res = ab->findByEmail( address );
+  ContactPreferences pref;
+  if ( !res.isEmpty() ) {
+    KABC::Addressee addr = res.first();
+    QString encryptPref = addr.custom( "KADDRESSBOOK", "CRYPTOENCRYPTPREF" );
+    pref.encryptionPreference = Kleo::stringToEncryptionPreference( encryptPref );
+    QString signPref = addr.custom( "KADDRESSBOOK", "CRYPTOSIGNPREF" );
+    pref.signingPreference = Kleo::stringToSigningPreference( signPref );
+    QString cryptoFormats = addr.custom( "KADDRESSBOOK", "CRYPTOPROTOPREF" );
+    pref.cryptoMessageFormat = Kleo::stringToCryptoMessageFormat( cryptoFormats );
+    pref.pgpKeyFingerprints = QStringList::split( ',', addr.custom( "KADDRESSBOOK", "OPENPGPFP" ) );
+    pref.smimeCertFingerprints = QStringList::split( ',', addr.custom( "KADDRESSBOOK", "SMIMEFP" ) );
   }
-  return (*pos).second;
+  // insert into map and grab resulting iterator
+  d->mContactPreferencesMap.insert( std::make_pair( address, pref ) );
+  return pref;
 }
 
 void Kleo::KeyResolver::saveContactPreference( const QString& email, const ContactPreferences& pref ) const
 {
+  d->mContactPreferencesMap.insert( std::make_pair( email, pref ) );
   KABC::AddressBook *ab = KABC::StdAddressBook::self( true );
   KABC::Addressee::List res = ab->findByEmail( email );
 
@@ -1495,7 +1599,7 @@ QStringList Kleo::KeyResolver::keysForAddress( const QString & address ) const {
     return QStringList();
   }
   QString addr = canonicalAddress( address ).lower();
-  ContactPreferences& pref = lookupContactPreferences( addr );
+  const ContactPreferences pref = lookupContactPreferences( addr );
   return pref.pgpKeyFingerprints + pref.smimeCertFingerprints;
 }
 
@@ -1504,7 +1608,7 @@ void Kleo::KeyResolver::setKeysForAddress( const QString& address, const QString
     return;
   }
   QString addr = canonicalAddress( address ).lower();
-  ContactPreferences& pref = lookupContactPreferences( addr );
+  ContactPreferences pref = lookupContactPreferences( addr );
   pref.pgpKeyFingerprints = pgpKeyFingerprints;
   pref.smimeCertFingerprints = smimeCertFingerprints;
   saveContactPreference( addr, pref );
