@@ -275,10 +275,9 @@ void KMAcctImap::processNewMail(bool interactive)
   if (!mFolder || !mFolder->folder() || !mFolder->folder()->child() ||
       makeConnection() == ImapAccountBase::Error)
   {
-    // checks for mCountRemainChecks
-    checkDone( false, CheckError );
     mCountRemainChecks = 0;
     mCheckingSingleFolder = false;
+    checkDone( false, CheckError );
     return;
   }
   // if necessary then initialize the list of folders which should be checked
@@ -353,7 +352,7 @@ void KMAcctImap::processNewMail(bool interactive)
         else {
           connect(imapFolder, SIGNAL(numUnreadMsgsChanged(KMFolder*)),
               this, SLOT(postProcessNewMail(KMFolder*)));
-          bool ok = imapFolder->processNewMail(interactive); // this removes the local kmfolderimap if its imapPath is somehow empty, and removing it calls createFolderList, invalidating mMailCheckFolders, and causing a crash
+          bool ok = imapFolder->processNewMail(interactive);
           if (!ok)
           {
             // there was an error so cancel
@@ -363,8 +362,6 @@ void KMAcctImap::processNewMail(bool interactive)
               mMailCheckProgressItem->incCompletedItems();
               mMailCheckProgressItem->updateProgress();
             }
-            // since the list of folders might have been updated at this point, mMailCheckFolders may be invalid, so break
-            break;
           }
         }
       }
