@@ -1,15 +1,27 @@
-// -*- mode: C++; c-file-style: "gnu" -*-
-// kmaddrbook.cpp
-// Author: Stefan Taferner <taferner@kde.org>
-// This code is under GPL
-
+/* -*- mode: C++; c-file-style: "gnu" -*-
+ * kmail: KDE mail client
+ * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *
+ */
 #include <config.h>
 #include <unistd.h>
 
 #include "kmaddrbook.h"
 #include "kcursorsaver.h"
-#include "kmmessage.h"
-#include "kmkernel.h" // for KabcBridge
 
 #include <kapplication.h>
 #include <kdebug.h>
@@ -26,7 +38,7 @@ void KabcBridge::addresses(QStringList& result) // includes lists
 {
   KCursorSaver busy(KBusyPtr::busy()); // loading might take a while
 
-  KABC::AddressBook *addressBook = KABC::StdAddressBook::self();
+  KABC::AddressBook *addressBook = KABC::StdAddressBook::self( true );
   KABC::AddressBook::ConstIterator it;
   for( it = addressBook->begin(); it != addressBook->end(); ++it ) {
     const QStringList emails = (*it).emails();
@@ -77,7 +89,7 @@ QStringList KabcBridge::addresses()
     QStringList entries;
     KABC::AddressBook::ConstIterator it;
 
-    const KABC::AddressBook *addressBook = KABC::StdAddressBook::self();
+    const KABC::AddressBook *addressBook = KABC::StdAddressBook::self( true );
     for( it = addressBook->begin(); it != addressBook->end(); ++it ) {
         entries += (*it).fullEmail();
     }
@@ -91,7 +103,7 @@ QString KabcBridge::expandNickName( const QString& nickName )
     return QString::null;
 
   const QString lowerNickName = nickName.lower();
-  const KABC::AddressBook *addressBook = KABC::StdAddressBook::self();
+  const KABC::AddressBook *addressBook = KABC::StdAddressBook::self( true );
   for( KABC::AddressBook::ConstIterator it = addressBook->begin();
        it != addressBook->end(); ++it ) {
     if ( (*it).nickName().lower() == lowerNickName )
@@ -105,7 +117,7 @@ QString KabcBridge::expandNickName( const QString& nickName )
 
 QStringList KabcBridge::categories()
 {
-  KABC::AddressBook *addressBook = KABC::StdAddressBook::self();
+  KABC::AddressBook *addressBook = KABC::StdAddressBook::self( true );
   KABC::Addressee::List addresses = addressBook->allAddressees();
   QStringList allcategories, aux;
 
