@@ -17,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -35,9 +35,9 @@
 #include "kmfoldertree.h"
 #include "kmstartup.h"
 #include "aboutdata.h"
-#include "kmkernel.h"
 #include "kmfolder.h"
-#include "kmacctmgr.h"
+#include "accountmanager.h"
+using KMail::AccountManager;
 #include "sidebarextension.h"
 #include "infoextension.h"
 #include "recentaddresses.h"
@@ -50,6 +50,9 @@ using KRecentAddress::RecentAddresses;
 #include <dcopclient.h>
 #include <kiconloader.h>
 #include <kdebug.h>
+#include <kstatusbar.h>
+#include <ksettings/dispatcher.h>
+
 
 #include <qlayout.h>
 
@@ -82,15 +85,15 @@ KMailPart::KMailPart(QWidget *parentWidget, const char *widgetName,
   kapp->dcopClient()->suspend(); // Don't handle DCOP requests yet
 
   //local, do the init
-  KMKernel *kmailKernel = new KMKernel();
-  kmailKernel->init();
-  kmailKernel->setXmlGuiInstance( KMailFactory::instance() );
+  KMKernel *mKMailKernel = new KMKernel();
+  mKMailKernel->init();
+  mKMailKernel->setXmlGuiInstance( KMailFactory::instance() );
 
   // and session management
-  kmailKernel->doSessionManagement();
+  mKMailKernel->doSessionManagement();
 
   // any dead letters?
-  kmailKernel->recoverDeadLetters();
+  mKMailKernel->recoverDeadLetters();
 
   kmsetSignalHandler(kmsignalHandler);
   kapp->dcopClient()->resume(); // Ok. We are ready for DCOP requests.
@@ -112,11 +115,10 @@ KMailPart::KMailPart(QWidget *parentWidget, const char *widgetName,
   KMMessage *msg = kmkernel->inboxFolder()->getMsg(0);
   mReaderWin->setMsg( msg, true );
   mReaderWin->setFocusPolicy(QWidget::ClickFocus);
-  m_extension = new KMailBrowserExtension(this);
   mStatusBar  = new KMailStatusBarExtension(this);
   //new KParts::SideBarExtension( kmkernel->mainWin()-mainKMWidget()->leftFrame(), this );
   KGlobal::iconLoader()->addAppDir("kmail");
-  setXMLFile( "kmmainwin.rc" );
+  setXMLFile( "kmail_part.rc" );
   kmkernel->inboxFolder()->close();
 #else
   mainWidget = new KMMainWidget( canvas, "mainWidget", this, actionCollection(),
@@ -124,8 +126,9 @@ KMailPart::KMailPart(QWidget *parentWidget, const char *widgetName,
   QVBoxLayout *topLayout = new QVBoxLayout(canvas);
   topLayout->addWidget(mainWidget);
   mainWidget->setFocusPolicy(QWidget::ClickFocus);
-  m_extension = new KMailBrowserExtension(this);
   mStatusBar  = new KMailStatusBarExtension(this);
+  mStatusBar->addStatusBarItem( mainWidget->vacationScriptIndicator(), 2, false );
+
   new KParts::SideBarExtension( mainWidget->folderTree(),
                                 this,
                                 "KMailSidebar" );
@@ -141,8 +144,11 @@ KMailPart::KMailPart(QWidget *parentWidget, const char *widgetName,
   connect( this, SIGNAL(iconChanged(const QPixmap&)), ie, SIGNAL(iconChanged(const QPixmap&)) );
 
   KGlobal::iconLoader()->addAppDir( "kmail" );
-  setXMLFile( "kmmainwin.rc" );
+  setXMLFile( "kmail_part.rc" );
 #endif
+
+  KSettings::Dispatcher::self()->registerInstance( KMailFactory::instance(), mKMailKernel,
+                                                   SLOT( slotConfigChanged() ) );
 }
 
 KMailPart::~KMailPart()
@@ -216,6 +222,8 @@ void KMailPart::guiActivateEvent(KParts::GUIActivateEvent *e)
   KParts::ReadOnlyPart::guiActivateEvent(e);
   mainWidget->initializeFilterActions();
   mainWidget->initializeFolderShortcutActions();
+  mainWidget->setupForwardingActionsList();
+  mainWidget->updateVactionScriptStatus();
 }
 
 void KMailPart::exit()
@@ -229,15 +237,6 @@ QWidget* KMailPart::parentWidget() const
 }
 
 
-KMailBrowserExtension::KMailBrowserExtension(KMailPart *parent) :
-  KParts::BrowserExtension(parent, "KMailBrowserExtension")
-{
-}
-
-KMailBrowserExtension::~KMailBrowserExtension()
-{
-}
-
 KMailStatusBarExtension::KMailStatusBarExtension( KMailPart *parent )
   : KParts::StatusBarExtension( parent ), mParent( parent )
 {
@@ -248,6 +247,5 @@ KMainWindow * KMailStatusBarExtension::mainWindow() const
   return static_cast<KMainWindow*>( mParent->parentWidget() );
 }
 
-
 #include "kmail_part.moc"
 
