@@ -348,7 +348,7 @@ private slots:
   /**
    * Read settings from app's config file.
    */
-  void readConfig(void);
+  void readConfig( bool reload = false );
   /**
    * Change window title to given string.
    */
