@@ -1,10 +1,21 @@
 /* -*- mode: C++; c-file-style: "gnu" -*-
- * Mail Filter Rule : incoming mail is sent trough the list of mail filter
- * rules before it is placed in the associated mail folder (usually "inbox").
- * This class represents one mail filter rule.
+ * kmail: KDE mail client
+ * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * Author: Stefan Taferner <taferner@kde.org>
- * This code is under GPL
  */
 #ifndef kmfilter_h
 #define kmfilter_h
@@ -29,7 +40,7 @@ const int FILTER_MAX_ACTIONS = 8;
 class KMFilter
 {
 public:
-  /** Result codes returned by @see process. They mean:
+  /** Result codes returned by process. They mean:
 
       @param GoOn Everything OK. You are still the owner of the
       message and you should continue applying filter actions to this
@@ -42,6 +53,17 @@ public:
   */
   enum ReturnCode { NoResult, GoOn, CriticalError };
 
+  /** Account type codes used by setApplicability. They mean:
+
+      @param All Apply to all accounts
+
+      @param ButImap Apply to all but online-IMAP accounts
+
+      @param Checked apply to all accounts specified by setApplyOnAccount
+
+  */
+  enum AccountType { All, ButImap, Checked };
+
   /** Constructor that initializes from given config file, if given.
     * Filters are stored one by one in config groups, i.e. one filter, one group.
     * The config group has to be preset if config is not 0. */
@@ -66,7 +88,7 @@ public:
       @li 0 if processed successfully.
       @param msg The message to which the actions should be applied.
       @param stopIt Contains
-      TRUE if the caller may apply other filters and FALSE if he shall
+      true if the caller may apply other filters and false if he shall
       stop the filtering of this message.
   */
   ReturnCode execActions( KMMessage* msg, bool& stopIt ) const ;
@@ -118,41 +140,72 @@ public:
   const KMSearchPattern* pattern() const { return &mPattern; }
 
   /** Set whether this filter should be applied on
-      outbound messages (@p aApply == TRUE) or not.
-      @see applyOnOutbound applyOnInbound setApplyOnInbound
+      outbound messages (@p aApply == true) or not.
+      See applyOnOutbound applyOnInbound setApplyOnInbound
   */
-  void setApplyOnOutbound( bool aApply=TRUE ) { bApplyOnOutbound = aApply; }
+  void setApplyOnOutbound( bool aApply=true ) { bApplyOnOutbound = aApply; }
 
-  /** @return TRUE if this filter should be applied on
-      outbound messages, FALSE otherwise.
+  /** @return true if this filter should be applied on
+      outbound messages, false otherwise.
       @see setApplyOnOutbound applyOnInbound setApplyOnInbound
   */
   bool applyOnOutbound() const { return bApplyOnOutbound; }
 
   /** Set whether this filter should be applied on
-      inbound messages (@p aApply == TRUE) or not.
+      inbound messages (@p aApply == true) or not.
       @see setApplyOnOutbound applyOnInbound applyOnOutbound
   */
-  void setApplyOnInbound( bool aApply=TRUE ) { bApplyOnInbound = aApply; }
+  void setApplyOnInbound( bool aApply=true ) { bApplyOnInbound = aApply; }
 
-  /** @return TRUE if this filter should be applied on
-      inbound messages, FALSE otherwise.
+  /** @return true if this filter should be applied on
+      inbound messages, false otherwise.
       @see setApplyOnOutbound applyOnOutbound setApplyOnInbound
   */
   bool applyOnInbound() const { return bApplyOnInbound; }
 
   /** Set whether this filter should be applied on
-      explicit (CTRL-J) filtering (@p aApply == TRUE) or not.
+      explicit (CTRL-J) filtering (@p aApply == true) or not.
       @see setApplyOnOutbound applyOnInbound applyOnOutbound
   */
-  void setApplyOnExplicit( bool aApply=TRUE ) { bApplyOnExplicit = aApply; }
+  void setApplyOnExplicit( bool aApply=true ) { bApplyOnExplicit = aApply; }
 
-  /** @return TRUE if this filter should be applied on
-      explicit (CTRL-J) filtering, FALSE otherwise.
+  /** @return true if this filter should be applied on
+      explicit (CTRL-J) filtering, false otherwise.
       @see setApplyOnOutbound applyOnOutbound setApplyOnInbound
   */
   bool applyOnExplicit() const { return bApplyOnExplicit; }
 
+  /** Set whether this filter should be applied on
+      inbound messages for all accounts (@p aApply == All) or
+      inbound messages for all but nline IMAP accounts (@p aApply == ButImap) or
+      for a specified set of accounts only.
+      Only applicable to filters that are applied on inbound messages.
+      @see setApplyOnInbound setApplyOnAccount
+  */
+  void setApplicability( AccountType aApply=All ) { mApplicability = aApply; }
+
+  /** @return true if this filter should be applied on
+      inbound messages for all accounts, or false if this filter
+      is to be applied on a specified set of accounts only.
+      Only applicable to filters that are applied on inbound messages.
+      @see setApplicability
+  */
+  AccountType applicability() const { return mApplicability; }
+
+  /** Set whether this filter should be applied on
+      inbound messages for the account with id (@p id).
+      Only applicable to filters that are only applied to a specified
+      set of accounts.
+      @see setApplicability applyOnAccount
+  */
+  void setApplyOnAccount( uint id, bool aApply=true );
+
+  /** @return true if this filter should be applied on
+      inbound messages from the account with id (@p id), false otherwise.
+      @see setApplicability
+  */
+  bool applyOnAccount( uint id ) const;
+
   void setStopProcessingHere( bool aStop ) { bStopProcessingHere = aStop; }
   bool stopProcessingHere() const { return bStopProcessingHere; }
 
@@ -163,8 +216,8 @@ public:
     bConfigureToolbar = bConfigureToolbar && bConfigureShortcut;
   }
 
-  /** @return TRUE if this filter should be plugged into the filter menu,
-      FALSE otherwise.
+  /** @return true if this filter should be plugged into the filter menu,
+      false otherwise.
       @see setConfigureShortcut
   */
   bool configureShortcut() const { return bConfigureShortcut; }
@@ -177,8 +230,8 @@ public:
     bConfigureToolbar = aTool && bConfigureShortcut;
   }
 
-  /** @return TRUE if this filter should be plugged into the toolbar,
-      FALSE otherwise.
+  /** @return true if this filter should be plugged into the toolbar,
+      false otherwise.
       @see setConfigureToolbar
   */
   bool configureToolbar() const { return bConfigureToolbar; }
@@ -209,8 +262,8 @@ public:
    * Called from the filter manager when a folder is moved.
    * Tests if the folder aFolder is used in any action. Changes it
    * to aNewFolder folder in this case.
-   * @return TRUE if a change in some action occurred,
-   * FALSE if no action was affected.
+   * @return true if a change in some action occurred,
+   * false if no action was affected.
    */
   bool folderRemoved( KMFolder* aFolder, KMFolder* aNewFolder );
 
@@ -227,10 +280,10 @@ public:
   }
 
   /** Set the mode for using automatic naming for the filter.
-      If the feature is enabled, the name is derived from the 
+      If the feature is enabled, the name is derived from the
       first filter rule.
   */
-  void setAutoNaming( bool useAutomaticNames ) { 
+  void setAutoNaming( bool useAutomaticNames ) {
     bAutoNaming = useAutomaticNames;
   }
 
@@ -241,6 +294,7 @@ public:
 private:
   KMSearchPattern mPattern;
   QPtrList<KMFilterAction> mActions;
+  QValueList<int> mAccounts;
   KMPopFilterAction mAction;
   QString mIcon;
   KShortcut mShortcut;
@@ -252,6 +306,7 @@ private:
   bool bConfigureShortcut : 1;
   bool bConfigureToolbar : 1;
   bool bAutoNaming : 1;
+  AccountType mApplicability;
 };
 
 #endif /*kmfilter_h*/
