@@ -273,7 +273,7 @@ bool KMFolderIndex::readIndex()
     else if (mi->isNew())
     {
       mi->setStatus(KMMsgStatusUnread);
-      mi->setDirty(FALSE);
+      mi->setDirty(false);
     }
 #endif
     if ((mi->isNew()) || (mi->isUnread()) ||
@@ -286,7 +286,7 @@ bool KMFolderIndex::readIndex()
   }
   if( version < 1505)
   {
-    mConvertToUtf8 = FALSE;
+    mConvertToUtf8 = false;
     setDirty( true );
     writeIndex();
   }
@@ -319,14 +319,14 @@ bool KMFolderIndex::readIndexHeader(int *gv)
   if (indexVersion < 1505 ) {
       if(indexVersion == 1503) {
 	  kdDebug(5006) << "Converting old index file " << indexLocation() << " to utf-8" << endl;
-	  mConvertToUtf8 = TRUE;
+	  mConvertToUtf8 = true;
       }
-      return TRUE;
+      return true;
   } else if (indexVersion == 1505) {
   } else if (indexVersion < INDEX_VERSION) {
       kdDebug(5006) << "Index file " << indexLocation() << " is out of date. Re-creating it." << endl;
       createIndexFromContents();
-      return FALSE;
+      return false;
   } else if(indexVersion > INDEX_VERSION) {
       kapp->setOverrideCursor(KCursor::arrowCursor());
       int r = KMessageBox::questionYesNo(0,
@@ -338,7 +338,7 @@ bool KMFolderIndex::readIndexHeader(int *gv)
       kapp->restoreOverrideCursor();
       if (r == KMessageBox::Yes)
 	  createIndexFromContents();
-      return FALSE;
+      return false;
   }
   else {
       // Header
@@ -382,7 +382,7 @@ bool KMFolderIndex::readIndexHeader(int *gv)
          kdDebug(5006) << "Index File sizeOfLong is " << mIndexSizeOfLong << " while sizeof(long) is " << sizeof(long) << " !" << endl;
 
   }
-  return TRUE;
+  return true;
 }
 
 
@@ -405,7 +405,7 @@ bool KMFolderIndex::updateIndexStreamPtr(bool)
 	    munmap((char *)mIndexStreamPtr, mIndexStreamPtrLength);
 	mIndexStreamPtr = 0;
 	mIndexStreamPtrLength = 0;
-	return TRUE;
+	return true;
     }
 
     assert(mIndexStream);
@@ -415,7 +415,7 @@ bool KMFolderIndex::updateIndexStreamPtr(bool)
 	    munmap((char *)mIndexStreamPtr, mIndexStreamPtrLength);
 	mIndexStreamPtr = 0;
 	mIndexStreamPtrLength = 0;
-	return FALSE;
+	return false;
     }
     if(mIndexStreamPtr)
 	munmap((char *)mIndexStreamPtr, mIndexStreamPtrLength);
@@ -425,10 +425,10 @@ bool KMFolderIndex::updateIndexStreamPtr(bool)
     if(mIndexStreamPtr == MAP_FAILED) {
 	mIndexStreamPtr = 0;
 	mIndexStreamPtrLength = 0;
-	return FALSE;
+	return false;
     }
 #endif
-    return TRUE;
+    return true;
 }
 
 
@@ -473,9 +473,14 @@ void KMFolderIndex::fillMessageDict()
 
 KMMsgInfo* KMFolderIndex::setIndexEntry( int idx, KMMessage *msg )
 {
-  KMMsgInfo *msgInfo = new KMMsgInfo( folder() );
+  KMMsgInfo *msgInfo = msg->msgInfo();
+  if ( !msgInfo )
+    msgInfo = new KMMsgInfo( folder() );
+
   *msgInfo = *msg;
   mMsgList.set( idx, msgInfo );
+  msg->setMsgInfo( 0 );
+  delete msg;
   return msgInfo;
 }
 
