@@ -34,19 +34,29 @@ namespace KMail {
       void setFolder( KMFolder* );
       void setFolder( const QString& idString );
 
+      /** Apply the given filter. */
+      void applyFilter( const QString& filter );
+
     public slots:
       void addChildFolder();
 
     protected slots:
       void slotContextMenuRequested( QListViewItem *, const QPoint & );
+      virtual void recolorRows();
 
     protected:
       /** Read color options and set palette. */
       virtual void readColorConfig(void);
+      virtual void keyPressEvent( QKeyEvent *e );
+
+      /** Folder and path column IDs. */
+      friend class KMFolderSelDlg;
+      int mFolderColumn;
+      int mPathColumn;
 
     private:
       KMFolderTree* mFolderTree;
-      int mFolderColumn;
+      QString mFilter;
       bool mLastMustBeReadWrite;
       bool mLastShowOutbox;
       bool mLastShowImapFolders;
