@@ -1358,9 +1358,13 @@ void KMFolderTree::cleanupConfigFile()
     {
       KMFolder* folder = kmkernel->findFolderById( name );
       if ( folder ) {
-          if ( kmkernel->iCalIface().hideResourceFolder( folder )
+        if ( kmkernel->iCalIface().hideResourceFolder( folder )
            ||  kmkernel->iCalIface().hideResourceAccountRoot( folder ) )
-        continue; // hidden IMAP resource folder, don't delete info
+          continue; // hidden IMAP resource folder, don't delete info
+        if ( folder->noContent() )
+          continue; // we hide nocontent folders if they have no child folders
+        if ( folder == kmkernel->inboxFolder() )
+          continue; // local inbox can be hidden as well
       }
 
       //KMessageBox::error( 0, "cleanupConfigFile: Deleting group " + *grpIt );
@@ -1540,8 +1544,8 @@ void KMFolderTree::slotFolderExpanded( QListViewItem * item )
   {
     KMFolderImap *folder = static_cast<KMFolderImap*>( fti->folder()->storage() );
     // if we should list all folders we limit this to the root folder
-    if ( !folder->account()->listOnlyOpenFolders() &&
-         fti->parent() )
+    if ( !folder->account() || ( !folder->account()->listOnlyOpenFolders() &&
+         fti->parent() ) )
       return;
     if ( folder->getSubfolderState() == KMFolderImap::imapNoInformation )
     {
@@ -2101,11 +2105,12 @@ void KMFolderTree::updateCopyActions()
 
 void KMFolderTree::slotAddToFavorites()
 {
-  QValueList<QGuardedPtr<KMFolder> > folders = selectedFolders();
   KMail::FavoriteFolderView *favView = mMainWidget->favoriteFolderView();
   assert( favView );
-  for ( QValueList<QGuardedPtr<KMFolder> >::ConstIterator it = folders.constBegin(); it != folders.constEnd(); ++it )
-    favView->addFolder( *it );
+  for ( QListViewItemIterator it( this ); it.current(); ++it ) {
+    if ( it.current()->isSelected() )
+      favView->addFolder( static_cast<KMFolderTreeItem*>( it.current() ) );
+  }
 }
 
 void KMFolderTree::slotUnhideLocalInbox()
