@@ -10,6 +10,7 @@
 #include "kmkernel.h"
 #include "kmmessage.h"
 #include "globalsettings.h"
+#include "util.h"
 
 #include <kasciistringtools.h>
 #include <kmime_charfreq.h>
@@ -102,7 +103,29 @@ int KMMessagePart::decodedSize(void) const
 //-----------------------------------------------------------------------------
 void KMMessagePart::setBody(const QCString &aStr)
 {
-  mBody.duplicate( aStr.data(), aStr.length() );
+  KMail::Util::setFromQCString( mBody, aStr );
+
+  int enc = cte();
+  if (enc == DwMime::kCte7bit || enc == DwMime::kCte8bit || enc == DwMime::kCteBinary)
+    mBodyDecodedSize = mBody.size();
+  else
+    mBodyDecodedSize = -1; // Can't know the decoded size
+}
+
+void KMMessagePart::setBody(const DwString &aStr)
+{
+  mBody.duplicate( aStr.c_str(), aStr.length() );
+
+  int enc = cte();
+  if (enc == DwMime::kCte7bit || enc == DwMime::kCte8bit || enc == DwMime::kCteBinary)
+    mBodyDecodedSize = mBody.size();
+  else
+    mBodyDecodedSize = -1; // Can't know the decoded size
+}
+
+void KMMessagePart::setBody(const QByteArray &aStr)
+{
+  mBody = aStr;
 
   int enc = cte();
   if (enc == DwMime::kCte7bit || enc == DwMime::kCte8bit || enc == DwMime::kCteBinary)
@@ -161,8 +184,7 @@ void KMMessagePart::setCharset( const QCString & c ) {
 //-----------------------------------------------------------------------------
 void KMMessagePart::setBodyEncoded(const QCString& aStr)
 {
-  mBodyDecodedSize = aStr.length();
-
+  mBodyDecodedSize = aStr.size() - 1; // same as aStr.length() but faster - assuming no embedded nuls
   switch (cte())
   {
   case DwMime::kCteQuotedPrintable:
@@ -191,6 +213,7 @@ void KMMessagePart::setBodyEncoded(const QCString& aStr)
   case DwMime::kCte7bit:
   case DwMime::kCte8bit:
   case DwMime::kCteBinary:
+    // This is slow and memory hungry - consider using setBodyEncodedBinary instead!
     mBody.duplicate( aStr.data(), mBodyDecodedSize );
     break;
   }
@@ -224,7 +247,7 @@ void KMMessagePart::setBodyAndGuessCte(const QCString& aBuf,
 				       bool allow8Bit,
                                        bool willBeSigned )
 {
-  mBodyDecodedSize = aBuf.length();
+  mBodyDecodedSize = aBuf.size() - 1; // same as aStr.length() but faster - assuming no embedded nuls
 
   CharFreq cf( aBuf.data(), mBodyDecodedSize ); // save to pass null strings
 
@@ -270,11 +293,36 @@ void KMMessagePart::setBodyEncodedBinary(const QByteArray& aStr)
   case DwMime::kCte7bit:
   case DwMime::kCte8bit:
   case DwMime::kCteBinary:
-    mBody.duplicate( aStr );
+    //mBody.duplicate( aStr );
+    mBody = aStr;
+    // Caller has to detach before it modifies aStr!
     break;
   }
 }
 
+void KMMessagePart::setMessageBody( const QByteArray& aBuf )
+{
+  CharFreq cf( aBuf ); // it's safe to pass null arrays
+  mBodyDecodedSize = aBuf.size();
+
+  int cte;
+  switch ( cf.type() ) {
+  case CharFreq::SevenBitText:
+  case CharFreq::SevenBitData:
+     cte = DwMime::kCte7bit;
+     break;
+  case CharFreq::EightBitText:
+  case CharFreq::EightBitData:
+     cte = DwMime::kCte8bit;
+     break;
+  default:
+     kdWarning(5006) << "Calling " << k_funcinfo
+         << " with something containing neither 7 nor 8 bit text!"
+         << " Fix this caller: " << kdBacktrace() << endl;
+  }
+  setCte( cte );
+  setBodyEncodedBinary( aBuf );
+}
 
 //-----------------------------------------------------------------------------
 QByteArray KMMessagePart::bodyDecodedBinary() const
@@ -348,13 +396,12 @@ QCString KMMessagePart::bodyDecoded(void) const
 
   if ( decodeBinary ) {
     len = mBody.size();
-    result.resize( len+1 /* trailing NUL */ );
-    memcpy(result.data(), mBody.data(), len);
-    result[len] = 0;
+    KMail::Util::setFromByteArray( result, mBody );
   }
 
-  kdWarning( result.length() != (unsigned int)len, 5006 )
-    << "KMMessagePart::bodyDecoded(): body is binary but used as text!" << endl;
+  // Calls length -> slow
+  //kdWarning( result.length() != (unsigned int)len, 5006 )
+  //  << "KMMessagePart::bodyDecoded(): body is binary but used as text!" << endl;
 
   result = result.replace( "\r\n", "\n" ); // CRLF -> LF conversion
 
@@ -382,7 +429,7 @@ void KMMessagePart::magicSetType(bool aAutoDecode)
 
 
 //-----------------------------------------------------------------------------
-QString KMMessagePart::iconName() const
+QString KMMessagePart::iconName( int size ) const
 {
   QCString mimeType( mType + "/" + mSubtype );
   KPIM::kAsciiToLower( mimeType.data() );
@@ -400,7 +447,7 @@ QString KMMessagePart::iconName() const
   }
 
   fileName =
-    KGlobal::instance()->iconLoader()->iconPath( fileName, KIcon::Desktop );
+    KGlobal::instance()->iconLoader()->iconPath( fileName, size );
   return fileName;
 }
 
@@ -505,20 +552,20 @@ void KMMessagePart::setContentDescription(const QString &aStr)
 QString KMMessagePart::fileName(void) const
 {
   QCString str;
-  
-  // Allow for multiple filname*0, filename*1, ... params (defined by RFC 2231) 
+
+  // Allow for multiple filname*0, filename*1, ... params (defined by RFC 2231)
   // in the Content-Disposision
-  if ( mContentDisposition.contains( "filename*", FALSE ) ) {
-  
+  if ( mContentDisposition.contains( "filename*", false ) ) {
+
     // It's RFC 2231 encoded, so extract the file name with the 2231 method
     str = KMMsgBase::extractRFC2231HeaderField( mContentDisposition, "filename" );
     return KMMsgBase::decodeRFC2231String(str);
-  
+
   } else {
-    
+
     // Standard RFC 2047-encoded
     // search the start of the filename
-    int startOfFilename = mContentDisposition.find("filename=", 0, FALSE);
+    int startOfFilename = mContentDisposition.find("filename=", 0, false);
     if (startOfFilename < 0)
       return QString::null;
     startOfFilename += 9;
@@ -540,14 +587,16 @@ QString KMMessagePart::fileName(void) const
                            .stripWhiteSpace();
     return KMMsgBase::decodeRFC2047String(str, charset());
   }
-  
+
   return QString::null;
 }
 
-
-
 QCString KMMessagePart::body() const
 {
   return QCString( mBody.data(), mBody.size() + 1 ); // space for trailing NUL
 }
 
+DwString KMMessagePart::dwBody() const
+{
+  return KMail::Util::dwString( mBody );
+}
