@@ -516,7 +516,8 @@ KMReaderWin::KMReaderWin(QWidget *aParent,
     mHtmlWriter( 0 ),
     mSavedRelativePosition( 0 ),
     mDecrytMessageOverwrite( false ),
-    mShowSignatureDetails( false )
+    mShowSignatureDetails( false ),
+    mShowAttachmentQuicklist( true )
 {
   mSplitterSizes << 180 << 100;
   mMimeTreeMode = 1;
@@ -764,10 +765,9 @@ void KMReaderWin::slotAllHeaders() {
 void KMReaderWin::slotLevelQuote( int l )
 {
   kdDebug( 5006 ) << "Old Level: " << mLevelQuote << " New Level: " << l << endl;
-	mLevelQuote = l;
-  QScrollView * scrollview = static_cast<QScrollView *>(mViewer->widget());
-  mSavedRelativePosition = (float)scrollview->contentsY() / scrollview->contentsHeight();
 
+  mLevelQuote = l;
+  saveRelativePosition();
   update(true);
 }
 
@@ -1461,7 +1461,8 @@ void KMReaderWin::updateReaderWin()
   if (mSavedRelativePosition)
   {
     QScrollView * scrollview = static_cast<QScrollView *>(mViewer->widget());
-    scrollview->setContentsPos ( 0, qRound(  scrollview->contentsHeight() * mSavedRelativePosition ) );
+    scrollview->setContentsPos( 0,
+      qRound( scrollview->contentsHeight() * mSavedRelativePosition ) );
     mSavedRelativePosition = 0;
   }
 }
@@ -2049,10 +2050,8 @@ void KMReaderWin::slotFindNext()
 //-----------------------------------------------------------------------------
 void KMReaderWin::slotToggleFixedFont()
 {
-  QScrollView * scrollview = static_cast<QScrollView *>(mViewer->widget());
-  mSavedRelativePosition = (float)scrollview->contentsY() / scrollview->contentsHeight();
-
   mUseFixedFont = !mUseFixedFont;
+  saveRelativePosition();
   update(true);
 }
 
@@ -2418,6 +2417,15 @@ bool KMReaderWin::htmlLoadExternal()
 }
 
 
+//-----------------------------------------------------------------------------
+void KMReaderWin::saveRelativePosition()
+{
+  const QScrollView * scrollview = static_cast<QScrollView *>( mViewer->widget() );
+  mSavedRelativePosition =
+    static_cast<float>( scrollview->contentsY() ) / scrollview->contentsHeight();
+}
+
+
 //-----------------------------------------------------------------------------
 void KMReaderWin::update( bool force )
 {
@@ -2656,13 +2664,34 @@ void KMReaderWin::injectAttachments()
   if ( injectionPoint.isNull() )
     return;
 
+  QString imgpath( locate("data","kmail/pics/") );
+  QString visibility;
+  QString urlHandle;
+  QString imgSrc;
+  if( !showAttachmentQuicklist() )
+    {
+      urlHandle.append( "kmail:showAttachmentQuicklist" );
+      imgSrc.append( "attachmentQuicklistClosed.png" );
+    } else {
+      urlHandle.append( "kmail:hideAttachmentQuicklist" );
+      imgSrc.append( "attachmentQuicklistOpened.png" );
+    }
+
   QString html = renderAttachments( mRootNode, QApplication::palette().active().background() );
   if ( html.isEmpty() )
     return;
-  if ( headerStyle() == HeaderStyle::fancy() )
-    html.prepend( QString::fromLatin1("<div style=\"float:left;\">%1&nbsp;</div>" ).arg(i18n("Attachments:")) );
-  assert( injectionPoint.tagName() == "div" );
-  static_cast<DOM::HTMLElement>( injectionPoint ).setInnerHTML( html );
+
+    if ( headerStyle() == HeaderStyle::fancy() )
+      html.prepend( QString::fromLatin1("<div style=\"float:left;\">%1&nbsp;</div>" ).arg(i18n("Attachments:")) );
+
+    if ( headerStyle() == HeaderStyle::enterprise() ) {
+      QString link("");
+      link += "<div style=\"text-align: right;\"><a href=\""+urlHandle+"\"><img src=\""+imgpath+imgSrc+"\"/></a></div>";
+      html.prepend( link );
+    }
+
+    assert( injectionPoint.tagName() == "div" );
+    static_cast<DOM::HTMLElement>( injectionPoint ).setInnerHTML( html );  
 }
 
 static QColor nextColor( const QColor & c )
@@ -2681,12 +2710,19 @@ QString KMReaderWin::renderAttachments(partNode * node, const QColor &bgColor )
   if ( node->firstChild() ) {
     QString subHtml = renderAttachments( node->firstChild(), nextColor( bgColor ) );
     if ( !subHtml.isEmpty() ) {
+
+      QString visibility;
+      if( !showAttachmentQuicklist() )
+	{
+	  visibility.append( "display:none;" );
+	}
+
       QString margin;
       if ( node != mRootNode || headerStyle() != HeaderStyle::enterprise() )
         margin = "padding:2px; margin:2px; ";
       if ( node->msgPart().typeStr() == "message" || node == mRootNode )
         html += QString::fromLatin1("<div style=\"background:%1; %2"
-            "vertical-align:middle; float:left;\">").arg( bgColor.name() ).arg( margin );
+            "vertical-align:middle; float:left; %3\">").arg( bgColor.name() ).arg( margin ).arg( visibility );
       html += subHtml;
       if ( node->msgPart().typeStr() == "message" || node == mRootNode )
         html += "</div>";
@@ -2709,7 +2745,7 @@ QString KMReaderWin::renderAttachments(partNode * node, const QColor &bgColor )
     typeBlacklisted = typeBlacklisted || node == mRootNode;
     if ( !label.isEmpty() && !icon.isEmpty() && !typeBlacklisted ) {
       html += "<div style=\"float:left;\">";
-      html += "<span style=\"white-space:nowrap;\">";
+      html += QString::fromLatin1( "<span style=\"white-space:nowrap; border-width: 0px; border-left-width: 5px; border-color: %1; 2px; border-left-style: solid;\">" ).arg( bgColor.name() );
       html += QString::fromLatin1( "<a href=\"#att%1\">" ).arg( node->nodeId() );
       html += "<img style=\"vertical-align:middle;\" src=\"" + icon + "\"/>&nbsp;";
       if ( headerStyle() == HeaderStyle::enterprise() ) {
@@ -2722,7 +2758,7 @@ QString KMReaderWin::renderAttachments(partNode * node, const QColor &bgColor )
     }
   }
 
-  html += renderAttachments( node->nextSibling(), bgColor );
+  html += renderAttachments( node->nextSibling(), nextColor ( bgColor ) );
   return html;
 }
 
