@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -28,13 +28,15 @@
 #endif
 
 #include "networkaccount.h"
-#include "kmacctmgr.h"
+#include "accountmanager.h"
 #include "kmkernel.h"
+#include "globalsettings.h"
 
 #include <kconfig.h>
 #include <kio/global.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <kdebug.h>
 #include <kwallet.h>
 using KIO::MetaData;
 using KWallet::Wallet;
@@ -43,7 +45,11 @@ using KWallet::Wallet;
 
 namespace KMail {
 
-  NetworkAccount::NetworkAccount( KMAcctMgr * parent, const QString & name, uint id )
+    
+ // for restricting number of concurrent connections to the same server
+  static QMap<QString, int> s_serverConnections;
+
+  NetworkAccount::NetworkAccount( AccountManager * parent, const QString & name, uint id )
     : KMAccount( parent, name, id ),
       mSlave( 0 ),
       mAuth( "*" ),
@@ -309,6 +315,53 @@ namespace KMail {
     }
   }
 
+  void NetworkAccount::setCheckingMail( bool checking )
+  {
+      mCheckingMail = checking;
+      if ( host().isEmpty() )
+          return;
+    if ( checking ) {
+        if ( s_serverConnections.find( host() ) != s_serverConnections.end() )
+            s_serverConnections[host()] += 1;
+        else
+            s_serverConnections[host()] = 1;
+        kdDebug(5006) << "check mail started - connections for host "
+                << host() << " now is "
+                << s_serverConnections[host()] << endl;
+    } else {
+            if ( s_serverConnections.find( host() ) != s_serverConnections.end() &&
+                s_serverConnections[host()] > 0 ) {
+                s_serverConnections[host()] -= 1;
+                kdDebug(5006) << "connections to server " << host()
+                        << " now " << s_serverConnections[host()] << endl;
+            }
+    }
+}
+  
+  bool NetworkAccount::mailCheckCanProceed() const
+  {
+      bool offlineMode = KMKernel::isOffline();
+
+      kdDebug(5006) << "for host " << host()
+              << " current connections="
+              << (s_serverConnections.find(host())==s_serverConnections.end() ? 0 : s_serverConnections[host()])
+              << " and limit is " << GlobalSettings::self()->maxConnectionsPerHost()
+              << endl;
+      bool connectionLimitForHostReached = !host().isEmpty()
+              && GlobalSettings::self()->maxConnectionsPerHost() > 0
+              && s_serverConnections.find( host() ) != s_serverConnections.end()
+              && s_serverConnections[host()] >= GlobalSettings::self()->maxConnectionsPerHost();
+      kdDebug(5006) << "connection limit reached: "
+              << connectionLimitForHostReached << endl;
+      
+      return ( !connectionLimitForHostReached && !offlineMode );
+  }
+
+  void NetworkAccount::resetConnectionList( NetworkAccount* acct )
+  {
+    s_serverConnections[ acct->host() ] = 0;
+  }
+
 } // namespace KMail
 
 #include "networkaccount.moc"
