@@ -1,4 +1,4 @@
-/** -*- c++ -*-
+/* -*- c++ -*-
  * networkaccount.h
  *
  * Copyright (c) 2000-2002 Michael Haeckel <haeckel@kde.org>
@@ -18,20 +18,22 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
 #ifndef __KMAIL_NETWORKACCOUNT_H__
 #define __KMAIL_NETWORKACCOUNT_H__
 
+#include <qguardedptr.h>
+
 #include "kmaccount.h"
 
 #include "sieveconfig.h"
 
 #include <qstring.h>
 
-class KMAcctMgr;
+class AccountManager;
 class KConfig/*Base*/;
 class KURL;
 namespace KIO {
@@ -44,7 +46,7 @@ namespace KMail {
   class NetworkAccount : public KMAccount {
     Q_OBJECT
   protected:
-    NetworkAccount( KMAcctMgr * parent, const QString & name, uint id );
+    NetworkAccount( AccountManager * parent, const QString & name, uint id );
   public:
     virtual ~NetworkAccount();
 
@@ -91,7 +93,7 @@ namespace KMail {
     bool useTLS() const { return mUseTLS; }
     virtual void setUseTLS( bool use );
 
-    /** @return the @see SieveConfig for this account */
+    /** @return the SieveConfig for this account */
     KMail::SieveConfig sieveConfig() const { return mSieveConfig; }
     virtual void setSieveConfig( const KMail::SieveConfig & config );
 
@@ -113,13 +115,19 @@ namespace KMail {
     /** Read password from wallet, used for on-demand wallet opening */
     void readPassword();
 
+    virtual bool mailCheckCanProceed() const;
+
+    virtual void setCheckingMail( bool checking );
+
+    /** Reset connection list for the account */
+    static void resetConnectionList( NetworkAccount* acct );
   protected:
     virtual QString protocol() const = 0;
     virtual unsigned short int defaultPort() const = 0;
 
   protected:
     KMail::SieveConfig mSieveConfig;
-    KIO::Slave * mSlave;
+    QGuardedPtr<KIO::Slave> mSlave;
     QString mLogin, mPasswd, mAuth, mHost;
     unsigned short int mPort;
     bool mStorePasswd : 1;
@@ -127,7 +135,6 @@ namespace KMail {
     bool mUseTLS : 1;
     bool mAskAgain : 1;
     bool mPasswdDirty, mStorePasswdInConfig;
-
   };
 
 } // namespace KMail
