@@ -114,12 +114,12 @@ void PopAccount::init(void)
 {
   NetworkAccount::init();
 
-  mUsePipelining = FALSE;
-  mLeaveOnServer = FALSE;
+  mUsePipelining = false;
+  mLeaveOnServer = false;
   mLeaveOnServerDays = -1;
   mLeaveOnServerCount = -1;
   mLeaveOnServerSize = -1;
-  mFilterOnServer = FALSE;
+  mFilterOnServer = false;
   //tz todo
   mFilterOnServerCheckSize = 50000;
 }
@@ -152,7 +152,7 @@ void PopAccount::processNewMail(bool _interactive)
       bool b = storePasswd();
       if (KIO::PasswordDialog::getNameAndPassword(mLogin, passwd, &b,
         i18n("You need to supply a username and a password to access this "
-        "mailbox."), FALSE, QString::null, mName, i18n("Account:"))
+        "mailbox."), false, QString::null, mName, i18n("Account:"))
         != QDialog::Accepted)
       {
         checkDone( false, CheckAborted );
@@ -162,7 +162,7 @@ void PopAccount::processNewMail(bool _interactive)
         if ( b ) {
           kmkernel->acctMgr()->writeConfig( true );
         }
-        mAskAgain = FALSE;
+        mAskAgain = false;
       }
     }
 
@@ -201,7 +201,7 @@ void PopAccount::processNewMail(bool _interactive)
     mSizeOfNextSeenMsgsDict.clear();
 
     interactive = _interactive;
-    mUidlFinished = FALSE;
+    mUidlFinished = false;
     startJob();
   }
   else {
@@ -216,12 +216,12 @@ void PopAccount::readConfig(KConfig& config)
 {
   NetworkAccount::readConfig(config);
 
-  mUsePipelining = config.readNumEntry("pipelining", FALSE);
-  mLeaveOnServer = config.readNumEntry("leave-on-server", FALSE);
+  mUsePipelining = config.readNumEntry("pipelining", false);
+  mLeaveOnServer = config.readNumEntry("leave-on-server", false);
   mLeaveOnServerDays = config.readNumEntry("leave-on-server-days", -1);
   mLeaveOnServerCount = config.readNumEntry("leave-on-server-count", -1);
   mLeaveOnServerSize = config.readNumEntry("leave-on-server-size", -1);
-  mFilterOnServer = config.readNumEntry("filter-on-server", FALSE);
+  mFilterOnServer = config.readNumEntry("filter-on-server", false);
   mFilterOnServerCheckSize = config.readUnsignedNumEntry("filter-os-check-size", 50000);
 }
 
@@ -389,6 +389,8 @@ void PopAccount::startJob()
   idsOfMsgs.clear();
   mUidForIdMap.clear();
   idsOfMsgsToDelete.clear();
+  idsOfForcedDeletes.clear();
+
   //delete any headers if there are some this have to be done because of check again
   headersOnServer.clear();
   headers = false;
@@ -486,7 +488,7 @@ void PopAccount::slotJobFinished() {
   }
   else if (stage == Uidl) {
     kdDebug(5006) << k_funcinfo << "stage == Uidl" << endl;
-    mUidlFinished = TRUE;
+    mUidlFinished = true;
 
     if ( mLeaveOnServer && mUidForIdMap.isEmpty() &&
         mUidsOfNextSeenMsgsDict.isEmpty() && !idsOfMsgs.isEmpty() ) {
@@ -735,6 +737,12 @@ void PopAccount::slotJobFinished() {
         idsOfMsgsToDelete.remove( it.key().second );
       }
     }
+
+    if ( !idsOfForcedDeletes.isEmpty() ) {
+      idsOfMsgsToDelete += idsOfForcedDeletes;
+      idsOfForcedDeletes.clear();
+    }
+
     // If there are messages to delete then delete them
     if ( !idsOfMsgsToDelete.isEmpty() ) {
       stage = Dele;
@@ -788,7 +796,7 @@ void PopAccount::slotJobFinished() {
     mSlave = 0;
     stage = Idle;
     if( mMailCheckProgressItem ) { // do this only once...
-      bool canceled = kmkernel->mailCheckAborted() || mMailCheckProgressItem->canceled();
+      bool canceled = !kmkernel || kmkernel->mailCheckAborted() || mMailCheckProgressItem->canceled();
       int numMessages = canceled ? indexOfCurrentMsg : idsOfMsgs.count();
       BroadcastStatus::instance()->setStatusMsgTransmissionCompleted(
         this->name(), numMessages, numBytes, numBytesRead, numBytesToRead, mLeaveOnServer, mMailCheckProgressItem );
@@ -923,8 +931,8 @@ void PopAccount::slotData( KIO::Job* job, const QByteArray &data)
   QString qdata = data;
   qdata = qdata.simplifyWhiteSpace(); // Workaround for Maillennium POP3/UNIBOX
   int spc = qdata.find( ' ' );
-  if (spc > 0) {
-    if (stage == List) {
+  if ( stage == List ) {
+    if ( spc > 0 ) {
       QString length = qdata.mid(spc+1);
       if (length.find(' ') != -1) length.truncate(length.find(' '));
       int len = length.toInt();
@@ -933,46 +941,76 @@ void PopAccount::slotData( KIO::Job* job, const QByteArray &data)
       idsOfMsgs.append( id );
       mMsgsPendingDownload.insert( id, len );
     }
-    else { // stage == Uidl
-      const QString id = qdata.left(spc);
-      const QString uid = qdata.mid(spc + 1);
-      int *size = new int; //malloc(size_of(int));
-      *size = mMsgsPendingDownload[id];
-      mSizeOfNextSeenMsgsDict.insert( uid, size );
-      if ( mUidsOfSeenMsgsDict.find( uid ) != 0 ) {
-
-        if ( mMsgsPendingDownload.contains( id ) ) {
-          mMsgsPendingDownload.remove( id );
-        }
-        else
-          kdDebug(5006) << "PopAccount::slotData synchronization failure." << endl;
-        idsOfMsgsToDelete.append( id );
-        mUidsOfNextSeenMsgsDict.insert( uid, (const int *)1 );
-        if ( mTimeOfSeenMsgsVector.empty() ) {
-          mTimeOfNextSeenMsgsMap.insert( uid, time(0) );
-        }
-        else {
-          // cast the int* with a long to can convert it to a int, BTW
-          // works with g++-4.0 and amd64
-          mTimeOfNextSeenMsgsMap.insert( uid,
-            mTimeOfSeenMsgsVector[(int)( long )mUidsOfSeenMsgsDict[uid] - 1] );
-        }
-      }
-      mUidForIdMap.insert( id, uid );
+    else {
+      stage = Idle;
+      if ( job ) job->kill();
+      job = 0;
+      mSlave = 0;
+      KMessageBox::error( 0, i18n( "Unable to complete LIST operation." ),
+                             i18n( "Invalid Response From Server") );
+      return;
     }
   }
-  else {
-    stage = Idle;
-    if (job) job->kill();
-    job = 0;
-    mSlave = 0;
-    KMessageBox::error(0, i18n( "Unable to complete LIST operation." ),
-                          i18n("Invalid Response From Server"));
-    return;
+  else { // stage == Uidl
+    Q_ASSERT ( stage == Uidl);
+
+    QString id;
+    QString uid;
+
+    if ( spc <= 0 ) {
+      // an invalid uidl line. we might just need to skip it, but
+      // some servers generate invalid uids with valid ids. in that
+      // case we will just make up a uid - which will cause us to
+      // not cache the document, but we will be able to interoperate
+
+      int testid = atoi ( qdata.ascii() );
+      if ( testid < 1 ) {
+        // we'll just have to skip this
+        kdDebug(5006) << "PopAccount::slotData skipping UIDL entry due to parse error "
+                      << endl << qdata.ascii() << endl;
+        return;
+      }
+      id.setNum (testid, 10);
+
+      QString datestring, serialstring;
+
+      serialstring.setNum ( ++dataCounter, 10 );
+      datestring.setNum ( time(NULL),10 );
+      uid = QString( "uidlgen" ) + datestring + QString( "." ) + serialstring;
+      kdDebug(5006) << "PopAccount::slotData message " << id.ascii()
+                    <<  "%d has bad UIDL, cannot keep a copy on server" << endl;
+      idsOfForcedDeletes.append( id );
+    }
+    else {
+      id = qdata.left( spc );
+      uid = qdata.mid( spc + 1 );
+    }
+
+    int *size = new int; //malloc(size_of(int));
+    *size = mMsgsPendingDownload[id];
+    mSizeOfNextSeenMsgsDict.insert( uid, size );
+    if ( mUidsOfSeenMsgsDict.find( uid ) != 0 ) {
+      if ( mMsgsPendingDownload.contains( id ) ) {
+        mMsgsPendingDownload.remove( id );
+      }
+      else
+        kdDebug(5006) << "PopAccount::slotData synchronization failure." << endl;
+      idsOfMsgsToDelete.append( id );
+      mUidsOfNextSeenMsgsDict.insert( uid, (const int *)1 );
+      if ( mTimeOfSeenMsgsVector.empty() ) {
+        mTimeOfNextSeenMsgsMap.insert( uid, time(0) );
+      }
+      else {
+        // cast the int* with a long to can convert it to a int, BTW
+        // works with g++-4.0 and amd64
+        mTimeOfNextSeenMsgsMap.insert( uid, mTimeOfSeenMsgsVector[(int)( long )
+                                                 mUidsOfSeenMsgsDict[uid] - 1] );
+      }
+    }
+    mUidForIdMap.insert( id, uid );
   }
 }
 
-
 //-----------------------------------------------------------------------------
 void PopAccount::slotResult( KIO::Job* )
 {
@@ -1015,14 +1053,14 @@ void PopAccount::slotSlaveError(KIO::Slave *aSlave, int error,
     mSlave = 0;
   }
 
-  if (interactive) {
+  if (interactive && kmkernel) {
     KMessageBox::error(kmkernel->mainWin(), KIO::buildErrorString(error, errorMsg));
   }
 
 
   stage = Quit;
   if (error == KIO::ERR_COULD_NOT_LOGIN && !mStorePasswd)
-    mAskAgain = TRUE;
+    mAskAgain = true;
   /* We need a timer, otherwise slotSlaveError of the next account is also
      executed, if it reuses the slave, because the slave member variable
      is changed too early */
