@@ -24,6 +24,9 @@
 #include "globalsettings.h"
 
 #include <libkdepim/recentaddresses.h>
+#include <libkdepim/ldapsearchdialog.h>
+
+#include <libemailfunctions/email.h>
 
 #ifndef KDEPIM_NEW_DISTRLISTS
 #include <kabc/distributionlist.h>
@@ -56,13 +59,21 @@ RecipientItem::RecipientItem()
 #endif
 
 #ifdef KDEPIM_NEW_DISTRLISTS
-void RecipientItem::setDistributionList( const KPIM::DistributionList &list )
+void RecipientItem::setDistributionList( KPIM::DistributionList &list )
 {
   mDistributionList = list;
 
   mIcon = KGlobal::iconLoader()->loadIcon( "kdmconfig", KIcon::Small );
 
-  mKey = "D" + list.name();
+  mName = list.name();
+  mKey = list.name();
+
+  int count = list.entries( mAddressBook ).count();
+  mEmail = i18n( "1 email address", "%n email addresses", count );
+
+  mRecipient = mName;
+
+  mTooltip = createTooltip( list );
 }
 #else
 void RecipientItem::setDistributionList( KABC::DistributionList *list )
@@ -71,7 +82,15 @@ void RecipientItem::setDistributionList( KABC::DistributionList *list )
 
   mIcon = KGlobal::iconLoader()->loadIcon( "kdmconfig", KIcon::Small );
 
-  mKey = "D" + list->name();
+  mName = list->name();
+  mKey = list->name();
+
+  int count = list->entries().count();
+  mEmail = i18n( "1 email address", "%n email addresses", count );
+
+  mRecipient = mName;
+
+  mTooltip = createTooltip( list );
 }
 #endif
 
@@ -80,6 +99,7 @@ void RecipientItem::setAddressee( const KABC::Addressee &a,
 {
   mAddressee = a;
   mEmail = email;
+  mRecipient = mAddressee.fullEmail( mEmail );
 
   QImage img = a.photo().data();
   if ( !img.isNull() )
@@ -87,7 +107,14 @@ void RecipientItem::setAddressee( const KABC::Addressee &a,
   else
     mIcon = KGlobal::iconLoader()->loadIcon( "personal", KIcon::Small );
 
-  mKey = "A" + a.preferredEmail();
+  mName = mAddressee.realName();
+  mKey = mAddressee.realName() + '|' + mEmail;
+
+  mTooltip = "<qt>";
+  if ( !mAddressee.realName().isEmpty() ) {
+    mTooltip += mAddressee.realName() + "<br/>";
+  }
+  mTooltip += "<b>" + mEmail + "</b>";
 }
 
 QPixmap RecipientItem::icon() const
@@ -97,104 +124,81 @@ QPixmap RecipientItem::icon() const
 
 QString RecipientItem::name() const
 {
-#ifdef KDEPIM_NEW_DISTRLISTS
-  if ( !mAddressee.isEmpty() ) return mAddressee.realName();
-  else if ( !mDistributionList.isEmpty() ) return mDistributionList.name();
-  else return QString::null;
-#else
-  if ( !mAddressee.isEmpty() ) return mAddressee.realName();
-  else if ( mDistributionList ) return mDistributionList->name();
-  else return QString::null;
-#endif
+  return mName;
 }
 
 QString RecipientItem::email() const
 {
-#ifdef KDEPIM_NEW_DISTRLISTS
-  if ( mAddressee.isEmpty() && !mDistributionList.isEmpty() ) {
-    int count = mDistributionList.entries( mAddressBook ).count();
-    return i18n( "1 email address", "%n email addresses", count );
-  } else {
-    return mEmail;
-  }
-#else
-  if ( mAddressee.isEmpty() &&  mDistributionList ) {
-    int count = mDistributionList->entries().count();
-    return i18n( "1 email address", "%n email addresses", count );
-  } else {
-    return mEmail;
-  }
-#endif
-  return QString::null;
+  return mEmail;
+}
+
+QString RecipientItem::recipient() const
+{
+  return mRecipient;
+}
+
+QString RecipientItem::tooltip() const
+{
+  return mTooltip;
 }
 
 #ifdef KDEPIM_NEW_DISTRLISTS
-QString RecipientItem::recipient() const
-{
-  QString r;
-  if ( !mAddressee.isEmpty() ) r = mAddressee.fullEmail( mEmail );
-  else if ( !mDistributionList.isEmpty() ) r = mDistributionList.name();
-  return r;
+KPIM::DistributionList& RecipientItem::distributionList() {
+  return mDistributionList;
 }
 #else
-QString RecipientItem::recipient() const
-{
-  QString r;
-  if ( !mAddressee.isEmpty() ) r = mAddressee.fullEmail( mEmail );
-  else if ( mDistributionList ) r = mDistributionList->name();
-  return r;
+KABC::DistributionList * RecipientItem::distributionList() {
+  return mDistributionList;
 }
 #endif
 
-QString RecipientItem::toolTip() const
+#ifdef KDEPIM_NEW_DISTRLISTS
+QString RecipientItem::createTooltip( KPIM::DistributionList &distributionList ) const
 {
   QString txt = "<qt>";
 
-  if ( !mAddressee.isEmpty() ) {
-    if ( !mAddressee.realName().isEmpty() ) {
-      txt += mAddressee.realName() + "<br/>";
-    }
-    txt += "<b>" + mEmail + "</b>";
-#ifdef KDEPIM_NEW_DISTRLISTS
-  } else if ( !mDistributionList.isEmpty() ) {
-    txt += "<b>" + i18n("Distribution List %1")
-      .arg( mDistributionList.name() ) + "</b>";
-    txt += "<ul>";
-    KPIM::DistributionList::Entry::List entries = mDistributionList.entries( mAddressBook );
-    KPIM::DistributionList::Entry::List::ConstIterator it;
-    for( it = entries.begin(); it != entries.end(); ++it ) {
-      txt += "<li>";
-      txt += (*it).addressee.realName() + " ";
-      txt += "<em>";
-      if ( (*it).email.isEmpty() ) txt += (*it).addressee.preferredEmail();
-      else txt += (*it).email;
-      txt += "</em>";
-      txt += "<li/>";
-    }
-    txt += "</ul>";
+  txt += "<b>" + i18n( "Distribution List %1" ).arg ( distributionList.name() ) + "</b>";
+  txt += "<ul>";
+  KPIM::DistributionList::Entry::List entries = distributionList.entries( mAddressBook );
+  KPIM::DistributionList::Entry::List::ConstIterator it;
+  for( it = entries.begin(); it != entries.end(); ++it ) {
+    txt += "<li>";
+    txt += (*it).addressee.realName() + ' ';
+    txt += "<em>";
+    if ( (*it).email.isEmpty() ) txt += (*it).addressee.preferredEmail();
+    else txt += (*it).email;
+    txt += "</em>";
+    txt += "<li/>";
   }
-#else
-  } else if ( mDistributionList ) {
-    txt += "<b>" + i18n("Distribution List %1")
-      .arg( mDistributionList->name() ) + "</b>";
-    txt += "<ul>";
-    KABC::DistributionList::Entry::List entries = mDistributionList->entries();
-    KABC::DistributionList::Entry::List::ConstIterator it;
-    for( it = entries.begin(); it != entries.end(); ++it ) {
-      txt += "<li>";
-      txt += (*it).addressee.realName() + " ";
-      txt += "<em>";
-      if ( (*it).email.isEmpty() ) txt += (*it).addressee.preferredEmail();
-      else txt += (*it).email;
-      txt += "</em>";
-      txt += "<li/>";
-    }
-    txt += "</ul>";
-  }
-#endif
+  txt += "</ul>";
+  txt += "</qt>";
 
   return txt;
 }
+#else
+QString RecipientItem::createTooltip( KABC::DistributionList *distributionList ) const
+{
+  QString txt = "<qt>";
+
+  txt += "<b>" + i18n("Distribution List %1" ).arg ( distributionList->name() ) + "</b>";
+  txt += "<ul>";
+  KABC::DistributionList::Entry::List entries = distributionList->entries();
+  KABC::DistributionList::Entry::List::ConstIterator it;
+  for( it = entries.begin(); it != entries.end(); ++it ) {
+    txt += "<li>";
+    txt += (*it).addressee.realName() + ' ';
+    txt += "<em>";
+    if ( (*it).email.isEmpty() ) txt += (*it).addressee.preferredEmail();
+    else txt += (*it).email;
+    txt += "</em>";
+    txt += "</li>";
+  }
+  txt += "</ul>";
+  txt += "</qt>";
+
+  return txt;
+}
+#endif
 
 void RecipientItem::setRecipientType( const QString &type )
 {
@@ -238,7 +242,7 @@ void RecipientsListToolTip::maybeTip( const QPoint & pos )
 
   if( item ) {
     r = mListView->itemRect( item );
-    QString tipText( i->recipientItem()->toolTip() );
+    QString tipText( i->recipientItem()->tooltip() );
     if ( !tipText.isEmpty() ) {
       tip( r, tipText );
     }
@@ -246,13 +250,26 @@ void RecipientsListToolTip::maybeTip( const QPoint & pos )
 }
 
 
-RecipientsCollection::RecipientsCollection()
+RecipientsCollection::RecipientsCollection( const QString &id )
 {
+  mId = id;
+  mTitle = id;
+  mIsReferenceContainer = false;
 }
 
 RecipientsCollection::~RecipientsCollection()
 {
-  clear();
+  deleteAll();
+}
+
+void RecipientsCollection::setReferenceContainer( bool isReferenceContainer )
+{
+  mIsReferenceContainer = isReferenceContainer;
+}
+
+bool RecipientsCollection::isReferenceContainer() const
+{
+  return mIsReferenceContainer;
 }
 
 void RecipientsCollection::setTitle( const QString &title )
@@ -267,14 +284,12 @@ QString RecipientsCollection::title() const
 
 void RecipientsCollection::addItem( RecipientItem *item )
 {
-  mItems.append( item );
-
   mKeyMap.insert( item->key(), item );
 }
 
 RecipientItem::List RecipientsCollection::items() const
 {
-  return mItems;
+  return mKeyMap.values();
 }
 
 bool RecipientsCollection::hasEquivalentItem( RecipientItem *item ) const
@@ -282,6 +297,15 @@ bool RecipientsCollection::hasEquivalentItem( RecipientItem *item ) const
   return mKeyMap.find( item->key() ) != mKeyMap.end();
 }
 
+RecipientItem * RecipientsCollection::getEquivalentItem( RecipientItem *item) const
+{
+  QMap<QString, RecipientItem *>::ConstIterator it;
+  it = mKeyMap.find( item->key() );
+  if ( it == mKeyMap.end() )
+    return 0;
+  return (*it);
+}
+
 void RecipientsCollection::clear()
 {
   mKeyMap.clear();
@@ -289,13 +313,19 @@ void RecipientsCollection::clear()
 
 void RecipientsCollection::deleteAll()
 {
-  QMap<QString, RecipientItem *>::ConstIterator it;
-  for( it = mKeyMap.begin(); it != mKeyMap.end(); ++it ) {
-    delete *it;
+  if ( !isReferenceContainer() ) {
+    QMap<QString, RecipientItem *>::ConstIterator it;
+    for( it = mKeyMap.begin(); it != mKeyMap.end(); ++it ) {
+      delete *it;
+    }
   }
   clear();
 }
 
+QString RecipientsCollection::id() const
+{
+  return mId;
+}
 
 SearchLine::SearchLine( QWidget *parent, KListView *listView )
   : KListViewSearchLine( parent, listView )
@@ -315,6 +345,7 @@ RecipientsPicker::RecipientsPicker( QWidget *parent )
 #ifndef KDEPIM_NEW_DISTRLISTS
     , mDistributionListManager( 0 )
 #endif
+    ,mLdapSearchDialog( 0 )
 {
 //  KWin::setType( winId(), NET::Dock );
 
@@ -333,8 +364,8 @@ RecipientsPicker::RecipientsPicker( QWidget *parent )
   resLayout->addWidget( mCollectionCombo );
   resLayout->addItem(new QSpacerItem(1, 1, QSizePolicy::Expanding));
 
-  connect( mCollectionCombo, SIGNAL( highlighted( int ) ),
-    SLOT( updateList() ) );
+//  connect( mCollectionCombo, SIGNAL( highlighted( int ) ),
+//    SLOT( updateList() ) );
   connect( mCollectionCombo, SIGNAL( activated( int ) ),
     SLOT( updateList() ) );
 
@@ -369,6 +400,10 @@ RecipientsPicker::RecipientsPicker( QWidget *parent )
   label->setBuddy( label );
   connect( mSearchLine, SIGNAL( downPressed() ), SLOT( setFocusList() ) );
 
+  mSearchLDAPButton = new QPushButton( i18n("Search &Directory Service"), this );
+  searchLayout->addWidget( mSearchLDAPButton );
+  connect( mSearchLDAPButton, SIGNAL( clicked() ), SLOT( slotSearchLDAP() ) );
+
   QBoxLayout *buttonLayout = new QHBoxLayout( topLayout );
 
   buttonLayout->addStretch( 1 );
@@ -421,8 +456,6 @@ RecipientsPicker::~RecipientsPicker()
   delete mDistributionListManager;
 #endif
 
-  mAllRecipients->deleteAll();
-
   QMap<int,RecipientsCollection *>::ConstIterator it;
   for( it = mCollectionMap.begin(); it != mCollectionMap.end(); ++it ) {
     delete *it;
@@ -431,19 +464,18 @@ RecipientsPicker::~RecipientsPicker()
 
 void RecipientsPicker::initCollections()
 {
-  mAllRecipients = new RecipientsCollection;
-  mAllRecipients->setTitle( i18n("All") );
+  mAllRecipients = new RecipientsCollection( i18n("All") );
+  mAllRecipients->setReferenceContainer( true );
+  mDistributionLists = new RecipientsCollection( i18n("Distribution Lists") );
+  mSelectedRecipients = new RecipientsCollection( i18n("Selected Recipients") );
+
   insertCollection( mAllRecipients );
-
   insertAddressBook( mAddressBook );
-
-  insertDistributionLists();
-
+  insertCollection( mDistributionLists );
   insertRecentAddresses();
-
-  mSelectedRecipients = new RecipientsCollection;
-  mSelectedRecipients->setTitle( i18n("Selected Recipients") );
   insertCollection( mSelectedRecipients );
+
+  rebuildAllRecipientsList();
 }
 
 void RecipientsPicker::insertAddressBook( KABC::AddressBook *addressbook )
@@ -453,7 +485,7 @@ void RecipientsPicker::insertAddressBook( KABC::AddressBook *addressbook )
   QPtrList<KABC::Resource> resources = addressbook->resources();
   KABC::Resource *res;
   for( res = resources.first(); res; res = resources.next() ) {
-    RecipientsCollection *collection = new RecipientsCollection;
+    RecipientsCollection *collection = new RecipientsCollection( res->identifier() );
     collectionMap.insert( res, collection );
     collection->setTitle( res->resourceName() );
   }
@@ -471,7 +503,6 @@ void RecipientsPicker::insertAddressBook( KABC::AddressBook *addressbook )
       RecipientItem *item = new RecipientItem;
 #endif
       item->setAddressee( *it, *it3 );
-      mAllRecipients->addItem( item );
 
       QMap<KABC::Resource *,RecipientsCollection *>::ConstIterator collIt;
       collIt = collectionMap.find( it->resource() );
@@ -486,8 +517,8 @@ void RecipientsPicker::insertAddressBook( KABC::AddressBook *addressbook )
         catMapIt = categoryMap.find( *catIt );
         RecipientsCollection *collection;
         if ( catMapIt == categoryMap.end() ) {
-          collection = new RecipientsCollection;
-          collection->setTitle( *catIt );
+          collection = new RecipientsCollection( *catIt );
+          collection->setReferenceContainer( true );
           categoryMap.insert( *catIt, collection );
         } else {
           collection = *catMapIt;
@@ -506,22 +537,22 @@ void RecipientsPicker::insertAddressBook( KABC::AddressBook *addressbook )
   for( it3 = categoryMap.begin(); it3 != categoryMap.end(); ++it3 ) {
     insertCollection( *it3 );
   }
-  
+
+  insertDistributionLists();
+  rebuildAllRecipientsList();
   updateList();
 }
 
 void RecipientsPicker::insertDistributionLists()
 {
-  RecipientsCollection *collection = new RecipientsCollection;
-  collection->setTitle( i18n("Distribution Lists") );
+  mDistributionLists->deleteAll();
 
 #ifdef KDEPIM_NEW_DISTRLISTS
   QValueList<KPIM::DistributionList> lists = KPIM::DistributionList::allDistributionLists( mAddressBook );
   for ( uint i = 0; i < lists.count(); ++i ) {
     RecipientItem *item = new RecipientItem( mAddressBook );
     item->setDistributionList( lists[ i ] );
-    mAllRecipients->addItem( item );
-    collection->addItem( item );
+    mDistributionLists->addItem( item );
   }
 #else
   delete mDistributionListManager;
@@ -537,18 +568,14 @@ void RecipientsPicker::insertDistributionLists()
     KABC::DistributionList *list = mDistributionListManager->list( *listIt );
     RecipientItem *item = new RecipientItem;
     item->setDistributionList( list );
-    mAllRecipients->addItem( item );
-    collection->addItem( item );
+    mDistributionLists->addItem( item );
   }
 #endif
-
-  insertCollection( collection );
 }
 
 void RecipientsPicker::insertRecentAddresses()
 {
-  RecipientsCollection *collection = new RecipientsCollection;
-  collection->setTitle( i18n("Recent Addresses") );
+  RecipientsCollection *collection = new RecipientsCollection( i18n("Recent Addresses") );
 
   KConfig config( "kmailrc" );
   KABC::Addressee::List recents =
@@ -562,9 +589,6 @@ void RecipientsPicker::insertRecentAddresses()
     RecipientItem *item = new RecipientItem;
 #endif
     item->setAddressee( *it, (*it).preferredEmail() );
-    if ( !mAllRecipients->hasEquivalentItem( item ) ) {
-      mAllRecipients->addItem( item );
-    }
     collection->addItem( item );
   }
 
@@ -573,10 +597,17 @@ void RecipientsPicker::insertRecentAddresses()
 
 void RecipientsPicker::insertCollection( RecipientsCollection *coll )
 {
-  int index = mCollectionMap.count();
-
-  kdDebug() << "RecipientsPicker::insertCollection() " << coll->title()
-    << "  index: " << index << endl;
+  int index = 0;
+  QMap<int,RecipientsCollection *>::ConstIterator it;
+  for ( it = mCollectionMap.begin(); it != mCollectionMap.end(); ++it ) {
+    if ( (*it)->id() == coll->id() ) {
+      delete *it;
+      mCollectionMap.remove( index );
+      mCollectionMap.insert( index, coll );
+      return;
+    }
+    index++;
+  }
 
   mCollectionCombo->insertItem( coll->title(), index );
   mCollectionMap.insert( index, coll );
@@ -596,23 +627,32 @@ void RecipientsPicker::updateRecipient( const Recipient &recipient )
 
 void RecipientsPicker::setRecipients( const Recipient::List &recipients )
 {
-  RecipientItem::List allRecipients = mAllRecipients->items();
-  RecipientItem::List::ConstIterator itAll;
-  for( itAll = allRecipients.begin(); itAll != allRecipients.end(); ++itAll ) {
-    (*itAll)->setRecipientType( QString::null );
-  }
-
-  mSelectedRecipients->clear();
+  mSelectedRecipients->deleteAll();
 
   Recipient::List::ConstIterator it;
   for( it = recipients.begin(); it != recipients.end(); ++it ) {
     RecipientItem *item = 0;
-    for( itAll = allRecipients.begin(); itAll != allRecipients.end(); ++itAll ) {
-      if ( (*itAll)->recipient() == (*it).email() ) {
-        (*itAll)->setRecipientType( (*it).typeLabel() );
-        item = *itAll;
+
+    // if recipient is a distribution list, create
+    // a detached copy.
+    RecipientItem::List items = mDistributionLists->items();
+    RecipientItem::List::ConstIterator distIt;
+#ifdef KDEPIM_NEW_DISTRLISTS
+    for ( distIt = items.begin(); distIt != items.end(); ++distIt ) {
+      if ( (*it).email() == (*distIt)->name() ) {
+        item = new RecipientItem( mAddressBook );
+        item->setDistributionList( (*distIt)->distributionList() );
       }
     }
+#else
+    for ( distIt = items.begin(); distIt != items.end(); ++distIt ) {
+      if ( (*it).email() == (*distIt)->name() ) {
+        item = new RecipientItem();
+        item->setDistributionList( (*distIt)->distributionList() );
+      }
+    }
+#endif
+
     if ( !item ) {
       KABC::Addressee a;
       QString name;
@@ -627,9 +667,9 @@ void RecipientsPicker::setRecipients( const Recipient::List &recipients )
       item = new RecipientItem;
 #endif
       item->setAddressee( a, a.preferredEmail() );
-      item->setRecipientType( (*it).typeLabel() );
-      mAllRecipients->addItem( item );
     }
+
+    item->setRecipientType( (*it).typeLabel() );
     mSelectedRecipients->addItem( item );
   }
 
@@ -655,6 +695,25 @@ void RecipientsPicker::setDefaultType( Recipient::Type type )
   }
 }
 
+void RecipientsPicker::rebuildAllRecipientsList()
+{
+  mAllRecipients->clear();
+
+  QMap<int,RecipientsCollection *>::ConstIterator it;
+  for( it = mCollectionMap.begin(); it != mCollectionMap.end(); ++it ) {
+    // skip self
+    if ( (*it) == mAllRecipients )
+      continue;
+
+    RecipientItem::List coll = (*it)->items();
+
+    RecipientItem::List::ConstIterator rcptIt;
+    for ( rcptIt = coll.begin(); rcptIt != coll.end(); ++rcptIt ) {
+      mAllRecipients->addItem( *rcptIt );
+    }
+  }
+}
+
 void RecipientsPicker::updateList()
 {
   mRecipientList->clear();
@@ -664,6 +723,14 @@ void RecipientsPicker::updateList()
   RecipientItem::List items = coll->items();
   RecipientItem::List::ConstIterator it;
   for( it = items.begin(); it != items.end(); ++it ) {
+    if ( coll != mSelectedRecipients ) {
+      RecipientItem *selItem = mSelectedRecipients->getEquivalentItem( *it );
+      if ( selItem ) {
+        (*it)->setRecipientType( selItem->recipientType() );
+      } else {
+        (*it)->setRecipientType( QString() );
+      }
+    }
     new RecipientViewItem( *it, mRecipientList );
   }
 
@@ -774,4 +841,38 @@ void RecipientsPicker::resetSearch()
   mSearchLine->setText( QString::null );
 }
 
+void RecipientsPicker::slotSearchLDAP()
+{
+    if ( !mLdapSearchDialog ) {
+        mLdapSearchDialog = new KPIM::LDAPSearchDialog( this );
+        connect( mLdapSearchDialog, SIGNAL( addresseesAdded() ),
+                 SLOT(ldapSearchResult() ) );
+    }
+    mLdapSearchDialog->setSearchText( mSearchLine->text() );
+    mLdapSearchDialog->show();
+
+}
+
+void RecipientsPicker::ldapSearchResult()
+{
+    QStringList emails = QStringList::split(',', mLdapSearchDialog->selectedEMails() );
+    QStringList::iterator it( emails.begin() );
+    QStringList::iterator end( emails.end() );
+    for ( ; it != end; ++it ){
+        QString name;
+        QString email;
+        KPIM::getNameAndMail( (*it), name, email );
+        KABC::Addressee ad;
+        ad.setNameFromString( name );
+        ad.insertEmail( email );
+#ifdef KDEPIM_NEW_DISTRLISTS
+        RecipientItem *item = new RecipientItem( mAddressBook );
+#else
+        RecipientItem *item = new RecipientItem;
+#endif
+        item->setAddressee( ad, ad.preferredEmail() );
+        emit pickedRecipient( Recipient( item->recipient(), Recipient::Undefined ) );
+    }
+}
+
 #include "recipientspicker.moc"
