@@ -10,7 +10,7 @@
     version 2.0, as published by the Free Software Foundation.
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software Foundation,
-    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, US
+    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
 #ifndef __KMAIL_SIGNATURECONFIGURATOR_H__
@@ -54,7 +54,7 @@ namespace KMail {
 
     /**
        Conveniece method.
-       @return a @see Signature object representing the state of the widgets.
+       @return a Signature object representing the state of the widgets.
      **/
     Signature signature() const;
     /**
