@@ -12,8 +12,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
 */
 
@@ -329,7 +329,7 @@ KMobileDevice * KMobileFactory::chooseDeviceDialog( QWidget *parent,
      answ = KMessageBox::questionYesNo(parent,
 		i18n( "<qt>You have no mobile devices configured yet.<p>"
 			"Do you want to add a device now ?</qt>" ),
-		i18n( "KDE Mobile Device Access" ) );
+		i18n( "KDE Mobile Device Access" ), KStdGuiItem::add(), i18n("Do Not Add") );
      if (answ != KMessageBox::Yes)
 	return 0L;
      // add a new device
