@@ -11,7 +11,7 @@
     (at your option) any later version.
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software Foundation,
-    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
 #include <qdragobject.h>
@@ -129,11 +129,7 @@ void KNHdrViewItem::paintCell( QPainter *p, const QColorGroup &cg, int column, i
       pen.setColor( greyColor() );
     else
       pen.setColor( normalColor() );
-#if KDE_IS_VERSION(3,3,90)
     base = backgroundColor( column );
-#else
-    base = backgroundColor();
-#endif
   }
 
   p->setPen( pen );
