@@ -1067,7 +1067,9 @@ void KNMainWidget::slotCollectionSelected(QListViewItem *i)
   h_drView->clear();
   slotArticleSelected(0);
 
-  // mark all articles in current group as not new
+  // mark all articles in current group as not new/read
+  if ( knGlobals.configManager()->readNewsNavigation()->leaveGroupMarkAsRead() )
+    a_rtManager->setAllRead( true );
   a_rtManager->setAllNotNew();
 
   if(i) {
