@@ -15,8 +15,8 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ MA  02110-1301, USA.
 
  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
@@ -35,6 +35,8 @@
 
 #include "resourcenotes.h"
 
+#include <kurl.h>
+
 #include <libkcal/calendarlocal.h>
 
 
@@ -44,6 +46,8 @@ public:
     ResourceLocal( const KConfig* );
     virtual ~ResourceLocal();
 
+    virtual void writeConfig( KConfig *config );
+
     /**
      * Load resource data.
      */
@@ -54,6 +58,9 @@ public:
      */
     virtual bool save();
 
+    virtual KURL url() const { return mURL; } ;
+    virtual void setURL(const KURL& url) { mURL = url; } ;
+
     virtual bool addNote( KCal::Journal* );
     virtual bool deleteNote( KCal::Journal* );
 
@@ -61,6 +68,7 @@ public:
 
 protected:
     KCal::CalendarLocal mCalendar;
+    KURL mURL;
 };
 
 
