@@ -60,7 +60,7 @@ TodoSummaryWidget::TodoSummaryWidget( TodoPlugin *plugin,
 
   QPixmap icon = KGlobal::iconLoader()->loadIcon( "kontact_todo",
                    KIcon::Desktop, KIcon::SizeMedium );
-  QWidget *header = createHeader( this, icon, i18n( "To-dos" ) );
+  QWidget *header = createHeader( this, icon, i18n( "To-do" ) );
   mainLayout->addWidget( header );
 
   mLayout = new QGridLayout( mainLayout, 7, 4, 3 );
@@ -226,6 +226,7 @@ void TodoSummaryWidget::completeTodo( const QString &uid )
 void TodoSummaryWidget::popupMenu( const QString &uid )
 {
   KPopupMenu popup( this );
+  QToolTip::remove( this );
   popup.insertItem( i18n( "&Edit To-do..." ), 0 );
   popup.insertItem( KGlobal::iconLoader()->loadIcon( "editdelete", KIcon::Small),
                     i18n( "&Delete To-do" ), 1 );
