@@ -56,7 +56,10 @@ class TodoSummaryWidget : public Kontact::Summary
 
   private slots:
     void updateView();
-    void selectEvent( const QString &uid );
+    void popupMenu( const QString &uid );
+    void viewTodo( const QString &uid );
+    void removeTodo( const QString &uid );
+    void completeTodo( const QString &uid );
 
   private:
     TodoPlugin *mPlugin;
