@@ -28,8 +28,6 @@
 
 using namespace KOrg;
 
-AboutData *AboutData::mSelf = 0;
-
 AboutData::AboutData()
   : KAboutData( "korganizer", I18N_NOOP("KOrganizer"), korgVersion,
                 I18N_NOOP("A Personal Organizer for KDE"),
@@ -75,9 +73,3 @@ AboutData::AboutData()
   addCredit("Thomas Zander");
   addCredit("Fester Zigterman");
 }
-
-AboutData *AboutData::self()
-{
-  if ( !mSelf ) mSelf = new AboutData;
-  return mSelf;
-}
