@@ -50,9 +50,12 @@
 #include <libkcal/htmlexport.h>
 #include <libkcal/htmlexportsettings.h>
 
+#include <libkmime/kmime_message.h>
+
 #include <dcopclient.h>
 #include <kaction.h>
 #include <kfiledialog.h>
+#include <kiconloader.h>
 #include <kio/netaccess.h>
 #include <kkeydialog.h>
 #include <kpopupmenu.h>
@@ -67,6 +70,7 @@
 #include <kactionclasses.h>
 
 #include <qapplication.h>
+#include <qcursor.h>
 #include <qtimer.h>
 #include <qlabel.h>
 
@@ -342,7 +346,7 @@ void ActionManager::initActions()
                             mCalendarView->viewManager(),
                             SLOT( showNextXView() ),
                             mACollection, "view_nextx" );
-  mNextXDays->setText( i18n( "&Next Day", "&Next %n Days",
+  mNextXDays->setText( i18n( "&Next Day", "Ne&xt %n Days",
                              KOPrefs::instance()->mNextXDays ) );
   new KAction( i18n("W&ork Week"),
                KOGlobals::self()->smallIcon( "5days" ), 0,
@@ -368,6 +372,10 @@ void ActionManager::initActions()
                KOGlobals::self()->smallIcon( "journal" ), 0,
                mCalendarView->viewManager(), SLOT( showJournalView() ),
                mACollection, "view_journal" );
+  new KAction( i18n("&Timeline View"),
+               KOGlobals::self()->smallIcon( "timeline" ), 0,
+               mCalendarView->viewManager(), SLOT( showTimelineView() ),
+               mACollection, "view_timeline" );
 
   //~~~~~~~~~~~~~~~~~~~~~~~~~~~ FILTERS ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   new KAction( i18n("&Refresh"), 0,
@@ -525,6 +533,11 @@ void ActionManager::initActions()
   connect( mCalendarView,SIGNAL( groupEventsSelected( bool ) ),
            action,SLOT( setEnabled( bool ) ) );
 
+  mForwardEvent = new KAction( i18n("&Send as iCalendar..."), "mail_forward", 0,
+                               mCalendarView, SLOT(schedule_forward()),
+                               mACollection, "schedule_forward" );
+  mForwardEvent->setEnabled( false );
+
   action = new KAction( i18n("&Mail Free Busy Information..."), 0,
                         mCalendarView, SLOT( mailFreeBusy() ),
                         mACollection, "mail_freebusy" );
@@ -1476,6 +1489,7 @@ void ActionManager::enableIncidenceActions( bool enabled )
   mCopyAction->setEnabled( enabled );
   mDeleteAction->setEnabled( enabled );
   mPublishEvent->setEnabled( enabled );
+  mForwardEvent->setEnabled( enabled );
 }
 
 void ActionManager::keyBindings()
@@ -1531,6 +1545,101 @@ void ActionManager::openEventEditor( const QString& summary,
   mCalendarView->newEvent( summary, description, attachment, attendees );
 }
 
+void ActionManager::openEventEditor( const QString & summary,
+                                     const QString & description,
+                                     const QString & uri,
+                                     const QString & file,
+                                     const QStringList & attendees,
+                                     const QString & attachmentMimetype )
+{
+  int action = KOPrefs::instance()->defaultEmailAttachMethod();
+  if ( attachmentMimetype != "message/rfc822" ) {
+    action = KOPrefs::Link;
+  } else if ( KOPrefs::instance()->defaultEmailAttachMethod() == KOPrefs::Ask ) {
+    KPopupMenu *menu = new KPopupMenu( 0 );
+    menu->insertItem( i18n("Attach as &link"), KOPrefs::Link );
+    menu->insertItem( i18n("Attach &inline"), KOPrefs::InlineFull );
+    menu->insertItem( i18n("Attach inline &without attachments"), KOPrefs::InlineBody );
+    menu->insertSeparator();
+    menu->insertItem( SmallIcon("cancel"), i18n("C&ancel"), KOPrefs::Ask );
+    action = menu->exec( QCursor::pos(), 0 );
+    delete menu;
+  }
+
+  QString attData;
+  KTempFile tf;
+  tf.setAutoDelete( true );
+  switch ( action ) {
+    case KOPrefs::Ask:
+      return;
+    case KOPrefs::Link:
+      attData = uri;
+      break;
+    case KOPrefs::InlineFull:
+      attData = file;
+      break;
+    case KOPrefs::InlineBody:
+    {
+      QFile f( file );
+      if ( !f.open( IO_ReadOnly ) )
+        return;
+      KMime::Message *msg = new KMime::Message();
+      msg->setContent( QCString( f.readAll() ) );
+      QCString head = msg->head();
+      msg->parse();
+      if ( msg == msg->textContent() || msg->textContent() == 0 ) { // no attachments
+        attData = file;
+      } else {
+        if ( KMessageBox::warningContinueCancel( 0,
+              i18n("Removing attachments from an email might invalidate its signature."),
+              i18n("Remove Attachments"), KStdGuiItem::cont(), "BodyOnlyInlineAttachment" )
+              != KMessageBox::Continue )
+          return;
+        // due to kmime shortcomings in KDE3, we need to assemble the result manually
+        int begin = 0;
+        int end = head.find( '\n' );
+        bool skipFolded = false;
+        while ( end >= 0 && end > begin ) {
+          if ( head.find( "Content-Type:", begin, false ) != begin &&
+                head.find( "Content-Transfer-Encoding:", begin, false ) != begin &&
+                !(skipFolded && (head[begin] == ' ' || head[end] == '\t')) ) {
+            QCString line = head.mid( begin, end - begin );
+            tf.file()->writeBlock( line.data(), line.length() );
+            tf.file()->writeBlock( "\n", 1 );
+            skipFolded = false;
+          } else {
+            skipFolded = true;
+          }
+
+          begin = end + 1;
+          end = head.find( '\n', begin );
+          if ( end < 0 && begin < (int)head.length() )
+            end = head.length() - 1;
+        }
+        QCString cte = msg->textContent()->contentTransferEncoding()->as7BitString();
+        if ( !cte.stripWhiteSpace().isEmpty() ) {
+          tf.file()->writeBlock( cte.data(), cte.length() );
+          tf.file()->writeBlock( "\n", 1 );
+        }
+        QCString ct = msg->textContent()->contentType()->as7BitString();
+        if ( !ct.stripWhiteSpace().isEmpty() )
+          tf.file()->writeBlock( ct.data(), ct.length() );
+        tf.file()->writeBlock( "\n", 1 );
+        tf.file()->writeBlock( msg->textContent()->body() );
+        attData = tf.name();
+      }
+      tf.close();
+      delete msg;
+      break;
+    }
+    default:
+      // menu could have been closed by cancel, if so, do nothing
+      return;
+  }
+
+  mCalendarView->newEvent( summary, description, attData, attendees, attachmentMimetype, action != KOPrefs::Link );
+}
+
 void ActionManager::openTodoEditor( const QString& text )
 {
   mCalendarView->newTodo( text );
@@ -1551,6 +1660,44 @@ void ActionManager::openTodoEditor( const QString& summary,
   mCalendarView->newTodo( summary, description, attachment, attendees );
 }
 
+void ActionManager::openTodoEditor(const QString & summary,
+                                   const QString & description,
+                                   const QString & uri,
+                                   const QString & file,
+                                   const QStringList & attendees,
+                                   const QString & attachmentMimetype)
+{
+  int action = KOPrefs::instance()->defaultTodoAttachMethod();
+  if ( attachmentMimetype != "message/rfc822" ) {
+    action = KOPrefs::TodoAttachLink;
+  } else if ( KOPrefs::instance()->defaultTodoAttachMethod() == KOPrefs::TodoAttachAsk ) {
+    KPopupMenu *menu = new KPopupMenu( 0 );
+    menu->insertItem( i18n("Attach as &link"), KOPrefs::TodoAttachLink );
+    menu->insertItem( i18n("Attach &inline"), KOPrefs::TodoAttachInlineFull );
+    menu->insertSeparator();
+    menu->insertItem( SmallIcon("cancel"), i18n("C&ancel"), KOPrefs::TodoAttachAsk );
+    action = menu->exec( QCursor::pos(), 0 );
+    delete menu;
+  }
+
+  QString attData;
+  switch ( action ) {
+    case KOPrefs::TodoAttachAsk:
+      return;
+    case KOPrefs::TodoAttachLink:
+      attData = uri;
+      break;
+    case KOPrefs::TodoAttachInlineFull:
+      attData = file;
+      break;
+    default:
+      // menu could have been closed by cancel, if so, do nothing
+      return;
+  }
+
+  mCalendarView->newTodo( summary, description, attData, attendees, attachmentMimetype, action != KOPrefs::Link );
+}
+
 void ActionManager::openJournalEditor( const QDate& date )
 {
   mCalendarView->newJournal( date );
@@ -1600,6 +1747,12 @@ void ActionManager::goDate( const QString& date )
   goDate( KGlobal::locale()->readDate( date ) );
 }
 
+void ActionManager::showDate(const QDate & date)
+{
+  mCalendarView->showDate( date );
+}
+
+
 void ActionManager::updateUndoAction( const QString &text )
 {
   if ( text.isNull() ) {
@@ -1755,6 +1908,46 @@ void ActionManager::slotAutoArchive()
   slotAutoArchivingSettingsModified();
 }
 
+void ActionManager::loadProfile( const QString & path )
+{
+  KOPrefs::instance()->writeConfig();
+  KConfig* const cfg = KOPrefs::instance()->config();
+
+  const KConfig profile( path+"/korganizerrc", /*read-only=*/false, /*useglobals=*/false );
+  const QStringList groups = profile.groupList();
+  for ( QStringList::ConstIterator it = groups.begin(), end = groups.end(); it != end; ++it )
+  {
+    cfg->setGroup( *it );
+    typedef QMap<QString, QString> StringMap;
+    const StringMap entries = profile.entryMap( *it );
+    for ( StringMap::ConstIterator it2 = entries.begin(), end = entries.end(); it2 != end; ++it2 )
+    {
+      cfg->writeEntry( it2.key(), it2.data() );
+    }
+  }
+
+  cfg->sync();
+  KOPrefs::instance()->readConfig();
+}
+
+namespace {
+    void copyConfigEntry( KConfig* source, KConfig* dest, const QString& group, const QString& key, const QString& defaultValue=QString() )
+    {
+        source->setGroup( group );
+        dest->setGroup( group );
+        dest->writeEntry( key, source->readEntry( key, defaultValue ) );
+    }
+}
+
+void ActionManager::saveToProfile( const QString & path ) const
+{
+  KOPrefs::instance()->writeConfig();
+  KConfig* const cfg = KOPrefs::instance()->config();
+
+  KConfig profile( path+"/korganizerrc", /*read-only=*/false, /*useglobals=*/false );
+  ::copyConfigEntry( cfg, &profile, "Views", "Agenda View Calendar Display" );
+}
+
 QWidget *ActionManager::dialogParent()
 {
   return mCalendarView->topLevelWidget();
