@@ -18,11 +18,19 @@
 
 #include "agendaview.h"
 
+#include <libkcal/calendarresources.h>
+
 using namespace KOrg;
 
 AgendaView::AgendaView(Calendar * cal, QWidget * parent, const char * name) :
     KOEventView( cal, parent, name )
 {
+  KCal::CalendarResources *calres = dynamic_cast<KCal::CalendarResources*>( cal );
+  if ( calres ) {
+    connect( calres, SIGNAL(signalResourceAdded(ResourceCalendar *)), SLOT(resourcesChanged()) );
+    connect( calres, SIGNAL(signalResourceModified( ResourceCalendar *)), SLOT(resourcesChanged()) );
+    connect( calres, SIGNAL(signalResourceDeleted(ResourceCalendar *)), SLOT(resourcesChanged()) );
+  }
 }
 
 #include "agendaview.moc"
