@@ -1015,7 +1015,6 @@ void CalendarView::newTodo( const QString &summary, const QString &description,
   KOTodoEditor *todoEditor = mDialogManager->getTodoEditor();
   connectIncidenceEditor( todoEditor );
   todoEditor->newTodo();
-  todoEditor->setDates( QDateTime(), false );
   todoEditor->setTexts( summary, description );
   todoEditor->addAttachments( attachments, attachmentMimetypes, inlineAttachment );
   todoEditor->addAttendees( attendees );
@@ -1884,6 +1883,11 @@ void CalendarView::copyIncidence(Incidence *)
   edit_copy();
 }
 
+void CalendarView::pasteIncidence()
+{
+  edit_paste();
+}
+
 void CalendarView::showIncidence( Incidence *incidence )
 {
   KOEventViewerDialog *eventViewer = new KOEventViewerDialog( this );
@@ -1891,7 +1895,7 @@ void CalendarView::showIncidence( Incidence *incidence )
   eventViewer->show();
 }
 
-bool CalendarView::editIncidence( Incidence *incidence )
+bool CalendarView::editIncidence( Incidence *incidence, bool isCounter )
 {
   kdDebug(5850) << "CalendarView::editEvent()" << endl;
 
@@ -1913,7 +1917,7 @@ bool CalendarView::editIncidence( Incidence *incidence )
     return true;
   }
 
-  if ( !mChanger->beginChange( incidence ) ) {
+  if ( !isCounter && !mChanger->beginChange( incidence ) ) {
     warningChangeFailed( incidence );
     showIncidence( incidence );
     return false;
@@ -2278,4 +2282,10 @@ void CalendarView::moveIncidenceTo( Incidence *incmove, const QDate &dt )
   delete oldIncidence;
 }
 
+void CalendarView::resourcesChanged()
+{
+  mViewManager->resourcesChanged();
+  updateView();
+}
+
 #include "calendarview.moc"
