@@ -287,7 +287,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
     /** Create a read-only viewer dialog for the supplied incidence. It calls the correct showXXX method*/
     void showIncidence( Incidence * );
     /** Create an editor for the supplied incidence. It calls the correct editXXX method*/
-    bool editIncidence( Incidence * );
+    bool editIncidence( Incidence *incidence, bool isCounter = false );
     /**
       Delete the supplied incidence. It calls the correct deleteXXX method
       @param force If true, all recurrences and sub-todos (if applicable) will be
@@ -302,6 +302,11 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
       Copies the selected incidence using the edit_copy() method
     */
     void copyIncidence( Incidence *);
+    /**
+      Pastes the curren incidence using the edit_paste() method
+    */
+    void pasteIncidence();
+
     /** Delete the supplied todo and all sub-todos */
     void deleteSubTodosIncidence ( Todo *todo );
     /**
@@ -517,6 +522,9 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
     void addIncidenceOn( Incidence *, const QDate & );
     void moveIncidenceTo( Incidence *, const QDate & );
     void filterActivated( int filterNum );
+
+    void resourcesChanged();
+
   protected slots:
     /** Select a view or adapt the current view to display the specified dates. */
     void showDates( const KCal::DateList & );
