@@ -47,6 +47,8 @@
 #include <libkcal/event.h>
 #include <libkcal/freebusy.h>
 
+#include <libemailfunctions/email.h>
+
 #include <kdgantt/KDGanttView.h>
 #include <kdgantt/KDGanttViewTaskItem.h>
 #include <kdgantt/KDGanttViewSubwidgets.h>
@@ -254,13 +256,6 @@ KOEditorFreeBusy::KOEditorFreeBusy( int spacing, QWidget *parent,
   connect( button, SIGNAL( clicked() ), SLOT( slotCenterOnStart() ) );
   controlLayout->addWidget( button );
 
-  button = new QPushButton( i18n( "Zoom to Fit" ), this );
-  QWhatsThis::add( button,
-		   i18n("Zooms the Gantt chart so that you can see the "
-			"entire duration of the event on it.") );
-  connect( button, SIGNAL( clicked() ), SLOT( slotZoomToTime() ) );
-  controlLayout->addWidget( button );
-
   controlLayout->addStretch( 1 );
 
   button = new QPushButton( i18n( "Pick Date" ), this );
@@ -294,7 +289,7 @@ KOEditorFreeBusy::KOEditorFreeBusy( int spacing, QWidget *parent,
   }
   mGanttView->setHeaderVisible( true );
   mGanttView->setScale( KDGanttView::Hour );
-  mGanttView->setShowHeaderPopupMenu( true, true, true, false, false, true );
+  mGanttView->setShowHeaderPopupMenu( false, false, false, false, false, false );
   // Initially, show 15 days back and forth
   // set start to even hours, i.e. to 12:AM 0 Min 0 Sec
   QDateTime horizonStart = QDateTime( QDateTime::currentDateTime()
@@ -344,6 +339,13 @@ KOEditorFreeBusy::KOEditorFreeBusy( int spacing, QWidget *parent,
   initEditWidgets( this, topLayout );
   connect( mRemoveButton, SIGNAL(clicked()),
            SLOT(removeAttendee()) );
+
+  slotOrganizerChanged( mOrganizerCombo->currentText() );
+  connect( mOrganizerCombo, SIGNAL( activated(const QString&) ),
+           this, SLOT( slotOrganizerChanged(const QString&) ) );
+
+  //suppress the buggy consequences of clicks on the time header widget
+  mGanttView->timeHeaderWidget()->installEventFilter( this );
 }
 
 KOEditorFreeBusy::~KOEditorFreeBusy()
@@ -863,4 +865,67 @@ void KOEditorFreeBusy::listViewClicked(int button, KDGanttViewItem * item)
     addNewAttendee();
 }
 
+void KOEditorFreeBusy::slotOrganizerChanged(const QString & newOrganizer)
+{
+  if (newOrganizer==mCurrentOrganizer) return;
+
+  QString name;
+  QString email;
+  bool success = KPIM::getNameAndMail( newOrganizer, name, email );
+
+  if (!success) return;
+//
+
+  Attendee *currentOrganizerAttendee = 0;
+  Attendee *newOrganizerAttendee = 0;
+
+  FreeBusyItem *anItem =
+    static_cast<FreeBusyItem *>( mGanttView->firstChild() );
+  while( anItem ) {
+    Attendee *attendee = anItem->attendee();
+    if( attendee->fullName() == mCurrentOrganizer )
+      currentOrganizerAttendee = attendee;
+
+    if( attendee->fullName() == newOrganizer )
+      newOrganizerAttendee = attendee;
+
+    anItem = static_cast<FreeBusyItem *>( anItem->nextSibling() );
+  }
+
+  int answer = KMessageBox::No;
+
+  if (currentOrganizerAttendee) {
+    answer = KMessageBox::questionYesNo( this, i18n("You are changing the organiser of "
+                                                    "this event, who is also attending, "
+                                                    "do you want to change that attendee "
+                                                    "as well?") );
+  } else {
+    answer = KMessageBox::Yes;
+  }
+
+  if (answer==KMessageBox::Yes) {
+    if (currentOrganizerAttendee) {
+      removeAttendee( currentOrganizerAttendee );
+    }
+
+    if (!newOrganizerAttendee) {
+      Attendee *a = new Attendee( name, email, true );
+      insertAttendee( a, false );
+      updateAttendee();
+    }
+  }
+
+  mCurrentOrganizer = newOrganizer;
+}
+
+bool KOEditorFreeBusy::eventFilter( QObject *watched, QEvent *event )
+{
+  if ( watched == mGanttView->timeHeaderWidget() &&
+       event->type() >= QEvent::MouseButtonPress && event->type() <= QEvent::MouseMove ) {
+    return true;
+  } else {
+    return KOAttendeeEditor::eventFilter( watched, event );
+  }
+}
+
 #include "koeditorfreebusy.moc"
