@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -54,7 +54,7 @@ class KOEditorGeneralTodo : public KOEditorGeneral
     /** Set widgets to default values */
     void setDefaults( const QDateTime &due, bool allDay );
     /** Read todo object and setup widgets accordingly */
-    void readTodo(Todo *);
+    void readTodo(Todo *todo, Calendar *calendar);
     /** Write todo settings to event object */
     void writeTodo(Todo *);
 
@@ -96,7 +96,7 @@ class KOEditorGeneralTodo : public KOEditorGeneral
     QLabel                  *mCompletedLabel;
     QLabel                  *mPriorityLabel;
     QComboBox               *mPriorityCombo;
-    
+
     KDateEdit               *mCompletionDateEdit;
     KTimeEdit               *mCompletionTimeEdit;
 
