@@ -51,6 +51,7 @@ class KOEventPopupMenu : public QPopupMenu {
   protected slots:
     void popupShow();
     void popupEdit();
+    void popupPaste();
     void print();
     void popupDelete();
     void popupCut();
@@ -58,6 +59,7 @@ class KOEventPopupMenu : public QPopupMenu {
     void popupAlarm();
     void dissociateOccurrence();
     void dissociateFutureOccurrence();
+    void forward();
 
   signals:
     void editIncidenceSignal(Incidence *);
@@ -65,6 +67,7 @@ class KOEventPopupMenu : public QPopupMenu {
     void deleteIncidenceSignal(Incidence *);
     void cutIncidenceSignal(Incidence *);
     void copyIncidenceSignal(Incidence *);
+    void pasteIncidenceSignal();
     void toggleAlarmSignal(Incidence *);
     void dissociateOccurrenceSignal( Incidence *, const QDate & );
     void dissociateFutureOccurrenceSignal( Incidence *, const QDate & );
