@@ -190,24 +190,34 @@ void KOGroupware::incomingDirChanged( const QString& path )
       if( (*it)->email() == receiver ) {
         if ( action.startsWith( "accepted" ) )
           (*it)->setStatus( KCal::Attendee::Accepted );
-        else if ( action.startsWith( "tentative" ) || action.startsWith( "counter" ) )
+        else if ( action.startsWith( "tentative" ) )
+          (*it)->setStatus( KCal::Attendee::Tentative );
+        else if ( KOPrefs::instance()->outlookCompatCounterProposals() && action.startsWith( "counter" ) )
           (*it)->setStatus( KCal::Attendee::Tentative );
         else if ( action.startsWith( "delegated" ) )
           (*it)->setStatus( KCal::Attendee::Delegated );
         break;
       }
     }
-    scheduler.acceptTransaction( incidence, method, status );
+    if ( KOPrefs::instance()->outlookCompatCounterProposals() || !action.startsWith( "counter" ) )
+      scheduler.acceptTransaction( incidence, method, status );
   } else if ( action.startsWith( "cancel" ) )
     // Delete the old incidence, if one is present
     scheduler.acceptTransaction( incidence, KCal::Scheduler::Cancel, status );
-  else if ( action.startsWith( "reply" ) )
-    scheduler.acceptTransaction( incidence, method, status );
-  else
+  else if ( action.startsWith( "reply" ) ) {
+    if ( method != Scheduler::Counter ) {
+      scheduler.acceptTransaction( incidence, method, status );
+    } else {
+      // accept counter proposal
+      scheduler.acceptCounterProposal( incidence );
+      // send update to all attendees
+      sendICalMessage( mView, Scheduler::Request, incidence );
+    }
+  } else
     kdError(5850) << "Unknown incoming action " << action << endl;
 
   if ( action.startsWith( "counter" ) ) {
-    mView->editIncidence( incidence );
+    mView->editIncidence( incidence, true );
     KOIncidenceEditor *tmp = mView->editorDialog( incidence );
     tmp->selectInvitationCounterProposal( true );
   }
@@ -323,5 +333,22 @@ bool KOGroupware::sendICalMessage( QWidget* parent,
     return false;
 }
 
+void KOGroupware::sendCounterProposal(KCal::Calendar *calendar, KCal::Event * oldEvent, KCal::Event * newEvent) const
+{
+  if ( !oldEvent || !newEvent || *oldEvent == *newEvent || !KOPrefs::instance()->mUseGroupwareCommunication )
+    return;
+  if ( KOPrefs::instance()->outlookCompatCounterProposals() ) {
+    Incidence* tmp = oldEvent->clone();
+    tmp->setSummary( i18n("Counter proposal: %1").arg( newEvent->summary() ) );
+    tmp->setDescription( newEvent->description() );
+    tmp->addComment( i18n("Proposed new meeting time: %1 - %2").arg( newEvent->dtStartStr(), newEvent->dtEndStr() ) );
+    KCal::MailScheduler scheduler( calendar );
+    scheduler.performTransaction( tmp, Scheduler::Reply );
+    delete tmp;
+  } else {
+    KCal::MailScheduler scheduler( calendar );
+    scheduler.performTransaction( newEvent, Scheduler::Counter );
+  }
+}
 
 #include "kogroupware.moc"
