@@ -94,7 +94,7 @@ void KOJournalEditor::setupGeneral()
   mGeneral->finishSetup();
 }
 
-void KOJournalEditor::editIncidence( Incidence *incidence )
+void KOJournalEditor::editIncidence( Incidence *incidence, Calendar * )
 {
   Journal *journal=dynamic_cast<Journal*>(incidence);
   if (journal)
@@ -106,48 +106,31 @@ void KOJournalEditor::editIncidence( Incidence *incidence )
   }
 }
 
-void KOJournalEditor::newJournal( const QDate &date )
+
+void KOJournalEditor::newJournal()
 {
   init();
-
   mJournal = 0;
-  setDefaults( date );
+  loadDefaults();
 }
 
-void KOJournalEditor::newJournal( const QString &text )
+void KOJournalEditor::setTexts( const QString &summary, const QString &description )
 {
-  init();
-
-  mJournal = 0;
-
-  loadDefaults();
-
-  mGeneral->setDescription( text );
-
-  int pos = text.find( "\n" );
-  if ( pos > 0 ) {
-    mGeneral->setSummary( text.left( pos ) );
-    mGeneral->setDescription( text );
+  if ( description.isEmpty() && summary.contains("\n") ) {
+    mGeneral->setDescription( summary );
+    int pos = summary.find( "\n" );
+    mGeneral->setSummary( summary.left( pos ) );
   } else {
-    mGeneral->setSummary( text );
+    mGeneral->setSummary( summary );
+    mGeneral->setDescription( description );
   }
 }
 
-void KOJournalEditor::newJournal( const QString &text, const QDate &date )
-{
-  init();
 
-  mJournal = 0;
-
-  loadDefaults();
-
-  mGeneral->setDescription( text );
-  mGeneral->setDate( date );
-}
 
 void KOJournalEditor::loadDefaults()
 {
-  setDefaults( QDate::currentDate() );
+  setDate( QDate::currentDate() );
 }
 
 bool KOJournalEditor::processInput()
@@ -166,7 +149,7 @@ bool KOJournalEditor::processInput()
 
     writeJournal( mJournal );
 
-    if ( !mChanger->addIncidence( mJournal ) ) {
+    if ( !mChanger->addIncidence( mJournal, this ) ) {
       KODialogManager::errorSaveIncidence( this, mJournal );
       delete mJournal;
       mJournal = 0;
@@ -187,7 +170,7 @@ void KOJournalEditor::deleteJournal()
   reject();
 }
 
-void KOJournalEditor::setDefaults( const QDate &date )
+void KOJournalEditor::setDate( const QDate &date )
 {
   mGeneral->setDefaults( date );
   mDetails->setDefaults();
