@@ -85,6 +85,7 @@ class KDE_EXPORT KOPrefs : public KOPrefsBase
 
     void setCategoryColor( const QString &cat, const QColor &color );
     QColor *categoryColor( const QString &cat );
+    bool hasCategoryColor( const QString &cat ) const;
 
     void setResourceColor ( const QString &, const QColor & );
     QColor* resourceColor( const QString & );
@@ -105,6 +106,8 @@ class KDE_EXPORT KOPrefs : public KOPrefsBase
     QFont mDefaultTimeBarFont;
     QFont mDefaultMonthViewFont;
 
+    QStringList mMyAddrBookMails;
+
   public: // Do not use - except in KOPrefsDialogMain
     QString mName;
     QString mEmail;
