@@ -22,7 +22,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -109,11 +109,6 @@ class KOrganizer : public KPartsMainWindow, public KOrgMainWindow
     /** write current state to config file. */
     void writeSettings();
 
-    /** Open toolbar configuration dialog */
-    void configureToolbars();
-
-    void toggleStatusBar();
-
     void statusBarPressed( int );
 
     /** Sets title of window according to filename and modification state */
@@ -137,8 +132,6 @@ class KOrganizer : public KPartsMainWindow, public KOrgMainWindow
     CalendarView *mCalendarView;  // Main view widget
     KOrg::Part::List mParts; // List of parts loaded
 
-    KToggleAction *mStatusBarAction;
-
     // status bar ids
     enum { ID_HISTORY, ID_GENERAL, ID_ACTIVE, ID_MESSAGES_IN, ID_MESSAGES_OUT };
     ActionManager *mActionManager;
