@@ -89,3 +89,15 @@ bool KOrganizerIfaceImpl::addIncidence( const QString &ical )
 {
   return mActionManager->addIncidence( ical );
 }
+
+void KOrganizerIfaceImpl::loadProfile( const QString& path )
+{
+    mActionManager->loadProfile( path );
+}
+
+void KOrganizerIfaceImpl::saveToProfile( const QString& path ) const
+{
+    mActionManager->saveToProfile( path );
+}
+
+
