@@ -3,6 +3,7 @@
 
     Copyright (c) 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
     Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+    Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -28,6 +29,7 @@
 #include <qmap.h>
 #include <qlistview.h>
 #include <qpalette.h>
+#include <qdatetime.h>
 
 namespace KCal {
 class Todo;
@@ -59,11 +61,7 @@ class KOTodoViewItem : public QCheckListItem
 
     void construct();
 
-    Todo *todo() { return mTodo; }
-
-    QString key(int, bool) const;
-
-    void setSortKey(int column,const QString &key);
+    Todo *todo() const { return mTodo; }
 
     bool isAlternate();
     int compare( QListViewItem *i, int col, bool ascending ) const;
@@ -77,12 +75,12 @@ class KOTodoViewItem : public QCheckListItem
 #endif
   virtual void stateChange(bool);
 
-
   private:
     Todo *mTodo;
     KOTodoView *mTodoView;
+    QDateTime mEffectiveDueDate;
+    int compareDueDates( const KOTodoViewItem *b ) const;
 
-    QMap<int,QString> mKeyMap;
     uint m_odd : 1;
     uint m_known : 1;
     uint m_unused : 30;
