@@ -184,6 +184,8 @@ void KOViewManager::connectView(KOrg::BaseView *view)
           mMainView, SLOT(copyIncidence(Incidence *)));
   connect(view, SIGNAL(cutIncidenceSignal(Incidence *)),
           mMainView, SLOT(cutIncidence(Incidence *)));
+  connect(view, SIGNAL(pasteIncidenceSignal()),
+          mMainView, SLOT(pasteIncidence()));
   connect(view, SIGNAL(toggleAlarmSignal(Incidence *)),
           mMainView, SLOT(toggleAlarm(Incidence *)));
   connect(view,SIGNAL(dissociateOccurrenceSignal( Incidence *, const QDate & )),
@@ -465,3 +467,11 @@ void KOViewManager::currentAgendaViewTabChanged( QWidget* widget )
 {
   showView( static_cast<KOrg::BaseView*>( widget ) );
 }
+
+void KOViewManager::resourcesChanged()
+{
+  if ( mAgendaView )
+    mAgendaView->resourcesChanged();
+  if ( mAgendaSideBySideView )
+    mAgendaSideBySideView->resourcesChanged();
+}
