@@ -26,13 +26,16 @@
 #include <qfile.h>
 #include <qregexp.h>
 
+#include <klocale.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 
+#include <libkcal/calendar.h>
 #include <libkcal/event.h>
 #include <libkcal/icalformat.h>
 
 #include "komailclient.h"
+#include "incidencechanger.h"
 
 #include "mailscheduler.h"
 
@@ -80,7 +83,11 @@ bool MailScheduler::performTransaction( IncidenceBase *incidence,
        method == Declinecounter ) {
     status = mailer.mailAttendees( incidence, messageText );
   } else {
-    status = mailer.mailOrganizer( incidence, messageText );
+    QString subject;
+    Incidence *inc = dynamic_cast<Incidence*>( incidence );
+    if ( inc && method == Counter )
+      subject = i18n( "Counter proposal: %1" ).arg( inc->summary() );
+    status = mailer.mailOrganizer( incidence, messageText, subject );
   }
   return status;
 }
@@ -158,3 +165,28 @@ QString MailScheduler::freeBusyDir()
 {
   return locateLocal( "data", "korganizer/freebusy" );
 }
+
+bool MailScheduler::acceptCounterProposal( Incidence *incidence )
+{
+  if ( !incidence )
+    return false;
+
+  Incidence *exInc = mCalendar->incidence( incidence->uid() );
+  if ( !exInc )
+    exInc = mCalendar->incidenceFromSchedulingID( incidence->uid() );
+  incidence->setRevision( incidence->revision() + 1 );
+  if ( exInc ) {
+    incidence->setRevision( QMAX( incidence->revision(), exInc->revision() + 1 ) );
+    // some stuff we don't want to change, just to be safe
+    incidence->setSchedulingID( exInc->schedulingID() );
+    incidence->setUid( exInc->uid() );
+
+    mCalendar->beginChange( exInc );
+    IncidenceChanger::assignIncidence( exInc, incidence );
+    exInc->updated();
+    mCalendar->endChange( exInc );
+  } else {
+    mCalendar->addIncidence( incidence );
+  }
+  return true;
+}
