@@ -18,8 +18,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -171,8 +171,8 @@ void ResolutionCheckListItem::updateText()
  *
  *****************************************************************/
 
-ResolutionDlg::ResolutionDlg( QWidget* parent, KPilotDeviceLink*fH,
-	QString caption, QString helpText, ResolutionTable*tab) :
+ResolutionDlg::ResolutionDlg( QWidget* parent, KPilotLink*fH,
+	const QString &caption, const QString &helpText, ResolutionTable*tab) :
 	KDialogBase( parent, "ResolutionDlg", false, caption, Apply|Cancel, Apply),
 	tickleTimer(0L),
 	fHandle(fH),
@@ -235,7 +235,7 @@ void ResolutionDlg::fillListView()
 	for ( ResolutionItem* it = fTable->last(); it; it = fTable->prev() )
 	{
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Building table, items="<<it->fExistItems<<", PC="<<
+		DEBUGKPILOT<<"Building table, items="<<it->fExistItems<<", PC="<<
 			it->fEntries[0]<<", Palm="<<it->fEntries[1]<<", Backup="<<
 			it->fEntries[2]<<endl;
 #endif
