@@ -18,8 +18,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -56,8 +56,7 @@
 // the modules are that make up a binary distribution.
 extern "C"
 {
-long version_conduit_doc = KPILOT_PLUGIN_API;
-const char *id_conduit_doc = "$Id: doc-conduit.cc 369132 2004-12-07 22:44:11Z adridg $";
+unsigned long version_conduit_doc = Pilot::PLUGIN_API;
 }
 
 QString dirToString(eSyncDirectionEnum dir) {
@@ -78,13 +77,10 @@ QString dirToString(eSyncDirectionEnum dir) {
  *********************************************************************/
 
 
-DOCConduit::DOCConduit(KPilotDeviceLink * o,
+DOCConduit::DOCConduit(KPilotLink * o,
 	const char *n, const QStringList & a):ConduitAction(o, n, a)
 {
 	FUNCTIONSETUP;
-#ifdef DEBUG
-	DEBUGCONDUIT<<id_conduit_doc<<endl;
-#endif
 	fConduitName=i18n("DOC");
 }
 
@@ -134,7 +130,7 @@ void DOCConduit::readConfig()
 	eSyncDirection = (enum eSyncDirectionEnum)(DOCConduitSettings::syncDirection() );
 
 #ifdef DEBUG
-	DEBUGCONDUIT << fname
+	DEBUGKPILOT << fname
 		<< ": Settings "
 		<< " tXTDirectory=" << DOCConduitSettings::tXTDirectory()
 		<< " pDBDirectory=" << DOCConduitSettings::pDBDirectory()
@@ -161,7 +157,7 @@ bool DOCConduit::pcTextChanged(QString txtfn)
 		return true;
 	}
 #ifdef DEBUG
-	DEBUGCONDUIT<<"Old digest is "<<oldDigest<<endl;
+	DEBUGKPILOT<<"Old digest is "<<oldDigest<<endl;
 #endif
 
 	KMD5 docmd5;
@@ -170,7 +166,7 @@ bool DOCConduit::pcTextChanged(QString txtfn)
 		docmd5.update(txtfile);
 		QString thisDigest(docmd5.hexDigest() /* .data() */);
 #ifdef DEBUG
-		DEBUGCONDUIT<<"New digest is "<<thisDigest<<endl;
+		DEBUGKPILOT<<"New digest is "<<thisDigest<<endl;
 #endif
 		return (thisDigest.length()<=0) || (thisDigest!=oldDigest);
 	} else {
@@ -199,7 +195,7 @@ bool DOCConduit::hhTextChanged(PilotDatabase*docdb)
 	int modRecInd=-1;
 	PilotRecord*modRec=docdb->readNextModifiedRec(&modRecInd);
 #ifdef DEBUG
-	DEBUGCONDUIT<<"Index of first changed record: "<<modRecInd<<endl;
+	DEBUGKPILOT<<"Index of first changed record: "<<modRecInd<<endl;
 #endif
 
 	KPILOT_DELETE(modRec);
@@ -208,7 +204,7 @@ bool DOCConduit::hhTextChanged(PilotDatabase*docdb)
 	if (modRecInd==0) {
 		modRec=docdb->readNextModifiedRec(&modRecInd);
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Reread Index of first changed records: "<<modRecInd<<endl;
+		DEBUGKPILOT<<"Reread Index of first changed records: "<<modRecInd<<endl;
 #endif
 		KPILOT_DELETE(modRec);
 	}
@@ -217,14 +213,14 @@ bool DOCConduit::hhTextChanged(PilotDatabase*docdb)
 	// no modified record was found
 	if (modRecInd >= 0) {
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Handheld side has changed, condition="<<
+		DEBUGKPILOT<<"Handheld side has changed, condition="<<
 			((!DOCConduitSettings::ignoreBmkChanges()) || (modRecInd <= storyRecs))<<endl;
 #endif
 		if ((!DOCConduitSettings::ignoreBmkChanges()) || (modRecInd <= storyRecs))
 			return true;
 	} else {
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Handheld side has NOT changed!"<<endl;
+		DEBUGKPILOT<<"Handheld side has NOT changed!"<<endl;
 #endif
 		return false;
 	}
@@ -269,9 +265,6 @@ QString DOCConduit::constructTXTFileName(QString name) {
 /* virtual */ bool DOCConduit::exec()
 {
 	FUNCTIONSETUP;
-#ifdef DEBUG
-	DEBUGCONDUIT<<"Conduit version: "<<id_conduit_doc<<endl;
-#endif
 
 	readConfig();
 	dbnr=0;
@@ -292,7 +285,7 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
 	if (sinfo.direction==eSyncDelete) {
 		if (!sinfo.txtfilename.isEmpty()) {
 			if (!QFile::remove(sinfo.txtfilename)) {
-				kdWarning()<<"Unable to delete the text file "<<sinfo.txtfilename<<" on the PC"<<endl;
+				WARNINGKPILOT << "Unable to delete the text file " << sinfo.txtfilename << " on the PC" << endl;
 			}
 			QString bmkfilename = sinfo.txtfilename;
 			if (bmkfilename.endsWith(CSL1(".txt"))){
@@ -301,7 +294,7 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
 			bmkfilename+=CSL1(PDBBMK_SUFFIX);
 			if (!QFile::remove(bmkfilename)) {
 #ifdef DEBUG
-				DEBUGCONDUIT<<"Could not remove bookmarks file "<<bmkfilename<<" for database "<<sinfo.handheldDB<<endl;
+				DEBUGKPILOT<<"Could not remove bookmarks file "<<bmkfilename<<" for database "<<sinfo.handheldDB<<endl;
 #endif
 			}
 		}
@@ -310,16 +303,15 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
 				QString::fromLatin1(sinfo.dbinfo.name), false);
 			if (database) {
 				if ( database->deleteDatabase() !=0 ) {
-					kdWarning()<<"Unable to delete database "<<sinfo.dbinfo.name<<" on the PC"<<endl;
+					WARNINGKPILOT << "Unable to delete database " << sinfo.dbinfo.name << " on the PC" << endl;
 				}
 				KPILOT_DELETE(database);
 			}
 		}
 		if (!DOCConduitSettings::localSync()) {
-			PilotDatabase *database=new PilotSerialDatabase(pilotSocket(),
-				QString::fromLatin1(sinfo.dbinfo.name));
+			PilotDatabase *database=deviceLink()->database( sinfo.dbinfo.name );
 			if ( database->deleteDatabase() !=0 ) {
-					kdWarning()<<"Unable to delete database "<<sinfo.dbinfo.name<<" from the handheld"<<endl;
+					WARNINGKPILOT << "Unable to delete database " << sinfo.dbinfo.name << " from the handheld" << endl;
 			}
 			KPILOT_DELETE(database);
 		}
@@ -330,19 +322,19 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
 	// instance which points either to a local database or a database on the handheld.
 	PilotDatabase *database = preSyncAction(sinfo);
 
-	if (database && ( !database->isDBOpen() ) ) {
+	if (database && ( !database->isOpen() ) ) {
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Database "<<sinfo.dbinfo.name<<" does not yet exist. Creating it:"<<endl;
+		DEBUGKPILOT<<"Database "<<sinfo.dbinfo.name<<" does not yet exist. Creating it:"<<endl;
 #endif
 		if (!database->createDatabase(dbcreator(), dbtype()) ) {
 #ifdef DEBUG
-			DEBUGCONDUIT<<"Failed"<<endl;
+			DEBUGKPILOT<<"Failed"<<endl;
 			emit logMessage(i18n("Database created."));
 #endif
 		}
 	}
 
-	if (database && database->isDBOpen()) {
+	if (database && database->isOpen()) {
 		DOCConverter docconverter;
 		connect(&docconverter, SIGNAL(logError(const QString &)), SIGNAL(logError(const QString &)));
 		connect(&docconverter, SIGNAL(logMessage(const QString &)), SIGNAL(logMessage(const QString &)));
@@ -375,11 +367,11 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
 				DOCConduitSettings::self()->config()->writeEntry(docconverter.txtFilename(), thisDigest);
 				DOCConduitSettings::self()->config()->sync();
 #ifdef DEBUG
-				DEBUGCONDUIT<<"MD5 Checksum of the text "<<sinfo.txtfilename<<" is "<<thisDigest<<endl;
+				DEBUGKPILOT<<"MD5 Checksum of the text "<<sinfo.txtfilename<<" is "<<thisDigest<<endl;
 #endif
 			} else {
 #ifdef DEBUG
-				DEBUGCONDUIT<<"couldn't open file "<<docconverter.txtFilename()<<" for reading!!!"<<endl;
+				DEBUGKPILOT<<"couldn't open file "<<docconverter.txtFilename()<<" for reading!!!"<<endl;
 #endif
 			}
 		}
@@ -417,7 +409,7 @@ void DOCConduit::syncNextDB() {
 	}
 	dbnr=dbinfo.index+1;
 #ifdef DEBUG
-	DEBUGCONDUIT<<"Next Palm database to sync: "<<dbinfo.name<<", Index="<<dbinfo.index<<endl;
+	DEBUGKPILOT<<"Next Palm database to sync: "<<dbinfo.name<<", Index="<<dbinfo.index<<endl;
 #endif
 
 	// if creator and/or type don't match, go to next db
@@ -492,7 +484,7 @@ void DOCConduit::syncNextTXT()
 		fDBNames.append(QString::fromLatin1(dbinfo.name));
 	} else {
 #ifdef DEBUG
-		DEBUGCONDUIT<<txtfilename<<" has already been synced, skipping it."<<endl;
+		DEBUGKPILOT<<txtfilename<<" has already been synced, skipping it."<<endl;
 #endif
 	}
 
@@ -552,7 +544,7 @@ void DOCConduit::checkPDBFiles() {
 			fDBNames.append(dbname);
 		} else {
 #ifdef DEBUG
-			DEBUGCONDUIT<<"Could not install database "<<dbname<<" ("<<pdbfilename<<") to the handheld"<<endl;
+			DEBUGKPILOT<<"Could not install database "<<dbname<<" ("<<pdbfilename<<") to the handheld"<<endl;
 #endif
 		}
 	}
@@ -596,25 +588,25 @@ void DOCConduit::resolve() {
 		// the remaining conflicts will be resolved in the resolution dialog
 		if ((*fSyncInfoListIterator).direction==eSyncConflict){
 #ifdef DEBUG
-			DEBUGCONDUIT<<"We have a conflict for "<<(*fSyncInfoListIterator).handheldDB<<", default="<<eConflictResolution<<endl;
+			DEBUGKPILOT<<"We have a conflict for "<<(*fSyncInfoListIterator).handheldDB<<", default="<<eConflictResolution<<endl;
 #endif
 			switch (eConflictResolution)
 			{
 				case eSyncPDAToPC:
 #ifdef DEBUG
-					DEBUGCONDUIT<<"PDA overrides for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
+					DEBUGKPILOT<<"PDA overrides for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
 #endif
 					(*fSyncInfoListIterator).direction = eSyncPDAToPC;
 					break;
 				case eSyncPCToPDA:
 #ifdef DEBUG
-					DEBUGCONDUIT<<"PC overrides for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
+					DEBUGKPILOT<<"PC overrides for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
 #endif
 					(*fSyncInfoListIterator).direction = eSyncPCToPDA;
 					break;
 				case eSyncNone:
 #ifdef DEBUG
-					DEBUGCONDUIT<<"No sync for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
+					DEBUGKPILOT<<"No sync for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
 #endif
 					(*fSyncInfoListIterator).direction = eSyncNone;
 					break;
@@ -622,7 +614,7 @@ void DOCConduit::resolve() {
 				case eSyncConflict:
 				default:
 #ifdef DEBUG
-					DEBUGCONDUIT<<"Conflict remains due to default resolution setting for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
+					DEBUGKPILOT<<"Conflict remains due to default resolution setting for database "<<(*fSyncInfoListIterator).handheldDB<<endl;
 #endif
 					break;
 			}
@@ -666,7 +658,7 @@ void DOCConduit::syncDatabases() {
 	switch (sinfo.direction) {
 		case eSyncConflict:
 #ifdef DEBUG
-			DEBUGCONDUIT<<"Entry "<<sinfo.handheldDB<<"( txtfilename: "<<sinfo.txtfilename<<
+			DEBUGKPILOT<<"Entry "<<sinfo.handheldDB<<"( txtfilename: "<<sinfo.txtfilename<<
 				", pdbfilename: "<<sinfo.pdbfilename<<") had sync direction eSyncConflict!!!"<<endl;
 #endif
 			break;
@@ -677,7 +669,7 @@ void DOCConduit::syncDatabases() {
 			if (!doSync(sinfo)) {
 				// The sync could not be done, so inform the user (the error message should probably issued inside doSync)
 #ifdef DEBUG
-				DEBUGCONDUIT<<"There was some error syncing the text \""<<sinfo.handheldDB<<"\" with the file "<<sinfo.txtfilename<<endl;
+				DEBUGKPILOT<<"There was some error syncing the text \""<<sinfo.handheldDB<<"\" with the file "<<sinfo.txtfilename<<endl;
 #endif
 			}
 			break;
@@ -692,9 +684,15 @@ void DOCConduit::syncDatabases() {
 }
 
 
-PilotDatabase*DOCConduit::openDOCDatabase(QString dbname) {
-	if (DOCConduitSettings::localSync()) return new PilotLocalDatabase(DOCConduitSettings::pDBDirectory(), dbname, false);
-	else return new PilotSerialDatabase(pilotSocket(), dbname);
+PilotDatabase*DOCConduit::openDOCDatabase(const QString &dbname) {
+	if (DOCConduitSettings::localSync())
+	{
+		return new PilotLocalDatabase(DOCConduitSettings::pDBDirectory(), dbname, false);
+	}
+	else
+	{
+		return deviceLink()->database( dbname );
+	}
 }
 
 
@@ -707,7 +705,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 	if (!fDBListSynced.contains(sinfo.handheldDB)) {
 		// the database wasn't included on last sync, so it has to be new.
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Database "<<sinfo.dbinfo.name<<" wasn't included in the previous sync!"<<endl;
+		DEBUGKPILOT<<"Database "<<sinfo.dbinfo.name<<" wasn't included in the previous sync!"<<endl;
 #endif
 
 		/* Resolution Table:
@@ -720,7 +718,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 
 		if (QFile::exists(sinfo.txtfilename)) sinfo.fPCStatus=eStatNew;
 		else sinfo.fPCStatus=eStatDoesntExist;
-		if (docdb && docdb->isDBOpen()) sinfo.fPalmStatus=eStatNew;
+		if (docdb && docdb->isOpen()) sinfo.fPalmStatus=eStatNew;
 		else sinfo.fPalmStatus=eStatDoesntExist;
 		KPILOT_DELETE(docdb);
 
@@ -744,7 +742,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 					else {
 						sinfo.direction=eSyncNone;
 #ifdef DEBUG
-						DEBUGCONDUIT<<"I'm supposed to find a sync direction, but the "<<
+						DEBUGKPILOT<<"I'm supposed to find a sync direction, but the "<<
 						" text "<<sinfo.dbinfo.name<<" doesn't exist on either "<<
 						" the handheld or the PC"<<endl;
 #endif
@@ -762,24 +760,24 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 	else if(pcTextChanged(sinfo.txtfilename)) {
 		sinfo.fPCStatus=eStatChanged;
 #ifdef DEBUG
-		DEBUGCONDUIT<<"PC side has changed!"<<endl;
+		DEBUGKPILOT<<"PC side has changed!"<<endl;
 #endif
 		// TODO: Check for changed bookmarks on the PC side
 #ifdef DEBUG
 	} else {
-		DEBUGCONDUIT<<"PC side has NOT changed!"<<endl;
+		DEBUGKPILOT<<"PC side has NOT changed!"<<endl;
 #endif
 	}
 
-	if (!docdb || !docdb->isDBOpen()) sinfo.fPalmStatus=eStatDeleted;
+	if (!docdb || !docdb->isOpen()) sinfo.fPalmStatus=eStatDeleted;
 	else if (hhTextChanged(docdb)) {
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Handheld side has changed!"<<endl;
+		DEBUGKPILOT<<"Handheld side has changed!"<<endl;
 #endif
 		sinfo.fPalmStatus=eStatChanged;
 #ifdef DEBUG
 	} else {
-		DEBUGCONDUIT<<"Handheld side has NOT changed!"<<endl;
+		DEBUGKPILOT<<"Handheld side has NOT changed!"<<endl;
 #endif
 	}
 	KPILOT_DELETE(docdb);
@@ -804,7 +802,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 
 	if (sinfo.fPCStatus == eStatNone && sinfo.fPalmStatus==eStatNone) {
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Nothing has changed, not need for a sync."<<endl;
+		DEBUGKPILOT<<"Nothing has changed, not need for a sync."<<endl;
 #endif
 		sinfo.direction=eSyncNone;
 		return false;
@@ -836,7 +834,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 	     ((sinfo.fPalmStatus==eStatDeleted) && (sinfo.fPCStatus!=eStatChanged)) )
 	{
 #ifdef DEBUG
-		DEBUGCONDUIT<<"DB was deleted on one side and not changed on "
+		DEBUGKPILOT<<"DB was deleted on one side and not changed on "
 			"the other -> Delete it."<<endl;
 #endif
 		sinfo.direction=eSyncDelete;
@@ -847,7 +845,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
 	// other values in combination with eStatNone, just copy the texts.
 	if (sinfo.fPCStatus==eStatNone) {
 #ifdef DEBUG
-		DEBUGCONDUIT<<"PC side has changed!"<<endl;
+		DEBUGKPILOT<<"PC side has changed!"<<endl;
 #endif
 		sinfo.direction=eSyncPDAToPC;
 		return true;
@@ -894,15 +892,15 @@ PilotDatabase *DOCConduit::preSyncAction(docSyncInfo &sinfo) const
 					dir.mkdir(dir.absPath());
 				}
 #ifdef DEBUG
-				DEBUGCONDUIT<<"Need to fetch database "<<dbinfo.name<<
+				DEBUGKPILOT<<"Need to fetch database "<<dbinfo.name<<
 					" to the directory "<<dir.absPath()<<endl;
 #endif
 				dbinfo.flags &= ~dlpDBFlagOpen;
 
 				if (!fHandle->retrieveDatabase(sinfo.pdbfilename, &dbinfo) )
 				{
-					kdWarning(0)<<"Unable to retrieve database "<<dbinfo.name<<
-						" from the handheld into "<<sinfo.pdbfilename<<"."<<endl;
+					WARNINGKPILOT << "Unable to retrieve database " << dbinfo.name <<
+						" from the handheld into " << sinfo.pdbfilename << "." << endl;
 					return 0L;
 				}
 			}
@@ -928,8 +926,7 @@ PilotDatabase *DOCConduit::preSyncAction(docSyncInfo &sinfo) const
 	}
 	else
 	{
-		return new PilotSerialDatabase(pilotSocket(),
-			QString::fromLatin1(dbinfo.name));
+		return deviceLink()->database(QString::fromLatin1(dbinfo.name));
 	}
 }
 
@@ -947,15 +944,15 @@ bool DOCConduit::postSyncAction(PilotDatabase * database,
 	case eSyncPDAToPC:
 		// also reset the sync flags on the handheld
 #ifdef DEBUG
-		DEBUGCONDUIT<<"Resetting sync flags for database "
+		DEBUGKPILOT<<"Resetting sync flags for database "
 			<<sinfo.dbinfo.name<<endl;
 #endif
 		if (DOCConduitSettings::keepPDBsLocally() && !DOCConduitSettings::localSync())
 		{
-			PilotSerialDatabase*db=new PilotSerialDatabase(pilotSocket(),
+			PilotDatabase*db=deviceLink()->database(
 				QString::fromLatin1(sinfo.dbinfo.name));
 #ifdef DEBUG
-			DEBUGCONDUIT<<"Middle 1 Resetting sync flags for database "
+			DEBUGKPILOT<<"Middle 1 Resetting sync flags for database "
 				<<sinfo.dbinfo.name<<endl;
 #endif
 			if (db)
@@ -965,7 +962,7 @@ bool DOCConduit::postSyncAction(PilotDatabase * database,
 			}
 		}
 #ifdef DEBUG
-		DEBUGCONDUIT<<"End Resetting sync flags for database "
+		DEBUGKPILOT<<"End Resetting sync flags for database "
 			<<sinfo.dbinfo.name<<endl;
 #endif
 		break;
@@ -977,7 +974,7 @@ bool DOCConduit::postSyncAction(PilotDatabase * database,
 			if (localdb)
 			{
 #ifdef DEBUG
-				DEBUGCONDUIT<<"Installing file "<<localdb->dbPathName()<<" ("
+				DEBUGKPILOT<<"Installing file "<<localdb->dbPathName()<<" ("
 					<<sinfo.handheldDB<<") to the handheld"<<endl;
 #endif
 				QString dbpathname=localdb->dbPathName();
@@ -987,7 +984,7 @@ bool DOCConduit::postSyncAction(PilotDatabase * database,
 				{
 					rs = false;
 #ifdef DEBUG
-					DEBUGCONDUIT<<"Could not install the database "<<dbpathname<<" ("
+					DEBUGKPILOT<<"Could not install the database "<<dbpathname<<" ("
 						<<sinfo.handheldDB<<")"<<endl;
 #endif
 				}
@@ -998,12 +995,12 @@ bool DOCConduit::postSyncAction(PilotDatabase * database,
 	}
 
 #ifdef DEBUG
-	DEBUGCONDUIT<<"Vor KPILOT_DELETE(database)"<<endl;
+	DEBUGKPILOT<<"Vor KPILOT_DELETE(database)"<<endl;
 #endif
 
 	KPILOT_DELETE(database);
 #ifdef DEBUG
-	DEBUGCONDUIT<<"End postSyncAction"<<endl;
+	DEBUGKPILOT<<"End postSyncAction"<<endl;
 #endif
 	return rs;
 }
