@@ -66,11 +66,11 @@ protected:
 	void test();
 
 	/**
-	* Contact KNotes by DCOP and retrieve the list of notes it
-	* has. @return false if the DCOP connection could not be made.
-	* Modifies fP to store the notes in.
+	* Loads the KNotes resource and retrieve the list of notes it
+	* has. @return false if the the resource could not be opened and a new
+	* resource could not be created. Modifies fP to store the notes in.
 	*/
-	bool retrieveKNotesInfo();
+	bool openKNotesResource();
 
 	/**
 	* For actual processing. These are called by process
