@@ -82,7 +82,7 @@ void TimeConduit::readConfig()
 	if (syncMode().isLocal())
 	{
 #ifdef DEBUG
-		DEBUGCONDUIT << fname << ": Would have set time to "
+		DEBUGKPILOT << fname << ": Would have set time to "
 			<< QDateTime::currentDateTime().toString() << endl;
 #endif
 		return delayDone();
@@ -116,6 +116,6 @@ void TimeConduit::syncHHfromPC()
 	}
 	else
 	{
-		kdWarning() << k_funcinfo << ": Link is not a real device." << endl;
+		WARNINGKPILOT << "Link is not a real device." << endl;
 	}
 }
