@@ -28,9 +28,6 @@
 /*
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
-static const char *addresswidget_id =
-	"$Id: addressWidget.cc 450284 2005-08-17 20:49:09Z adridg $";
-
 
 
 #ifndef _KPILOT_OPTIONS_H
@@ -79,9 +76,6 @@ AddressWidget::AddressWidget(QWidget * parent,
 
 	setupWidget();
 	fAddressList.setAutoDelete(true);
-
-	/* NOTREACHED */
-	(void) addresswidget_id;
 }
 
 AddressWidget::~AddressWidget()
@@ -107,11 +101,10 @@ int AddressWidget::getAllAddresses(PilotDatabase * addressDB)
 		if (!(pilotRec->isDeleted()) &&
 			(!(pilotRec->isSecret()) || KPilotSettings::showSecrets()))
 		{
-			address = new PilotAddress(fAddressAppInfo, pilotRec);
+			address = new PilotAddress(pilotRec);
 			if (address == 0L)
 			{
-				kdWarning() << k_funcinfo
-					<< ": Couldn't allocate record "
+				WARNINGKPILOT << "Couldn't allocate record "
 					<< currentRecord++
 					<< endl;
 				break;
@@ -146,7 +139,7 @@ void AddressWidget::showComponent()
 
 	fAddressList.clear();
 
-	if (addressDB->isDBOpen())
+	if (addressDB->isOpen())
 	{
 		KPILOT_DELETE(fAddressAppInfo);
 		fAddressAppInfo = new PilotAddressInfo(addressDB);
@@ -157,8 +150,7 @@ void AddressWidget::showComponent()
 	else
 	{
 		populateCategories(fCatList, 0L);
-		kdWarning() << k_funcinfo
-			<< ": Could not open local AddressDB" << endl;
+		WARNINGKPILOT << "Could not open local AddressDB" << endl;
 	}
 
 	KPILOT_DELETE( addressDB );
@@ -282,11 +274,11 @@ void AddressWidget::setupWidget()
 		i18n("<qt>Delete the selected address from the address book.</qt>") :
 		i18n("<qt><i>Deleting is disabled by the 'internal editors' setting.</i></qt>") ;
 
-	button = new QPushButton(TODO_I18N("Export..."), this);
+	button = new QPushButton(i18n("Export addresses to file","Export..."), this);
 	grid->addWidget(button, 3,1);
 	connect(button, SIGNAL(clicked()), this, SLOT(slotExport()));
 	QWhatsThis::add(button,
-		TODO_I18N("<qt>Export all addresses in the selected category to CSV format.</qt>") );
+		i18n("<qt>Export all addresses in the selected category to CSV format.</qt>") );
 
 	QWhatsThis::add(fDeleteButton,wt);
 }
@@ -447,7 +439,7 @@ void AddressWidget::slotEditRecord()
 	}
 
 	AddressEditor *editor = new AddressEditor(selectedRecord,
-		fAddressAppInfo->info(), this);
+		fAddressAppInfo, this);
 
 	connect(editor, SIGNAL(recordChangeComplete(PilotAddress *)),
 		this, SLOT(slotUpdateRecord(PilotAddress *)));
@@ -470,7 +462,7 @@ void AddressWidget::slotCreateNewRecord()
 	//
 	PilotDatabase *myDB = new PilotLocalDatabase(dbPath(), CSL1("AddressDB"));
 
-	if (!myDB || !myDB->isDBOpen())
+	if (!myDB || !myDB->isOpen())
 	{
 #ifdef DEBUG
 		DEBUGKPILOT << fname
@@ -480,7 +472,7 @@ void AddressWidget::slotCreateNewRecord()
 			<< " and got pointer @"
 			<< (long) myDB
 			<< " with status "
-			<< ( myDB ? myDB->isDBOpen() : false )
+			<< ( myDB ? myDB->isOpen() : false )
 			<< endl;
 #endif
 
@@ -497,7 +489,7 @@ void AddressWidget::slotCreateNewRecord()
 	}
 
 	AddressEditor *editor = new AddressEditor(0L,
-		fAddressAppInfo->info(), this);
+		fAddressAppInfo, this);
 
 	connect(editor, SIGNAL(recordChangeComplete(PilotAddress *)),
 		this, SLOT(slotAddRecord(PilotAddress *)));
@@ -517,7 +509,7 @@ void AddressWidget::slotAddRecord(PilotAddress * address)
 		fAddressAppInfo->categoryInfo(), true);
 
 
-	address->PilotAppCategory::setCategory(currentCatID);
+	address->PilotRecordBase::setCategory(currentCatID);
 	fAddressList.append(address);
 	writeAddress(address);
 	// TODO: Just add the new record to the lists
@@ -614,7 +606,7 @@ void AddressWidget::slotShowAddress(int which)
 #endif
 
 	QString text(CSL1("<qt>"));
-	text += addr->getTextRepresentation(true);
+	text += addr->getTextRepresentation(fAddressAppInfo,Qt::RichText);
 	text += CSL1("</qt>\n");
 	fAddrInfo->setText(text);
 
@@ -636,7 +628,7 @@ void AddressWidget::writeAddress(PilotAddress * which,
 	PilotDatabase *myDB = addressDB;
 	bool usemyDB = false;
 
-	if (myDB == 0L || !myDB->isDBOpen())
+	if (myDB == 0L || !myDB->isOpen())
 	{
 		myDB = new PilotLocalDatabase(dbPath(), CSL1("AddressDB"));
 		usemyDB = true;
@@ -645,7 +637,7 @@ void AddressWidget::writeAddress(PilotAddress * which,
 	// Still no valid address database...
 	//
 	//
-	if (!myDB->isDBOpen())
+	if (!myDB->isOpen())
 	{
 #ifdef DEBUG
 		DEBUGKPILOT << fname << ": Address database is not open" <<
@@ -683,7 +675,7 @@ void AddressWidget::slotExport()
 
 	QString prompt = (currentCatID==-1) ?
 		i18n("Export All Addresses") :
-		i18n("Export Address Category %1").arg(fAddressAppInfo->category(currentCatID)) ;
+		i18n("Export Address Category %1").arg(fAddressAppInfo->categoryName(currentCatID)) ;
 
 
 	QString saveFile = KFileDialog::getSaveFileName(
