@@ -40,15 +40,12 @@
 #include "kroupware.h"
 #include "kpilotConfig.h"
 
-static const char *kroupware_id =
-	"$Id: kroupware.cc 437980 2005-07-23 19:53:57Z kainhofe $";
-
 KroupwareSync::KroupwareSync(bool pre,int parts,KPilotDeviceLink *p) :
 	SyncAction(p,pre ? "KroupwarePreSync" : "KroupwarePostSync"),
 	fPre(pre),
 	fParts(parts)
 {
-	(void) kroupware_id;
+
 }
 
 /* virtual */ bool KroupwareSync::exec()
