@@ -28,114 +28,109 @@
 */
 
 
-static const char *options_id =
-	"$Id: options.cc 449050 2005-08-14 05:03:22Z vanrijn $";
-
 #include "options.h"
 
 
 #include <iostream>
 
-#if TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# if HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
-
 #include <qsize.h>
 
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kcmdlineargs.h>
 
-// The daemon also has a debug level; debug_spaces is 60 spaces,
-// to align FUNCTIONSETUP output.
-//
-//
+#ifdef DEBUG
+int debug_level = 1;
+#else
 int debug_level = 0;
-const char *debug_spaces =
-	"                                                    ";
-QString rtExpand(const QString &s, bool richText)
+#endif
+
+// The daemon also has a debug level; debug_spaces is 60 spaces,
+// to align FUNCTIONSETUP output. The one byte extra is for the NUL.
+//
+//
+static const char debug_spaces[61] =
+	"                    "
+	"                    "
+	"                    ";
+
+
+QString rtExpand(const QString &s, Qt::TextFormat richText)
 {
-	if (richText)
+	if (richText == Qt::RichText)
 	{
 		QString t(s);
-		return t.replace(CSL1("\n"), CSL1("<br>\n"));
+		return t.replace(CSL1("\n"), CSL1("<br/>\n"));
 	}
 	else
+	{
 		return s;
+	}
 
-	Q_UNUSED(options_id);
 }
 
 QDateTime readTm(const struct tm &t)
 {
-  QDateTime dt;
-  dt.setDate(QDate(1900 + t.tm_year, t.tm_mon + 1, t.tm_mday));
-  dt.setTime(QTime(t.tm_hour, t.tm_min, t.tm_sec));
-  return dt;
+	QDateTime dt;
+	dt.setDate(QDate(1900 + t.tm_year, t.tm_mon + 1, t.tm_mday));
+	dt.setTime(QTime(t.tm_hour, t.tm_min, t.tm_sec));
+	return dt;
 }
 
 
 
 struct tm writeTm(const QDateTime &dt)
 {
-  struct tm t;
+	struct tm t;
 
-  t.tm_wday = 0; // unimplemented
-  t.tm_yday = 0; // unimplemented
-  t.tm_isdst = 0; // unimplemented
-  t.tm_zone = 0; // unimplemented
+	t.tm_wday = 0; // unimplemented
+	t.tm_yday = 0; // unimplemented
+	t.tm_isdst = 0; // unimplemented
+#ifdef HAVE_STRUCT_TM_TM_ZONE
+	t.tm_zone = 0; // unimplemented
+#endif
 
-  t.tm_year = dt.date().year() - 1900;
-  t.tm_mon = dt.date().month() - 1;
-  t.tm_mday = dt.date().day();
-  t.tm_hour = dt.time().hour();
-  t.tm_min = dt.time().minute();
-  t.tm_sec = dt.time().second();
+	t.tm_year = dt.date().year() - 1900;
+	t.tm_mon = dt.date().month() - 1;
+	t.tm_mday = dt.date().day();
+	t.tm_hour = dt.time().hour();
+	t.tm_min = dt.time().minute();
+	t.tm_sec = dt.time().second();
 
-  return t;
+	return t;
 }
 
 
 
-struct tm writeTm(const QDate &dt)
+struct tm writeTm(const QDate &d)
 {
-  struct tm t;
-
-  t.tm_wday = 0; // unimplemented
-  t.tm_yday = 0; // unimplemented
-  t.tm_isdst = 0; // unimplemented
-
-  t.tm_year = dt.year() - 1900;
-  t.tm_mon = dt.month() - 1;
-  t.tm_mday = dt.day();
-  t.tm_hour = 0;
-  t.tm_min = 0;
-  t.tm_sec = 0;
-
-  return t;
+	QDateTime dt(d);
+	return writeTm(dt);
 }
 
-#ifdef DEBUG
-KPilotDepthCount::KPilotDepthCount(int area, int level, const char *s) :
+KPilotDepthCount::KPilotDepthCount(int, int level, const char *s) :
+	fDepth(depth),
+	fLevel(level),
+	fName(s)
+{
+	DEBUGKPILOT << "! DEPRECATED Depth call.\n!   "
+		<< kdBacktrace(4) << endl;
+
+	if (debug_level>=fLevel)
+	{
+		DEBUGKPILOT << indent() << ">" << name() << endl;
+	}
+	depth++;
+}
+
+KPilotDepthCount::KPilotDepthCount(int level, const char *s) :
 	fDepth(depth),
 	fLevel(level),
 	fName(s)
 {
 	if (debug_level>=fLevel)
 	{
-#ifdef DEBUG_CERR
-		DEBUGKPILOT
-#else
-		debug(area)
-#endif
-		<< indent() << ">" << name() << endl;
+		DEBUGKPILOT << indent() << ">" << name() << endl;
 	}
 	depth++;
 }
@@ -143,15 +138,20 @@ KPilotDepthCount::KPilotDepthCount(int area, int level, const char *s) :
 KPilotDepthCount::~KPilotDepthCount()
 {
 	depth--;
+	std::cerr.clear(std::ios_base::goodbit);
 }
 
-QString KPilotDepthCount::indent() const
+const char *KPilotDepthCount::indent() const
 {
-	QString s;
-	s.fill(' ',fDepth);
-	return s+s+' ';
+	if (fDepth < 30)
+	{
+		return debug_spaces + 60-fDepth*2;
+	}
+	else
+	{
+		return debug_spaces;
+	}
 }
 
 int KPilotDepthCount::depth = 0;
-#endif
 
