@@ -1,5 +1,5 @@
-#ifndef _RECORD_CONDUIT_H
-#define _RECORD_CONDUIT_H
+#ifndef _KPILOT_RECORDCONDUIT_H
+#define _KPILOT_RECORDCONDUIT_H
 /* record-conduit.h                           KPilot
 **
 ** Copyright (C) 2005 by Adriaan de Groot
@@ -31,9 +31,11 @@
 #include <klocale.h>
 
 #include "plugin.h"
-#include "pilotAppCategory.h"
+#include "pilot.h"
 #include "pilotDatabase.h"
+#include "kpilotdevicelink.h"
 
+class KPilotDeviceLink;
 
 /** @file
 *
@@ -70,19 +72,20 @@ public:
 		// delete fTimer; // Timer is a child object
 	} ;
 
-	/** The different directions that a pair of records (one on the PC, one
-	* on the Pilot) can be synced. These correspond to special sync directions
-	* and the most general "sync both ways". Values of this type are passed
-	* to the single-record syncer functions.
-	*/
-	typedef enum { HHtoPC=0, PCtoHH=1, Both=2 } SyncDirection;
-
 	/** Return values for the processing functions. Each should return
 	* NotDone if it needs to be called again (e.g. to process another record),
 	* Done if it is finished and something else should be done, and
 	* Error if the sync cannot be completed.
 	*/
-	typedef enum { NotDone=0, Done=1, Error=2 } SyncProgress;
+	enum SyncProgress { NotDone=0, Done=1, Error=2 } ;
+
+	/** Returns a human-readable name for the progress indicator @p s */
+	static QString name(SyncProgress s);
+
+	/** State of the conduit's sync. This is changed by process(). */
+	enum States { Initialize, PalmToPC, PCToPalm, Cleanup } ;
+
+	static QString name(States s);
 
 protected:
 	/** Function called at the beginning of a sync to load data from the PC.
@@ -94,16 +97,24 @@ protected:
 	/** Function called repeatedly to fetch the next modified entry from the Palm and
 	* sync it with the PC by looking up the record, and calling the syncer for it.
 	*
-	* @return true when there are no more modified records on the Palm
-	* @see process
+	* @return Dome when there are no more modified records on the Palm
+	* @see process()
 	*/
 	virtual SyncProgress palmRecToPC() = 0;
 
+	/** Function called repeatedly to fetch the next modified entry from the PC and
+	* sync it with the Palm by looking up the record and calling the syncer for it.
+	*
+	* @return Done when there are no more modified records on the PC
+	* @see process()
+	*/
+	virtual SyncProgress pcRecToPalm() = 0;
+
 	/** Function called at the end of this conduit's sync, which should reset DB flags
 	* and write changed config data out to disk.
 	*
-	* @return true if the cleanup succeeds.
-	* @see process
+	* @return Done when the cleanup is complete.
+	* @see process()
 	*/
 	virtual SyncProgress cleanup() = 0;
 
@@ -120,12 +131,10 @@ private:
 	/** Timer to signal the process() slot. Used to keep the UI responsive. */
 	QTimer *fTimer;
 
-	/** State of the conduit's sync. This is changed by process. */
-	enum { Initialize, PalmToPC, Cleanup } fState;
+	States fState;
 
-	QMap<recordid_t,QString> fUIDMap;
-	RecordIDList fIDList;
-	RecordIDList::Iterator fIDListIterator;
+	Pilot::RecordIDList fIDList;
+	Pilot::RecordIDList::Iterator fIDListIterator;
 
 	QString fDBName;
 } ;
@@ -135,13 +144,12 @@ class RecordConduit : public RecordConduitBase
 {
 public:
 	/** Construct a record conduit on a given device link. */
-	RecordConduit(const QString &name /**< Name presented to user */,
+	RecordConduit(
 		KPilotDeviceLink *o /**< Connection to HH */,
 		const char *n /**< Name for QObject */,
 		const QStringList a = QStringList() /**< Flags */) :
 		RecordConduitBase(o,n,a)
 	{
-		fConduitName=name;
 	} ;
 	virtual ~RecordConduit()
 	{
@@ -149,78 +157,23 @@ public:
 
 	virtual SyncProgress loadPC()
 	{
-		fAppInfo = new HHAppInfo(fDatabase) ;
-		fContainer = new PCContainer();
-		if (!fContainer->load())
-		{
-			emit logError(i18n("Unable to load the %1 database on the PC.").arg(fConduitName));
-			return Error;
-		}
-		if (fContainer->isEmpty()) setFirstSync(true); /* And leave UID map empty */
-		else fContainer->mapToRecords(fUIDMap);
-
 		return Done;
 	} ;
 
 	virtual SyncProgress palmRecToPC()
 	{
-		if ( fIDListIterator == fIDList.end() )
-		{
-			return Done;
-		}
+		return Done;
+	}
 
-		recordid_t currentID = *fIDListIterator++;
-		PilotRecord *rec = fDatabase->readRecordById(currentID);
-		HHEntry *currentHH = 0;
-		PCEntry *currentPC = 0;
-		Q_ASSERT(rec);
-		if (fUIDMap.contains(currentID))
-		{
-			QString currentUID = fUIDMap[currentID];
-			// This is a modified entry or it is deleted on the HH
-			if (rec->isDeleted())
-			{
-				fContainer->remove(currentUID);
-			}
-			else
-			{
-				currentHH = new HHEntry(rec);
-				currentPC = fContainer->get(currentUID);
-				Syncer::sync(currentPC,currentHH,fAppInfo,HHtoPC);
-			}
-		}
-		else
-		{
-			// Deleted on HH, unknown on PC -> Ignore it.
-			// Not deleted, unknown -> New record.
-			if (!rec->isDeleted())
-			{
-				currentHH = new HHEntry(rec);
-				currentPC = new PCEntry();
-				Syncer::sync(currentPC,currentHH,fAppInfo,HHtoPC);
-				fContainer->insert(currentPC);
-			}
-		}
-		delete rec;
-		delete currentHH;
-		// delete currentPC; Ownership passed to the container
-
-		return NotDone;
+	virtual SyncProgress pcRecToPalm()
+	{
+		return Done;
 	}
 
 	virtual SyncProgress cleanup()
 	{
-		delete fAppInfo;
-		fContainer->save();
-		delete fContainer;
 		return Done;
 	}
-
-	virtual bool getAppInfo( unsigned char *buffer, int appLen ) { return true; } ;
-
-protected:
-	HHAppInfo *fAppInfo;
-	PCContainer *fContainer;
 } ;
 
 
