@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 #ifndef KPIM_EXCHANGECALENDAR_H
 #define KPIM_EXCHANGECALENDAR_H
@@ -85,7 +85,7 @@ class ResourceExchange : public ResourceCalendar, public IncidenceBase::Observer
     /** Add Event to calendar. */
     bool addEvent(Event *anEvent);
     /** deletes an event from this calendar. */
-    void deleteEvent(Event *);
+    bool deleteEvent(Event *);
 
     // Isn't called anymore.
     void changeIncidence( Incidence * );
@@ -104,12 +104,6 @@ class ResourceExchange : public ResourceCalendar, public IncidenceBase::Observer
     */
     Event::List rawEvents();
 
-    /*
-      Returns a QString with the text of the holiday (if any) that falls
-      on the specified date.
-    */
-    QString getHolidayForDate(const QDate &qd);
-
     virtual void subscribeEvents( const QDate& start, const QDate& end );
 
     /**
@@ -128,7 +122,7 @@ class ResourceExchange : public ResourceCalendar, public IncidenceBase::Observer
     /**
       Remove a todo from the todolist.
     */
-    void deleteTodo( Todo * );
+    bool deleteTodo( Todo * );
     /**
       Searches todolist for an event with this unique string identifier,
       returns a pointer or null.
@@ -146,7 +140,7 @@ class ResourceExchange : public ResourceCalendar, public IncidenceBase::Observer
     /** Add a Journal entry to calendar */
     virtual bool addJournal(Journal *);
     /** deletes an event from this calendar. */
-    virtual void deleteJournal(Journal *);
+    virtual bool deleteJournal(Journal *);
     /** Return Journals for given date */
     virtual Journal::List journals(const QDate &);
     /** Return Journal with given UID */
@@ -183,7 +177,11 @@ class ResourceExchange : public ResourceCalendar, public IncidenceBase::Observer
       Builds and then returns a list of all events that match for the
       date specified. useful for dayView, etc. etc.
     */
-    Event::List rawEventsForDate( const QDate &date, bool sorted = false );
+    Event::List rawEventsForDate(
+      const QDate &date,
+      EventSortField sortField=EventSortUnsorted,
+      SortDirection sortDirection=SortDirectionAscending );
+
     /**
       Get unfiltered events for date \a qdt.
     */
