@@ -17,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "kabc_resourcegroupdav.h"
@@ -36,6 +36,7 @@ extern "C"
   void *init_kabc_groupdav()
   {
     KGlobal::locale()->insertCatalogue( "kdepimresources" );
+    KGlobal::locale()->insertCatalogue( "kres_groupdav" );
     return new GroupDavFactory;
   }
 }
