@@ -46,7 +46,11 @@
 #include <kabc/locknull.h>
 #include <kmainwindow.h>
 #include <klocale.h>
+#include <kinputdialog.h>
+#include <ktempfile.h>
+#include <kmdcodec.h>
 
+#include <qfile.h>
 #include <qobject.h>
 #include <qtimer.h>
 #include <qapplication.h>
@@ -107,7 +111,7 @@ bool ResourceKolab::openResource( KConfig& config, const char* contentType,
   map.clear();
   QValueList<KMailICalIface::SubResource>::ConstIterator it;
   for ( it = subResources.begin(); it != subResources.end(); ++it )
-    loadSubResourceConfig( config, (*it).location, (*it).label, (*it).writable, 
+    loadSubResourceConfig( config, (*it).location, (*it).label, (*it).writable,
                            (*it).alarmRelevant, map );
   return true;
 }
@@ -212,6 +216,9 @@ bool ResourceKolab::loadSubResource( const QString& subResource,
 
 bool ResourceKolab::doLoad()
 {
+  if (!mUidMap.isEmpty() ) {
+    return true;
+  }
   mUidMap.clear();
 
   return loadAllEvents() & loadAllTodos() & loadAllJournals();
@@ -290,17 +297,10 @@ bool ResourceKolab::doSave()
       && kmailTriggerSync( kmailJournalContentsType );
   */
 }
-
-void ResourceKolab::incidenceUpdated( KCal::IncidenceBase* incidencebase )
+void ResourceKolab::incidenceUpdatedSilent( KCal::IncidenceBase* incidencebase)
 {
-  if ( incidencebase->isReadOnly() ) return; // Should not happen (TM)
-  incidencebase->setSyncStatus( KCal::Event::SYNCMOD );
-  incidencebase->setLastModified( QDateTime::currentDateTime() );
-  // we should probably update the revision number here,
-  // or internally in the Event itself when certain things change.
-  // need to verify with ical documentation.
-
-  const QString uid = incidencebase->uid();
+ const QString uid = incidencebase->uid();
+  //kdDebug() << k_funcinfo << uid << endl;
 
   if ( mUidsPendingUpdate.contains( uid ) || mUidsPendingAdding.contains( uid ) ) {
     /* We are currently processing this event ( removing and readding or
@@ -318,6 +318,18 @@ void ResourceKolab::incidenceUpdated( KCal::IncidenceBase* incidencebase )
     mUidsPendingUpdate.append( uid );
   }
   sendKMailUpdate( incidencebase, subResource, sernum );
+
+}
+void ResourceKolab::incidenceUpdated( KCal::IncidenceBase* incidencebase )
+{
+  if ( incidencebase->isReadOnly() ) return;
+  incidencebase->setSyncStatusSilent( KCal::Event::SYNCMOD );
+  incidencebase->setLastModified( QDateTime::currentDateTime() );
+  // we should probably update the revision number here,
+  // or internally in the Event itself when certain things change.
+  // need to verify with ical documentation.
+  incidenceUpdatedSilent( incidencebase );
+
 }
 
 void ResourceKolab::resolveConflict( KCal::Incidence* inc, const QString& subresource, Q_UINT32 sernum )
@@ -329,45 +341,54 @@ void ResourceKolab::resolveConflict( KCal::Incidence* inc, const QString& subres
         delete inc;
         return;
     }
-    Incidence* local = mCalendar.incidence( inc->uid() );
+    const QString origUid = inc->uid();
+    Incidence* local = mCalendar.incidence( origUid );
     Incidence* localIncidence = 0;
     Incidence* addedIncidence = 0;
+    Incidence*  result = 0;
     if ( local ) {
+      if (*local == *inc) {
+        // real duplicate, remove the second one
+        result = local;
+      } else {
         KIncidenceChooser* ch = new KIncidenceChooser();
         ch->setIncidence( local ,inc );
         if ( KIncidenceChooser::chooseMode == KIncidenceChooser::ask ) {
-            connect ( this, SIGNAL( useGlobalMode() ), ch, SLOT (  useGlobalMode() ) );
-            if ( ch->exec() )
-                if ( KIncidenceChooser::chooseMode != KIncidenceChooser::ask )
-                    emit useGlobalMode() ;
+          connect ( this, SIGNAL( useGlobalMode() ), ch, SLOT (  useGlobalMode() ) );
+          if ( ch->exec() )
+            if ( KIncidenceChooser::chooseMode != KIncidenceChooser::ask )
+              emit useGlobalMode() ;
         }
-        Incidence* result = ch->getIncidence();
-      delete ch;
-      if ( result == local ) {
-          localIncidence = local->clone();
-          delete inc;
-      } else  if ( result == inc ) {
-          addedIncidence = inc;
-      } else if ( result == 0 ) { // take both
-          localIncidence = local->clone();
-          localIncidence->recreate();
-          localIncidence->setSummary( i18n("Copy of: %1").arg(localIncidence->summary()) );
-          addedIncidence = inc;
+        result = ch->getIncidence();
+        delete ch;
       }
-      bool silent = mSilent;
-      mSilent = false;
-      deleteIncidence( local ); // remove local from kmail
-      kmailDeleteIncidence( subresource, sernum );// remove new from kmail
-      if ( localIncidence ) {
-        addIncidence( localIncidence, subresource, 0  );
-        mUidsPendingAdding.remove( localIncidence->uid() ); // we do want to inform KOrg also
-      }
-      if ( addedIncidence  ) {
-        addIncidence( addedIncidence, subresource, 0  );
-        mUidsPendingAdding.remove( addedIncidence->uid() ); // we do want to inform KOrg also
-      }
-      mSilent = silent;
-  }
+    } else {
+      // nothing there locally, just take the new one. Can't Happen (TM)
+      result = inc;
+    }
+    if ( result == local ) {
+        delete inc;
+        localIncidence = local;
+    } else  if ( result == inc ) {
+        addedIncidence = inc;
+    } else if ( result == 0 ) { // take both
+        addedIncidence = inc;
+        addedIncidence->setSummary( i18n("Copy of: %1").arg( addedIncidence->summary() ) );
+        addedIncidence->setUid( CalFormat::createUniqueId() );
+        localIncidence = local;
+    }
+    bool silent = mSilent;
+    mSilent = false;
+    if ( !localIncidence ) {
+        deleteIncidence( local ); // remove local from kmail
+    }
+    mUidsPendingDeletion.append( origUid );
+    if ( addedIncidence  ) {
+        sendKMailUpdate( addedIncidence, subresource, sernum );
+    } else {
+        kmailDeleteIncidence( subresource, sernum );// remove new from kmail
+    }
+    mSilent = silent;
 }
 void ResourceKolab::addIncidence( const char* mimetype, const QString& data,
                                   const QString& subResource, Q_UINT32 sernum )
@@ -431,6 +452,27 @@ bool ResourceKolab::sendKMailUpdate( KCal::IncidenceBase* incidencebase, const Q
 //  kdDebug() << k_funcinfo << "Data string:\n" << data << endl;
 
   KCal::Incidence* incidence = static_cast<KCal::Incidence *>( incidencebase );
+
+  KCal::Attachment::List atts = incidence->attachments();
+  QStringList attURLs, attMimeTypes, attNames;
+  QValueList<KTempFile*> tmpFiles;
+  for ( KCal::Attachment::List::ConstIterator it = atts.constBegin(); it != atts.constEnd(); ++it ) {
+    KTempFile* tempFile = new KTempFile;
+    QCString decoded = KCodecs::base64Decode( QCString( (*it)->data() ) );
+    tempFile->file()->writeBlock( decoded.data(), decoded.length() );
+    tempFile->close();
+    KURL url;
+    url.setPath( tempFile->name() );
+    attURLs.append( url.url() );
+    attMimeTypes.append( (*it)->mimeType() );
+    attNames.append( (*it)->label() );
+  }
+  QStringList deletedAtts;
+  if ( kmailListAttachments( deletedAtts, subresource, sernum ) ) {
+    for ( QStringList::ConstIterator it = attNames.constBegin(); it != attNames.constEnd(); ++it ) {
+      deletedAtts.remove( *it );
+    }
+  }
   CustomHeaderMap customHeaders;
   if ( incidence->schedulingID() != incidence->uid() )
     customHeaders.insert( "X-Kolab-SchedulingID", incidence->schedulingID() );
@@ -439,11 +481,17 @@ bool ResourceKolab::sendKMailUpdate( KCal::IncidenceBase* incidencebase, const Q
   if ( !isXMLStorageFormat ) subject.prepend( "iCal " ); // conform to the old style
 
   // behold, sernum is an in-parameter
-  const bool rc = kmailUpdate( subresource, sernum, data, mimetype, subject, customHeaders );
+  const bool rc = kmailUpdate( subresource, sernum, data, mimetype, subject, customHeaders, attURLs, attMimeTypes, attNames, deletedAtts );
   // update the serial number
   if ( mUidMap.contains( incidencebase->uid() ) ) {
     mUidMap[ incidencebase->uid() ].setSerialNumber( sernum );
   }
+
+  for( QValueList<KTempFile *>::Iterator it = tmpFiles.begin(); it != tmpFiles.end(); ++it ) {
+    (*it)->setAutoDelete( true );
+    delete (*it);
+  }
+
   return rc;
 }
 
@@ -452,7 +500,7 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const QString& _su
 {
   Q_ASSERT( incidence );
   if ( !incidence ) return false;
-  const QString &uid = incidence->uid();
+  QString uid = incidence->uid();
   QString subResource = _subresource;
 
   Kolab::ResourceMap *map = &mEventSubResources; // don't use a ref here!
@@ -471,7 +519,37 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const QString& _su
     // Find out if this event was previously stored in KMail
     bool newIncidence = _subresource.isEmpty();
     if ( newIncidence ) {
-      subResource = findWritableResource( *map );
+      // Add a description of the incidence
+      QString text = "<b><font size=\"+1\">";
+      if ( incidence->type() == "Event" )
+        text += i18n( "Choose the folder where you want to store this event" );
+      else if ( incidence->type() == "Todo" )
+        text += i18n( "Choose the folder where you want to store this task" );
+      else
+        text += i18n( "Choose the folder where you want to store this incidence" );
+      text += "<font></b><br>";
+      if ( !incidence->summary().isEmpty() )
+        text += i18n( "<b>Summary:</b> %1" ).arg( incidence->summary() ) + "<br>";
+      if ( !incidence->location().isEmpty() )
+        text += i18n( "<b>Location:</b> %1" ).arg( incidence->location() );
+      text += "<br>";
+      if ( !incidence->doesFloat() )
+        text += i18n( "<b>Start:</b> %1, %2" )
+                .arg( incidence->dtStartDateStr(), incidence->dtStartTimeStr() );
+      else
+        text += i18n( "<b>Start:</b> %1" ).arg( incidence->dtStartDateStr() );
+      text += "<br>";
+      if ( incidence->type() == "Event" ) {
+        Event* event = static_cast<Event*>( incidence );
+        if ( event->hasEndDate() )
+          if ( !event->doesFloat() )
+            text += i18n( "<b>End:</b> %1, %2" )
+                    .arg( event->dtEndDateStr(), event->dtEndTimeStr() );
+          else
+            text += i18n( "<b>End:</b> %1" ).arg( event->dtEndDateStr() );
+        text += "<br>";
+      }
+      subResource = findWritableResource( *map, text );
     }
 
     if ( subResource.isEmpty() )
@@ -511,15 +589,21 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const QString& _su
        * unless the folder is read-only, in which case the user should not be
        * offered a means of putting mails in a folder she'll later be unable to
        * upload. Skip the incidence, in this case. */
-      if ( mUidMap.contains( uid )
-          && ( mUidMap[ uid ].resource() == subResource ) ) {
-        if ( (*map)[ subResource ].writable() ) {
-          resolveConflict( incidence, subResource, sernum );
+      if ( mUidMap.contains( uid ) ) {
+        if ( mUidMap[ uid ].resource() == subResource ) {
+          if ( (*map)[ subResource ].writable() ) {
+            resolveConflict( incidence, subResource, sernum );
+          } else {
+            kdWarning( 5650 ) << "Duplicate event in a read-only folder detected! "
+              "Please inform the owner of the folder. " << endl;
+          }
+          return true;
         } else {
-          kdWarning( 5650 ) << "Duplicate event in a read-only folder detected! "
-            "Please inform the owner of the folder. " << endl;
+          // duplicate uid in a different folder, do the internal-uid tango
+          incidence->setSchedulingID( uid );
+          incidence->setUid(CalFormat::createUniqueId( ) );
+          uid = incidence->uid();
         }
-        return true;
       }
       /* Add to the cache if the add didn't come from KOrganizer, in which case
        * we've already added it, and listen to updates from KOrganizer for it. */
@@ -564,7 +648,7 @@ bool ResourceKolab::addEvent( KCal::Event* event )
 void ResourceKolab::addEvent( const QString& xml, const QString& subresource,
                               Q_UINT32 sernum )
 {
-  KCal::Event* event = Kolab::Event::xmlToEvent( xml, mCalendar.timeZoneId() );
+  KCal::Event* event = Kolab::Event::xmlToEvent( xml, mCalendar.timeZoneId(), this, subresource, sernum );
   Q_ASSERT( event );
   if( event ) {
       addIncidence( event, subresource, sernum );
@@ -636,7 +720,7 @@ bool ResourceKolab::addTodo( KCal::Todo* todo )
 void ResourceKolab::addTodo( const QString& xml, const QString& subresource,
                              Q_UINT32 sernum )
 {
-  KCal::Todo* todo = Kolab::Task::xmlToTask( xml, mCalendar.timeZoneId() );
+  KCal::Todo* todo = Kolab::Task::xmlToTask( xml, mCalendar.timeZoneId(), this, subresource, sernum );
   Q_ASSERT( todo );
   if( todo )
       addIncidence( todo, subresource, sernum );
@@ -727,6 +811,8 @@ KCal::Alarm::List ResourceKolab::relevantAlarms( const KCal::Alarm::List &alarms
   return relevantAlarms;
 }
 
+
+
 KCal::Alarm::List ResourceKolab::alarms( const QDateTime& from,
                                          const QDateTime& to )
 {
@@ -789,8 +875,8 @@ void ResourceKolab::fromKMailDelIncidence( const QString& type,
   if ( !subresourceActive( subResource ) ) return;
 
   // Can't be in both, by contract
-  if ( mUidsPendingDeletion.contains( uid ) ) {
-    mUidsPendingDeletion.remove( uid );
+  if ( mUidsPendingDeletion.find( uid ) != mUidsPendingDeletion.end() ) {
+    mUidsPendingDeletion.remove( mUidsPendingDeletion.find( uid ) );
   } else if ( mUidsPendingUpdate.contains( uid ) ) {
     // It's good to know if was deleted, but we are waiting on a new one to
     // replace it, so let's just sit tight.
@@ -849,7 +935,7 @@ void ResourceKolab::fromKMailAddSubresource( const QString& type,
   config.setGroup( subResource );
 
   bool active = config.readBoolEntry( subResource, true );
-  (*map)[ subResource ] = Kolab::SubResource( active, writable, 
+  (*map)[ subResource ] = Kolab::SubResource( active, writable,
                                               alarmRelevant, label );
   loadSubResource( subResource, mimetype );
   emit signalSubresourceAdded( this, type, subResource, label );
@@ -872,25 +958,7 @@ void ResourceKolab::fromKMailDelSubresource( const QString& type,
   config.deleteGroup( subResource );
   config.sync();
 
-  // Make a list of all uids to remove
-  Kolab::UidMap::ConstIterator mapIt;
-  QStringList uids;
-  for ( mapIt = mUidMap.begin(); mapIt != mUidMap.end(); ++mapIt )
-    if ( mapIt.data().resource() == subResource )
-      // We have a match
-      uids << mapIt.key();
-
-  // Finally delete all the incidences
-  if ( !uids.isEmpty() ) {
-    TemporarySilencer t( this );
-    QStringList::ConstIterator it;
-    for ( it = uids.begin(); it != uids.end(); ++it ) {
-      KCal::Incidence* incidence = mCalendar.incidence( *it );
-      if( incidence )
-        mCalendar.deleteIncidence( incidence );
-      mUidMap.remove( *it );
-    }
-  }
+  unloadSubResource( subResource );
 
   emit signalSubresourceRemoved( this, type, subResource );
 }
@@ -917,18 +985,6 @@ ResourceKolab::labelForSubresource( const QString& subresource ) const
   return subresource;
 }
 
-QString ResourceKolab::subresourceIdentifier( Incidence *incidence )
-{
-  QString uid = incidence->uid();
-  if ( mUidMap.contains( uid ) )
-    return mUidMap[ uid ].resource();
-  else
-    if ( mNewIncidencesMap.contains( uid ) )
-      return mNewIncidencesMap[ uid ];
-    else
-      return QString();
-}
-
 void ResourceKolab::fromKMailAsyncLoadResult( const QMap<Q_UINT32, QString>& map,
                                               const QString& type,
                                               const QString& folder )
@@ -960,17 +1016,27 @@ bool ResourceKolab::subresourceActive( const QString& subresource ) const
 void ResourceKolab::setSubresourceActive( const QString &subresource, bool v )
 {
   ResourceMap *map = 0;
-
-  if ( mEventSubResources.contains( subresource ) )
+  const char* mimeType = 0;
+  if ( mEventSubResources.contains( subresource ) ) {
      map = &mEventSubResources;
-  if ( mTodoSubResources.contains( subresource ) )
+     mimeType = eventAttachmentMimeType;
+  }
+  if ( mTodoSubResources.contains( subresource ) ) {
      map = &mTodoSubResources;
-  if ( mJournalSubResources.contains( subresource ) )
+     mimeType = todoAttachmentMimeType;
+  }
+  if ( mJournalSubResources.contains( subresource ) ) {
      map = &mJournalSubResources;
+     mimeType = journalAttachmentMimeType;
+  }
 
   if ( map && ( ( *map )[ subresource ].active() != v ) ) {
     ( *map )[ subresource ].setActive( v );
-    doLoad();                     // refresh the mCalendar cache
+    if ( v ) {
+        loadSubResource( subresource, mimeType );
+    } else {
+        unloadSubResource( subresource );
+    }
     mResourceChangedTimer.changeInterval( 100 );
   }
 }
@@ -1001,4 +1067,87 @@ Kolab::ResourceMap* ResourceKolab::subResourceMap( const QString& contentsType )
   return 0;
 }
 
+
+/*virtual*/
+bool ResourceKolab::addSubresource( const QString& resource, const QString& parent )
+{
+   kdDebug(5650) << "KCal Kolab resource - adding subresource: " << resource << endl;
+   QString contentsType = kmailCalendarContentsType;
+   if ( !parent.isEmpty() ) {
+     if ( mEventSubResources.contains( parent ) )
+       contentsType = kmailCalendarContentsType;
+     else if ( mTodoSubResources.contains( parent ) )
+       contentsType = kmailTodoContentsType;
+     else if ( mJournalSubResources.contains( parent ) )
+       contentsType = kmailJournalContentsType;
+   } else {
+     QStringList contentTypeChoices;
+     contentTypeChoices << i18n("Calendar") << i18n("Tasks") << i18n("Journals");
+     const QString caption = i18n("Which kind of subresource should this be?");
+     const QString choice = KInputDialog::getItem( caption, QString::null, contentTypeChoices );
+     if ( choice == contentTypeChoices[0] )
+       contentsType = kmailCalendarContentsType;
+     else if ( choice == contentTypeChoices[1] )
+       contentsType = kmailTodoContentsType;
+     else if ( choice == contentTypeChoices[2] )
+       contentsType = kmailJournalContentsType;
+   }
+
+   return kmailAddSubresource( resource, parent, contentsType );
+}
+
+/*virtual*/
+bool ResourceKolab::removeSubresource( const QString& resource )
+{
+   kdDebug(5650) << "KCal Kolab resource - removing subresource: " << resource << endl;
+   return kmailRemoveSubresource( resource );
+}
+
+/*virtual*/
+QString ResourceKolab::subresourceIdentifier( Incidence *incidence )
+{
+  QString uid = incidence->uid();
+  if ( mUidMap.contains( uid ) )
+    return mUidMap[ uid ].resource();
+  else
+    if ( mNewIncidencesMap.contains( uid ) )
+      return mNewIncidencesMap[ uid ];
+    else
+      return QString();
+}
+
+
+bool ResourceKolab::unloadSubResource( const QString& subResource )
+{
+    const bool silent = mSilent;
+    mSilent = true;
+    Kolab::UidMap::Iterator mapIt = mUidMap.begin();
+    while ( mapIt != mUidMap.end() )
+    {
+        Kolab::UidMap::Iterator it = mapIt++;
+        const StorageReference ref = it.data();
+        if ( ref.resource() != subResource ) continue;
+        // FIXME incidence() is expensive
+        KCal::Incidence* incidence = mCalendar.incidence( it.key() );
+        if( incidence ) {
+            incidence->unRegisterObserver( this );
+            mCalendar.deleteIncidence( incidence );
+        }
+        mUidMap.remove( it );
+    }
+    mSilent = silent;
+    return true;
+}
+
+QString ResourceKolab::subresourceType( const QString &resource )
+{
+  if ( mEventSubResources.contains( resource ) )
+    return "event";
+  if ( mTodoSubResources.contains( resource ) )
+    return "todo";
+  if ( mJournalSubResources.contains( resource ) )
+    return "journal";
+  return QString();
+}
+
 #include "resourcekolab.moc"
