@@ -121,6 +121,8 @@ public:
   /** Return the list of subresources. */
   QStringList subresources() const;
 
+  bool canHaveSubresources() const { return true; }
+
   /** Is this subresource active? */
   bool subresourceActive( const QString& ) const;
   /** (De)activate the subresource */
@@ -131,14 +133,19 @@ public:
 
   virtual QString subresourceIdentifier( Incidence *incidence );
 
+  virtual bool addSubresource( const QString& resource, const QString& parent );
+  virtual bool removeSubresource( const QString& resource );
+
+  virtual QString subresourceType( const QString &resource );
+
   KABC::Lock* lock();
 
 signals:
   void useGlobalMode();
 protected slots:
-   void slotEmitResourceChanged();
+  void slotEmitResourceChanged();
 protected:
-  /** 
+  /**
    * Return list of alarms which are relevant for the current user. These
    * are the ones coming from folders which the user has "Administer" rights
    * for, as per ACL */
@@ -169,6 +176,7 @@ private:
 
   /// Reimplemented from IncidenceBase::Observer to know when an incidence was changed
   void incidenceUpdated( KCal::IncidenceBase* );
+  void incidenceUpdatedSilent( KCal::IncidenceBase* incidencebase);
 
   bool openResource( KConfig& config, const char* contentType,
                      Kolab::ResourceMap& map );
@@ -176,6 +184,7 @@ private:
                               const QString& label, bool writable,
                               bool alarmRelevant, Kolab::ResourceMap& subResource );
   bool loadSubResource( const QString& subResource, const char* mimetype );
+  bool unloadSubResource( const QString& subResource );
 
   QString configFile() const {
     return ResourceKolabBase::configFile( "kcal" );
