@@ -15,13 +15,25 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "kabcresourceslox.h"
 #include "kabcresourcesloxconfig.h"
 
+#include <kglobal.h>
+#include <klocale.h>
+
 using namespace KABC;
 
 typedef KRES::PluginFactory< ResourceSlox, ResourceSloxConfig > SloxFactory;
-K_EXPORT_COMPONENT_FACTORY( kabc_slox, SloxFactory )
+
+extern "C"
+{
+  void *init_kabc_slox()
+  {
+    KGlobal::locale()->insertCatalogue( "libkcal" );
+    KGlobal::locale()->insertCatalogue( "kabc_slox" );
+    return new SloxFactory;
+  }
+}
