@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef RESOURCESLOXCONFIG_H
 #define RESOURCESLOXCONFIG_H
@@ -23,13 +23,17 @@
 #include <kresources/configwidget.h>
 #include <kdepimmacros.h>
 
+class QCheckBox;
 class KLineEdit;
 class KURLRequester;
+class KPushButton;
+
+class SloxBase;
 
 namespace KABC {
 
 class KDE_EXPORT ResourceSloxConfig : public KRES::ConfigWidget
-{ 
+{
   Q_OBJECT
 
   public:
@@ -39,10 +43,17 @@ class KDE_EXPORT ResourceSloxConfig : public KRES::ConfigWidget
     void loadSettings( KRES::Resource* );
     void saveSettings( KRES::Resource* );
 
+  private slots:
+    void selectAddressFolder();
+
   private:
     KURLRequester *mURL;
     KLineEdit *mUser;
     KLineEdit *mPassword;
+    QCheckBox *mLastSyncCheck;
+    KPushButton *mFolderButton;
+    QString mFolderId;
+    SloxBase *mRes;
 };
 
 }
