@@ -1,5 +1,6 @@
 /*
     This file is part of libkcal.
+
     Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
 
     This library is free software; you can redistribute it and/or
@@ -14,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <klocale.h>
@@ -27,21 +28,7 @@
 using namespace KCal;
 
 QString CalFormat::mApplication = QString::fromLatin1("libkcal");
-QString CalFormat::mProductId = QString::fromLatin1("-//K Desktop Environment//NONSGML libkcal 3.2//EN");
-
-// An array containing the PRODID strings indexed against the calendar file format version used.
-// Every time the calendar file format is changed, add an entry/entries to this list.
-struct CalVersion {
-  int       version;
-  QString   prodId;
-};
-static CalVersion prodIds[] = {
-  { 220, QString::fromLatin1("-//K Desktop Environment//NONSGML KOrganizer 2.2//EN") },
-  { 300, QString::fromLatin1("-//K Desktop Environment//NONSGML KOrganizer 3.0//EN") },
-  { 310, QString::fromLatin1("-//K Desktop Environment//NONSGML KOrganizer 3.1//EN") },
-  { 320, QString::fromLatin1("-//K Desktop Environment//NONSGML KOrganizer 3.2//EN") },
-  { 0 , QString() }
-};
+QString CalFormat::mProductId = QString::fromLatin1("-//K Desktop Environment//NONSGML libkcal 3.5//EN");
 
 
 CalFormat::CalFormat()
@@ -89,11 +76,3 @@ QString CalFormat::createUniqueId()
   return uidStr;
 }
 
-int CalFormat::calendarVersion(const char* prodId)
-{
-  for (const CalVersion* cv = prodIds;  cv->version;  ++cv) {
-    if (!strcmp(prodId, cv->prodId.utf8()))
-      return cv->version;
-  }
-  return 0;
-}
