@@ -3,10 +3,9 @@
   FILE: icaltime.c
   CREATOR: eric 02 June 2000
   
-  $Id: icaltime.c 405592 2005-04-14 19:28:51Z dfaure $
-  $Locker:  $
     
- (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
+ (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
+     http://www.softwarestudio.org
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of either: 
@@ -55,7 +54,7 @@
  *  Function to convert a struct tm time specification
  *  to an ANSI time_t using the specified time zone.
  *  This is different from the standard mktime() function
- *  in that we dont want the automatic adjustments for
+ *  in that we don't want the automatic adjustments for
  *  local daylight savings time applied to the result.
  *  This function expects well-formed input.
  */
@@ -177,7 +176,7 @@ icaltime_from_timet(const time_t tm, const int is_date)
  */
 struct icaltimetype 
 icaltime_from_timet_with_zone(const time_t tm, const int is_date,
-	const icaltimezone *zone)
+	icaltimezone *zone)
 {
     struct icaltimetype tt = icaltime_null_time();
     struct tm t;
@@ -222,7 +221,7 @@ icaltime_from_timet_with_zone(const time_t tm, const int is_date,
  * 
  * Returns the current time in the given timezone, as an icaltimetype.
  */
-struct icaltimetype icaltime_current_time_with_zone(const icaltimezone *zone)
+struct icaltimetype icaltime_current_time_with_zone(icaltimezone *zone)
 {
     return icaltime_from_timet_with_zone (time (NULL), 0, zone);
 }
@@ -274,7 +273,7 @@ time_t icaltime_as_timet(const struct icaltimetype tt)
  *	time is simply returned as time_t in its native timezone.
  */
 time_t icaltime_as_timet_with_zone(const struct icaltimetype _tt,
-	const icaltimezone *zone)
+	icaltimezone *zone)
 {
     struct icaltimetype tt = _tt;
     struct tm stm;
@@ -317,7 +316,7 @@ const char* icaltime_as_ical_string(const struct icaltimetype tt)
     if(tt.is_date){
 	snprintf(buf, size,"%04d%02d%02d",tt.year,tt.month,tt.day);
     } else {
-	char* fmt;
+	const char* fmt;
 	if(tt.is_utc){
 	    fmt = "%04d%02d%02dT%02d%02d%02dZ";
 	} else {
@@ -866,13 +865,13 @@ struct icaltimetype icaltime_convert_to_zone(const struct icaltimetype tt,
 	return ret;
 }
 
-const icaltimezone *
+icaltimezone *
 icaltime_get_timezone(const struct icaltimetype t) {
 
 	return t.zone;
 }
 
-char *
+const char *
 icaltime_get_tzid(const struct icaltimetype t) {
 
 	if (t.zone != NULL) {
@@ -889,7 +888,7 @@ icaltime_get_tzid(const struct icaltimetype t) {
  *	then you should use icaltime_convert_to_timezone instead.
  */
 struct icaltimetype
-icaltime_set_timezone(struct icaltimetype *t, const icaltimezone *zone) {
+icaltime_set_timezone(struct icaltimetype *t, icaltimezone *zone) {
 
 	/* If it's a date do nothing */
 	if (t->is_date) {
