@@ -4,10 +4,9 @@
  CREATOR: eric 21 Aug 2000
 
 
- $Id: icalclassify.h 618271 2006-12-31 20:49:49Z kainhofe $
- $Locker:  $
 
- (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
+ (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
+     http://www.softwarestudio.org
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of either: 
