@@ -22,6 +22,7 @@
 
 #include <klocale.h>
 #include <kdebug.h>
+#include <kmessagebox.h>
 #include <kstandarddirs.h>
 
 #include "event.h"
@@ -254,10 +255,19 @@ bool Scheduler::acceptAdd(IncidenceBase *incidence,ScheduleMessage::Status /* st
 bool Scheduler::acceptCancel(IncidenceBase *incidence,ScheduleMessage::Status /* status */)
 {
   bool ret = false;
-  Incidence *inc = mCalendar->incidence( incidence->uid() );
-  if ( inc ) {
-    mCalendar->deleteIncidence( inc );
-    ret = true;
+  const IncidenceBase *toDelete = mCalendar->incidenceFromSchedulingID( incidence->uid() );
+  if ( toDelete ) {
+    Event *even = mCalendar->event(toDelete->uid());
+    if (even) {
+      mCalendar->deleteEvent(even);
+      ret = true;
+    } else {
+      Todo *todo = mCalendar->todo(toDelete->uid());
+      if (todo) {
+        mCalendar->deleteTodo(todo);
+        ret = true;
+      }
+    }
   }
   deleteTransaction(incidence);
   return ret;
@@ -283,27 +293,93 @@ bool Scheduler::acceptReply(IncidenceBase *incidence,ScheduleMessage::Status /*
   bool ret = false;
   Event *ev = mCalendar->event(incidence->uid());
   Todo *to = mCalendar->todo(incidence->uid());
+
+  // try harder to find the correct incidence
+  if ( !ev && !to ) {
+    const Incidence::List list = mCalendar->incidences();
+    for ( Incidence::List::ConstIterator it = list.begin(), end = list.end(); it != end; ++it ) {
+      if ( (*it)->schedulingID() == incidence->uid() ) {
+        ev = dynamic_cast<Event*>( *it );
+        to = dynamic_cast<Todo*>( *it );
+        break;
+      }
+    }
+  }
+
   if (ev || to) {
     //get matching attendee in calendar
     kdDebug(5800) << "Scheduler::acceptTransaction match found!" << endl;
     Attendee::List attendeesIn = incidence->attendees();
     Attendee::List attendeesEv;
+    Attendee::List attendeesNew;
     if (ev) attendeesEv = ev->attendees();
     if (to) attendeesEv = to->attendees();
     Attendee::List::ConstIterator inIt;
     Attendee::List::ConstIterator evIt;
     for ( inIt = attendeesIn.begin(); inIt != attendeesIn.end(); ++inIt ) {
       Attendee *attIn = *inIt;
+      bool found = false;
       for ( evIt = attendeesEv.begin(); evIt != attendeesEv.end(); ++evIt ) {
         Attendee *attEv = *evIt;
         if (attIn->email().lower()==attEv->email().lower()) {
           //update attendee-info
           kdDebug(5800) << "Scheduler::acceptTransaction update attendee" << endl;
           attEv->setStatus(attIn->status());
+          attEv->setDelegate(attIn->delegate());
+          attEv->setDelegator(attIn->delegator());
           ret = true;
+          found = true;
         }
       }
+      if ( !found && attIn->status() != Attendee::Declined )
+        attendeesNew.append( attIn );
     }
+
+    bool attendeeAdded = false;
+    for ( Attendee::List::ConstIterator it = attendeesNew.constBegin(); it != attendeesNew.constEnd(); ++it ) {
+      Attendee* attNew = *it;
+      QString msg = i18n("%1 wants to attend %2 but was not invited.").arg( attNew->fullName() )
+          .arg( ev ? ev->summary() : to->summary() );
+      if ( !attNew->delegator().isEmpty() )
+        msg = i18n("%1 wants to attend %2 on behalf of %3.").arg( attNew->fullName() )
+            .arg( ev ? ev->summary() : to->summary() )
+            .arg( attNew->delegator() );
+      if ( KMessageBox::questionYesNo( 0, msg, i18n("Uninvited attendee"),
+           KGuiItem(i18n("Accept Attendance")), KGuiItem(i18n("Reject Attendance")) )
+           != KMessageBox::Yes )
+      {
+        KCal::Incidence *cancel = dynamic_cast<Incidence*>( incidence );
+        if ( cancel )
+          cancel->addComment( i18n( "The organizer rejected your attendance at this meeting." ) );
+        performTransaction( cancel ? cancel : incidence, Scheduler::Cancel, attNew->fullName() );
+        delete cancel;
+        continue;
+      }
+
+      Attendee *a = new Attendee( attNew->name(), attNew->email(), attNew->RSVP(),
+                                  attNew->status(), attNew->role(), attNew->uid() );
+      a->setDelegate( attNew->delegate() );
+      a->setDelegator( attNew->delegator() );
+      if ( ev )
+        ev->addAttendee( a );
+      else if ( to )
+        to->addAttendee( a );
+      ret = true;
+      attendeeAdded = true;
+    }
+
+    // send update about new participants
+    if ( attendeeAdded ) {
+      if ( ev ) {
+        ev->setRevision( ev->revision() + 1 );
+        performTransaction( ev, Scheduler::Request );
+      }
+      if ( to ) {
+        to->setRevision( ev->revision() + 1 );
+        performTransaction( to, Scheduler::Request );
+      }
+    }
+
     if ( ret ) {
       // We set at least one of the attendees, so the incidence changed
       // Note: This should not result in a sequence number bump
@@ -313,7 +389,7 @@ bool Scheduler::acceptReply(IncidenceBase *incidence,ScheduleMessage::Status /*
         to->updated();
     }
     if ( to ) {
-      // for VTODO a REPLY can be used to update the completion status of 
+      // for VTODO a REPLY can be used to update the completion status of
       // a task. see RFC2446 3.4.3
       Todo *update = dynamic_cast<Todo*> ( incidence );
       Q_ASSERT( update );
