@@ -21,6 +21,10 @@
 
 #include "calendarlocal.h"
 
+extern "C" {
+#include "icaltimezone.h"
+}
+
 #include <kaboutdata.h>
 #include <kapplication.h>
 #include <kdebug.h>
@@ -54,6 +58,9 @@ int main( int argc, char **argv )
     args->usage( "Wrong number of arguments." );
   }
 
+  // use zoneinfo data from source dir
+  set_zone_directory( KDETOPSRCDIR "/libkcal/libical/zoneinfo" );
+
   QString input = QFile::decodeName( args->arg( 0 ) );
   QString output = QFile::decodeName( args->arg( 1 ) );
 
