@@ -248,6 +248,18 @@ namespace GpgME {
     GpgME::Error startCombinedSigningAndEncryption( const std::vector<Key> & recipients, const Data & plainText, Data & cipherText, EncryptionFlags flags );
     // use encryptionResult() and signingResult() to retrieve the result objects...
 
+    //
+    //
+    // Audit Log
+    //
+    //
+    enum AuditLogFlags {
+        HtmlAuditLog = 1,
+        AuditLogWithHelp = 128
+    };
+    GpgME::Error startGetAuditLog( Data & output, unsigned int flags=0 );
+    GpgME::Error getAuditLog( Data & output, unsigned int flags=0 );
+
     //
     //
     // Run Control
@@ -287,6 +299,17 @@ namespace GpgME {
 
   KDE_EXPORT GpgME::Error checkEngine( Context::Protocol proto );
 
+  enum Feature {
+      ValidatingKeylistModeFeature = 0x00000001,
+      CancelOperationFeature       = 0x00000002,
+      WrongKeyUsageFeature         = 0x00000004,
+
+      AuditLogFeature              = 0x00001000,
+
+      FeatureMaxValue              = 0x80000000
+  };
+  KDE_EXPORT bool hasFeature( unsigned long feature );
+
 } // namespace GpgME
 
 #endif // __GPGMEPP_CONTEXT_H__
