@@ -35,7 +35,7 @@
 #include <kabc/addressee.h>
 
 #include "clicklineedit.h"
-#include "kcompletion.h"
+#include "kmailcompletion.h"
 #include <dcopobject.h>
 #include <kdepimmacros.h>
 
@@ -61,6 +61,7 @@ class KDE_EXPORT AddresseeLineEdit : public ClickLineEdit, public DCOPObject
     virtual ~AddresseeLineEdit();
 
     virtual void setFont( const QFont& );
+    void allowSemiColonAsSeparator( bool );
 
   public slots:
     void cursorAtEnd();
@@ -92,12 +93,12 @@ class KDE_EXPORT AddresseeLineEdit : public ClickLineEdit, public DCOPObject
     virtual QPopupMenu *createPopupMenu();
 
     /**
-     * Adds the name of a completion source to the internal list of 
+     * Adds the name of a completion source to the internal list of
      * such sources and returns its index, such that that can be used
      * for insertion of items associated with that source.
      */
     int addCompletionSource( const QString& );
-    
+
     /** return whether we are using sorted or weighted display */
     static KCompletion::CompOrder completionOrder();
 
@@ -108,6 +109,7 @@ class KDE_EXPORT AddresseeLineEdit : public ClickLineEdit, public DCOPObject
   private slots:
     void slotCompletion();
     void slotPopupCompletion( const QString& );
+    void slotReturnPressed( const QString& );
     void slotStartLDAPLookup();
     void slotLDAPSearchData( const KPIM::LdapResultList& );
     void slotEditCompletionOrder();
@@ -120,9 +122,10 @@ class KDE_EXPORT AddresseeLineEdit : public ClickLineEdit, public DCOPObject
     void stopLDAPLookup();
 
     void setCompletedItems( const QStringList& items, bool autoSuggest );
-    void addCompletionItem( const QString& string, int weight, int source );
+    void addCompletionItem( const QString& string, int weight, int source, const QStringList * keyWords=0 );
     QString completionSearchText( QString& );
     const QStringList getAdjustedCompletionItems( bool fullSearch );
+    void updateSearchString();
 
     QString m_previousAddresses;
     QString m_searchString;
@@ -130,11 +133,14 @@ class KDE_EXPORT AddresseeLineEdit : public ClickLineEdit, public DCOPObject
     bool m_completionInitialized;
     bool m_smartPaste;
     bool m_addressBookConnected;
+    bool m_lastSearchMode;
+    bool m_searchExtended; //has \" been added?
+    bool m_useSemiColonAsSeparator;
 
     //QMap<QString, KABC::Addressee> m_contactMap;
 
     static bool s_addressesDirty;
-    static KCompletion *s_completion;
+    static KMailCompletion *s_completion;
     static CompletionItemsMap* s_completionItemMap;
     static QTimer *s_LDAPTimer;
     static KPIM::LdapSearch *s_LDAPSearch;
@@ -144,6 +150,20 @@ class KDE_EXPORT AddresseeLineEdit : public ClickLineEdit, public DCOPObject
 
     class AddresseeLineEditPrivate;
     AddresseeLineEditPrivate *d;
+
+    //until MenuID moves into protected in KLineEdit, we keep a copy here
+    //Constants that represent the ID's of the popup menu.
+      enum MenuID
+      {
+        Default = 42,
+        NoCompletion,
+        AutoCompletion,
+        ShellCompletion,
+        PopupCompletion,
+        ShortAutoCompletion,
+        PopupAutoCompletion
+      };
+
 };
 
 }
