@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <qlayout.h>
@@ -189,6 +189,7 @@ KPrefsWidColor::KPrefsWidColor( KConfigSkeleton::ItemColor *item,
   mButton = new KColorButton( parent );
   connect( mButton, SIGNAL( changed( const QColor & ) ), SIGNAL( changed() ) );
   mLabel = new QLabel( mButton, mItem->label()+':', parent );
+  mLabel->setBuddy( mButton );
   QString whatsThis = mItem->whatsThis();
   if (!whatsThis.isNull()) {
     QWhatsThis::add(mButton, whatsThis);
@@ -285,6 +286,7 @@ KPrefsWidTime::KPrefsWidTime( KConfigSkeleton::ItemDateTime *item,
 {
   mLabel = new QLabel( mItem->label()+':', parent );
   mTimeEdit = new KTimeEdit( parent );
+  mLabel->setBuddy( mTimeEdit );
   connect( mTimeEdit, SIGNAL( timeChanged( QTime ) ), SIGNAL( changed() ) );
   QString whatsThis = mItem->whatsThis();
   if ( !whatsThis.isNull() ) {
@@ -323,6 +325,7 @@ KPrefsWidDuration::KPrefsWidDuration( KConfigSkeleton::ItemDateTime *item,
 {
   mLabel = new QLabel( mItem->label()+':', parent );
   mTimeEdit = new QTimeEdit( parent );
+  mLabel->setBuddy( mTimeEdit );
   mTimeEdit->setAutoAdvance( true );
   mTimeEdit->setDisplay( QTimeEdit::Hours | QTimeEdit::Minutes );
   mTimeEdit->setRange( QTime( 0, 1 ), QTime( 24, 0 ) ); // [1min, 24hr]
@@ -363,6 +366,7 @@ KPrefsWidDate::KPrefsWidDate( KConfigSkeleton::ItemDateTime *item,
 {
   mLabel = new QLabel( mItem->label()+':', parent );
   mDateEdit = new KDateEdit( parent );
+  mLabel->setBuddy( mDateEdit );
   connect( mDateEdit, SIGNAL( dateChanged( const QDate& ) ), SIGNAL( changed() ) );
   QString whatsThis = mItem->whatsThis();
   if ( !whatsThis.isNull() ) {
@@ -435,6 +439,41 @@ QValueList<QWidget *> KPrefsWidRadios::widgets() const
   return w;
 }
 
+KPrefsWidCombo::KPrefsWidCombo( KConfigSkeleton::ItemEnum *item,
+                                  QWidget *parent )
+  : mItem( item )
+{
+  QHBox *hbox = new QHBox(parent);
+  new QLabel( mItem->label(), hbox );
+  mCombo = new QComboBox( hbox );
+  connect( mCombo, SIGNAL( activated( int ) ), SIGNAL( changed() ) );
+}
+
+KPrefsWidCombo::~KPrefsWidCombo()
+{
+}
+
+void KPrefsWidCombo::readConfig()
+{
+  mCombo->setCurrentItem( mItem->value() );
+}
+
+void KPrefsWidCombo::writeConfig()
+{
+  mItem->setValue( mCombo->currentItem() );
+}
+
+QValueList<QWidget *> KPrefsWidCombo::widgets() const
+{
+  QValueList<QWidget *> w;
+  w.append( mCombo );
+  return w;
+}
+
+QComboBox* KPrefsWidCombo::comboBox()
+{
+  return mCombo;
+}
 
 KPrefsWidString::KPrefsWidString( KConfigSkeleton::ItemString *item,
                                   QWidget *parent,
@@ -443,6 +482,7 @@ KPrefsWidString::KPrefsWidString( KConfigSkeleton::ItemString *item,
 {
   mLabel = new QLabel( mItem->label()+':', parent );
   mEdit = new QLineEdit( parent );
+  mLabel->setBuddy( mEdit );
   connect( mEdit, SIGNAL( textChanged( const QString & ) ),
            SIGNAL( changed() ) );
   mEdit->setEchoMode( echomode );
@@ -491,6 +531,7 @@ KPrefsWidPath::KPrefsWidPath( KConfigSkeleton::ItemPath *item, QWidget *parent,
 {
   mLabel = new QLabel( mItem->label()+':', parent );
   mURLRequester = new KURLRequester( parent );
+  mLabel->setBuddy( mURLRequester );
   mURLRequester->setMode( mode );
   mURLRequester->setFilter( filter );
   connect( mURLRequester, SIGNAL( textChanged( const QString & ) ),
@@ -602,6 +643,20 @@ KPrefsWidRadios *KPrefsWidManager::addWidRadios( KConfigSkeleton::ItemEnum *item
   return w;
 }
 
+KPrefsWidCombo *KPrefsWidManager::addWidCombo( KConfigSkeleton::ItemEnum *item,
+                                               QWidget* parent )
+{
+  KPrefsWidCombo *w = new KPrefsWidCombo( item, parent );
+  QValueList<KConfigSkeleton::ItemEnum::Choice> choices;
+  choices = item->choices();
+  QValueList<KConfigSkeleton::ItemEnum::Choice>::ConstIterator it;
+  for( it = choices.begin(); it != choices.end(); ++it ) {
+    w->comboBox()->insertItem( (*it).label, -1 );
+  }
+  addWid( w );
+  return w;
+}
+
 KPrefsWidString *KPrefsWidManager::addWidString( KConfigSkeleton::ItemString *item,
                                                  QWidget *parent )
 {
