@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 #ifndef KPREFSDIALOG_H
 #define KPREFSDIALOG_H
@@ -37,6 +37,7 @@
 
 class KColorButton;
 class QCheckBox;
+class QComboBox;
 class QLabel;
 class QSpinBox;
 class QButtonGroup;
@@ -411,6 +412,41 @@ class KDE_EXPORT KPrefsWidRadios : public KPrefsWid
     QButtonGroup *mBox;
 };
 
+/**
+  @short Widgets for settings represented by a combo box in
+  @ref KPrefsDialog.
+
+  This class provides a control element for configuring selections. It is meant
+  to be used by KPrefsDialog. The user is responsible for the layout management.
+
+  The setting is interpreted as an int value, corresponding to the index in 
+  the combo box.
+*/
+class KDE_EXPORT KPrefsWidCombo : public KPrefsWid
+{
+  public:
+    /**
+      Create a control element for selection of an option. It consists of a
+      combo box.
+
+      @param item    The KConfigSkeletonItem representing the preferences entry.
+      @param parent  Parent widget.
+    */
+    KPrefsWidCombo( KConfigSkeleton::ItemEnum *item, QWidget *parent );
+    virtual ~KPrefsWidCombo();
+
+    void readConfig();
+    void writeConfig();
+
+    QComboBox *comboBox();
+    QValueList<QWidget *> widgets() const;
+
+  private:
+    KConfigSkeleton::ItemEnum *mItem;
+    QComboBox *mCombo;
+};
+
+
 
 /**
   @short Widgets for string settings in @ref KPrefsDialog.
@@ -600,6 +636,16 @@ class KDE_EXPORT KPrefsWidManager
     KPrefsWidRadios *addWidRadios( KConfigSkeleton::ItemEnum *item,
                                    QWidget *parent );
 
+    /**
+      Register a @ref KPrefsWidCombo object. The choices represented by the
+      given item object are automatically added to the combo box.
+
+      @param item    The KConfigSkeletonItem representing the preferences entry.
+      @param parent  Parent widget.
+    */
+    KPrefsWidCombo *addWidCombo( KConfigSkeleton::ItemEnum *item,
+                                   QWidget *parent );
+
     /**
       Register a @ref KPrefsWidString object.
 
