@@ -428,6 +428,8 @@ RuleEditWidget::RuleEditWidget(KScoringManager *m,QWidget *p, const char *n)
   expireCheck = new QCheckBox(i18n("&Expire rule automatically"), groupB);
   groupL->addMultiCellWidget( expireCheck, 4,4, 0,1 );
   expireEdit = new KIntSpinBox(1,99999,1,30,10, groupB, "expireWidget");
+  //Init suffix
+  slotExpireEditChanged(30);
   connect(expireEdit, SIGNAL(valueChanged(int)), SLOT(slotExpireEditChanged(int)));
   groupL->addWidget( expireEdit, 5, 1 );
   expireLabel = new QLabel(expireEdit, i18n("&Rule is valid for:"), groupB, "expireLabel");
