@@ -14,14 +14,15 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <kapplication.h>
 #include <kurl.h>
 #include <kdebug.h>
 #include <kcursor.h>
+#include <klocale.h>
 
 // These for test() method
 #include <kio/http.h>
@@ -41,8 +42,9 @@
 
 using namespace KPIM;
 
-ExchangeClient::ExchangeClient( ExchangeAccount* account, const QString& timeZoneId ) :
-  mWindow( 0 ), mTimeZoneId( timeZoneId )
+ExchangeClient::ExchangeClient( ExchangeAccount *account,
+                                const QString &timeZoneId )
+  : mWindow( 0 ), mTimeZoneId( timeZoneId )
 {
   kdDebug() << "Creating ExchangeClient...\n";
   mAccount = account;
@@ -78,7 +80,7 @@ QString ExchangeClient::timeZoneId()
 
 void ExchangeClient::test()
 {
-//  mAccount->authenticate( mWindow );
+//  if ( !mAccount->authenticate( mWindow ) ) return;
   kdDebug() << "Entering test()" << endl;
   KURL baseURL = KURL( "http://mail.tbm.tudelft.nl/janb/Calendar" );
   KURL url( "webdav://mail.tbm.tudelft.nl/exchange/" );
@@ -116,40 +118,73 @@ ExchangeMonitor* ExchangeClient::monitor( int pollMode, const QHostAddress& ownI
   return new ExchangeMonitor( mAccount, pollMode, ownInterface  );
 }
 */
-void ExchangeClient::download( KCal::Calendar* calendar, const QDate& start, const QDate& end, bool showProgress )
+void ExchangeClient::download( KCal::Calendar *calendar, const QDate &start,
+                               const QDate &end, bool showProgress )
 {
-  mAccount->authenticate( mWindow );
-  ExchangeDownload* worker = new ExchangeDownload( mAccount, mWindow );
+  kdDebug() << "ExchangeClient::download1()" << endl;
+
+  if ( !mAccount->authenticate( mWindow ) ) {
+    emit downloadFinished( 0, i18n("Authentication error") ); 
+    return;
+  }
+
+  ExchangeDownload *worker = new ExchangeDownload( mAccount, mWindow );
   worker->download( calendar, start, end, showProgress );
-  connect( worker, SIGNAL( finished( ExchangeDownload*, int, const QString& ) ), this, SLOT( slotDownloadFinished( ExchangeDownload*, int, const QString& ) ) );
+  connect( worker,
+           SIGNAL( finished( ExchangeDownload *, int, const QString & ) ),
+           SLOT( slotDownloadFinished( ExchangeDownload *, int,
+                                       const QString & ) ) );
 }
 
-void ExchangeClient::download( const QDate& start, const QDate& end, bool showProgress )
+void ExchangeClient::download( const QDate &start, const QDate &end,
+                               bool showProgress )
 {
-  mAccount->authenticate( mWindow );
-  ExchangeDownload* worker = new ExchangeDownload( mAccount, mWindow );
+  kdDebug() << "ExchangeClient::download2()" << endl;
+
+  if ( !mAccount->authenticate( mWindow ) ) {
+    emit downloadFinished( 0, i18n("Authentication error") ); 
+    return;
+  }
+
+  ExchangeDownload *worker = new ExchangeDownload( mAccount, mWindow );
   worker->download( start, end, showProgress );
-  connect( worker, SIGNAL( finished( ExchangeDownload*, int, const QString& ) ), 
-           this, SLOT( slotDownloadFinished( ExchangeDownload*, int, const QString& ) ) );
-  connect( worker, SIGNAL( gotEvent( KCal::Event*, const KURL&  ) ), 
-           this, SIGNAL( event( KCal::Event*, const KURL& ) ) );
+  connect( worker,
+           SIGNAL( finished( ExchangeDownload *, int, const QString & ) ), 
+           SLOT( slotDownloadFinished( ExchangeDownload *, int,
+                                       const QString & ) ) );
+  connect( worker, SIGNAL( gotEvent( KCal::Event *, const KURL & ) ), 
+           SIGNAL( event( KCal::Event *, const KURL & ) ) );
 }
 
-void ExchangeClient::upload( KCal::Event* event )
+void ExchangeClient::upload( KCal::Event *event )
 {
-  mAccount->authenticate( mWindow );
-  ExchangeUpload* worker = new ExchangeUpload( event, mAccount, mTimeZoneId, mWindow );
-  connect( worker, SIGNAL( finished( ExchangeUpload*, int, const QString& ) ), this, SLOT( slotUploadFinished( ExchangeUpload*, int, const QString& ) ) );
+  kdDebug() << "ExchangeClient::upload()" << endl;
+
+  if ( !mAccount->authenticate( mWindow ) ) {
+    emit uploadFinished( 0, i18n("Authentication error") ); 
+    return;
+  }
+
+  ExchangeUpload *worker = new ExchangeUpload( event, mAccount, mTimeZoneId,
+                                               mWindow );
+  connect( worker, SIGNAL( finished( ExchangeUpload *, int, const QString & ) ),
+           SLOT( slotUploadFinished( ExchangeUpload *, int, const QString & ) ) );
 }
 
-void ExchangeClient::remove( KCal::Event* event )
+void ExchangeClient::remove( KCal::Event *event )
 {
-  mAccount->authenticate( mWindow );
-  ExchangeDelete* worker = new ExchangeDelete( event, mAccount, mWindow );
-  connect( worker, SIGNAL( finished( ExchangeDelete*, int, const QString& ) ), this, SLOT( slotRemoveFinished( ExchangeDelete*, int, const QString& ) ) );
+  if ( !mAccount->authenticate( mWindow ) ) {
+    emit removeFinished( 0, i18n("Authentication error") ); 
+    return;
+  }
+
+  ExchangeDelete *worker = new ExchangeDelete( event, mAccount, mWindow );
+  connect( worker, SIGNAL( finished( ExchangeDelete *, int, const QString & ) ),
+           SLOT( slotRemoveFinished( ExchangeDelete *, int, const QString & ) ) );
 }
 
-void ExchangeClient::slotDownloadFinished( ExchangeDownload* worker, int result, const QString& moreInfo ) 
+void ExchangeClient::slotDownloadFinished( ExchangeDownload *worker,
+                                           int result, const QString &moreInfo )
 {
   emit downloadFinished( result, moreInfo );
   worker->deleteLater();
@@ -175,61 +210,71 @@ void ExchangeClient::slotRemoveFinished( ExchangeDelete* worker, int result, con
   worker->deleteLater();
 }
 
-int ExchangeClient::downloadSynchronous( KCal::Calendar* calendar, const QDate& start, const QDate& end, bool showProgress)
+int ExchangeClient::downloadSynchronous( KCal::Calendar *calendar,
+                                         const QDate &start, const QDate &end,
+                                         bool showProgress )
 {
+  kdDebug() << "ExchangeClient::downloadSynchronous()" << endl;
+
   mClientState = WaitingForResult;
-  connect(this, SIGNAL(downloadFinished( int, const QString& )), 
-		  this, SLOT(slotSyncFinished( int, const QString& )));
+  connect( this, SIGNAL( downloadFinished( int, const QString & ) ), 
+           SLOT( slotSyncFinished( int, const QString & ) ) );
 
   download( calendar, start, end, showProgress );
 
-  QApplication::setOverrideCursor( KCursor::waitCursor() );
+  // TODO: Remove this busy loop
+  QApplication::setOverrideCursor
+  ( KCursor::waitCursor() );
   do {
     qApp->processEvents();
-  } while ( mClientState==WaitingForResult );
+  } while ( mClientState == WaitingForResult );
   QApplication::restoreOverrideCursor();  
-  disconnect(this, SIGNAL(downloadFinished( int, const QString& )), 
-		  this, SLOT(slotSyncFinished( int, const QString& )));
+
+  disconnect( this, SIGNAL( downloadFinished( int, const QString & ) ), 
+              this, SLOT( slotSyncFinished( int, const QString & ) ) );
+
   return mSyncResult;
 }
 
 int ExchangeClient::uploadSynchronous( KCal::Event* event )
 {
   mClientState = WaitingForResult;
-  connect(this, SIGNAL(uploadFinished( int, const QString& )), 
-		  this, SLOT(slotSyncFinished( int, const QString& )));
+  connect( this, SIGNAL( uploadFinished( int, const QString & ) ), 
+           SLOT( slotSyncFinished( int, const QString & ) ) );
 
   upload( event );
 
+  // TODO: Remove this busy loop
   QApplication::setOverrideCursor( KCursor::waitCursor() );
   do {
     qApp->processEvents();
-  } while ( mClientState==WaitingForResult );
+  } while ( mClientState == WaitingForResult );
   QApplication::restoreOverrideCursor();  
-  disconnect(this, SIGNAL(uploadFinished( int, const QString& )), 
-		  this, SLOT(slotSyncFinished( int, const QString& )));
+  disconnect( this, SIGNAL( uploadFinished( int, const QString & ) ), 
+              this, SLOT( slotSyncFinished( int, const QString & ) ) );
   return mSyncResult;
 }
 
 int ExchangeClient::removeSynchronous( KCal::Event* event )
 {
   mClientState = WaitingForResult;
-  connect(this, SIGNAL(removeFinished( int, const QString& )), 
-		  this, SLOT(slotSyncFinished( int, const QString& )));
+  connect( this, SIGNAL( removeFinished( int, const QString & ) ), 
+           SLOT( slotSyncFinished( int, const QString & ) ) );
 
   remove( event );
 
+  // TODO: Remove this busy loop
   QApplication::setOverrideCursor( KCursor::waitCursor() );
   do {
     qApp->processEvents();
-  } while ( mClientState==WaitingForResult );
+  } while ( mClientState == WaitingForResult );
   QApplication::restoreOverrideCursor();  
-  disconnect(this, SIGNAL(removeFinished( int, const QString& )), 
-		  this, SLOT(slotSyncFinished( int, const QString& )));
+  disconnect( this, SIGNAL( removeFinished( int, const QString & ) ), 
+              this, SLOT( slotSyncFinished( int, const QString & ) ) );
   return mSyncResult;
 }
 
-void ExchangeClient::slotSyncFinished( int result, const QString& moreInfo )
+void ExchangeClient::slotSyncFinished( int result, const QString &moreInfo )
 {
   kdDebug() << "Exchangeclient::slotSyncFinished("<<result<<","<<moreInfo<<")" << endl;
   if ( mClientState == WaitingForResult ) {
