@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 #ifndef KDEPIM_EXCHANGE_UPLOAD_H
 #define KDEPIM_EXCHANGE_UPLOAD_H
@@ -24,6 +24,8 @@
 #include <qwidget.h>
 #include <kio/job.h>
 
+#include <kdepimmacros.h>
+
 #include <libkcal/calendar.h>
 #include <libkcal/event.h>
 
@@ -31,7 +33,7 @@ namespace KPIM {
 
 class ExchangeAccount;
 
-class ExchangeUpload : public QObject {
+class KDE_EXPORT ExchangeUpload : public QObject {
     Q_OBJECT
   public:
     ExchangeUpload( KCal::Event* event, ExchangeAccount* account, const QString& timeZoneId, QWidget* window=0 );
